#include <stdint.h>

const static uint16_t mandelbrot1[] = {
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0x810, 0x810, 0x10, 0x10, 0x10, 0xF, 
0xE, 0x2E, 0x2F, 0xE, 0xF, 0x82F, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xC, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0x830, 0xF, 
0xF, 0x10, 0x10, 0xF, 0xF, 0x2F, 0xE, 0xF, 0x2F, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0x4F, 0x2F, 0x2F, 0x50, 0x71, 0x10, 0x30, 
0x2F, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x82E, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0x90, 0x21B5, 
0x2A16, 0x21D5, 0x50, 0x92, 0x91, 0x71, 0x30, 0x50, 0x30, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0x2F, 0xB1, 0x1194, 0x3AB9, 0x3AFA, 0x133, 0xD2, 
0xF2, 0x113, 0x2A17, 0x8D2, 0x31, 0x30, 0xF, 0xF, 0xE, 
0x2F, 0xF, 0xE, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0x2F, 0x70, 
0xB1, 0xD2, 0x435C, 0x53DD, 0x2A98, 0x133, 0x3B1B, 0x3AFA, 0xF3, 
0x51, 0x51, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0x30, 0x70, 0x8F3, 0xB3, 0x955, 0x2A98, 
0x439B, 0x4BDC, 0x439B, 0x994, 0xB1, 0xB2, 0x892, 0x31, 0x30, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0x10, 0x30, 
0x71, 0x71, 0xD3, 0x934, 0xD1, 0x22B7, 0x5C5D, 0x1A55, 0x132, 
0x133, 0xB2, 0x71, 0x72, 0x51, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0x30, 0x30, 0x71, 0x71, 0xB2, 0x934, 
0x133, 0x1215, 0x5C7D, 0x3318, 0x132, 0x954, 0xF2, 0xB2, 0x71, 
0x72, 0x50, 0x30, 0x30, 0xF, 0xF, 0x30, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0x2E, 0xD, 
0x2D, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x50, 0x871, 0x891, 0xB2, 0xD2, 0x154, 0x1A36, 0x5C7D, 0x3338, 
0x152, 0x973, 0xF2, 0x8F3, 0x8D2, 0x71, 0x51, 0x71, 0x10, 
0x51, 0x30, 0xF, 0x30, 0x30, 0xF, 0x2F, 0xF, 0xF, 
0x82F, 0xF, 0xE, 0xE, 0x2E, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x50, 0x51, 0xB2, 0xB2, 
0xF3, 0x133, 0x3B5A, 0x64FE, 0x43D9, 0x22B5, 0x3B38, 0x2A77, 0xD2, 
0xD2, 0xB2, 0x92, 0x71, 0x892, 0x71, 0x51, 0x71, 0x51, 
0x50, 0x30, 0x50, 0x50, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x30, 0x50, 0x91, 0x91, 0xB2, 0xF3, 0x974, 0x993, 0x541A, 
0x85DF, 0x85DE, 0x6CFC, 0x2276, 0x133, 0x933, 0xB2, 0xB2, 0xB2, 
0x72, 0x72, 0x92, 0x71, 0x71, 0xB2, 0x8D2, 0x91, 0x30, 
0x30, 0x2F, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x51, 0x70, 0x91, 
0xB3, 0xD3, 0x1194, 0x971, 0x5C39, 0x85BC, 0x5435, 0x6CF9, 0x991, 
0x973, 0x954, 0x113, 0xD2, 0xF3, 0xB3, 0xB2, 0xB2, 0xD2, 
0xD2, 0x71, 0x1174, 0x3257, 0x10F3, 0x50, 0x2F, 0x2F, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x30, 0x30, 0x51, 0x91, 0x71, 0x92, 0x914, 0x112, 0x4359, 
0x74FC, 0x7D9C, 0x85DC, 0x85BC, 0x541A, 0x53FC, 0x1A16, 0x113, 0x113, 
0xF3, 0xD3, 0xF3, 0x113, 0x113, 0xF3, 0xD2, 0x3298, 0x4B3B, 
0x8F2, 0x50, 0x2F, 0x2F, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x51, 0x91, 
0xB2, 0xD2, 0xB2, 0xF2, 0x32D9, 0x2AD7, 0x2AF6, 0x3397, 0x4C7B, 
0x7DDF, 0x4BFB, 0x9B4, 0x995, 0x154, 0x134, 0x914, 0xD3, 0x113, 
0x954, 0x974, 0x153, 0x435B, 0x433A, 0xD2, 0xB1, 0x70, 0x2F, 
0xF, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x30, 0x30, 0x50, 0x51, 0x71, 0x92, 0x92, 0x913, 0x134, 
0x154, 0x194, 0x9F5, 0xA14, 0x2317, 0x759F, 0x3BB7, 0xA14, 0x1216, 
0x174, 0x1195, 0x975, 0x2217, 0x1A36, 0x172, 0x192, 0x9D4, 0x645E, 
0x643E, 0x42FA, 0x1134, 0x50, 0x50, 0x30, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xF, 0xF, 0x10, 0x2F, 0x50, 0x51, 0x71, 
0x92, 0x92, 0xB3, 0xD3, 0x114, 0x155, 0x995, 0x11F5, 0x1236, 
0x2AF6, 0x7D9D, 0x8E3F, 0x549C, 0x214, 0x1A16, 0x11D6, 0x174, 0x331A, 
0x5C9C, 0x4C19, 0x5CBB, 0x64DC, 0x5C7C, 0x11F4, 0x21F6, 0x913, 0x71, 
0x50, 0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0x10, 
0x30, 0x30, 0x50, 0x51, 0x71, 0x92, 0xB2, 0xB3, 0xD3, 
0x114, 0x134, 0x974, 0x11B5, 0x9D5, 0x22B6, 0x85DF, 0x9EFF, 0x75BE, 
0x1AB5, 0x1A76, 0x2297, 0x9F4, 0x2B37, 0x7DDF, 0x863F, 0x7DFF, 0x6D5D, 
0x4BDA, 0x152, 0xF2, 0x91, 0x71, 0x50, 0x30, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xF, 0x30, 0x31, 0x50, 0x50, 0x71, 
0x71, 0x92, 0xB2, 0xD2, 0xF3, 0x113, 0x153, 0x974, 0x9B5, 
0x1B5, 0x22F9, 0x5CDE, 0x5D1C, 0x9EBF, 0x5CD9, 0x1273, 0x3B97, 0x75BD, 
0x8E5F, 0x6D3D, 0x3B98, 0x6D1E, 0x2AF7, 0x1A36, 0x1195, 0xD2, 0xB2, 
0x91, 0x70, 0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0x2F, 
0x31, 0x31, 0x51, 0x51, 0x71, 0x91, 0x91, 0xB2, 0xD2, 
0xF2, 0x112, 0x133, 0x174, 0x9B5, 0x9F6, 0x1277, 0xA76, 0x12B5, 
0x8E3F, 0x96BF, 0x54BA, 0x863F, 0x96DF, 0x8E5F, 0x4BF9, 0x9D3, 0x11F4, 
0x1A15, 0xD2, 0x113, 0xD3, 0xB2, 0x71, 0x50, 0x30, 0x10, 
0x810, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x31, 0x32, 0x51, 0x51, 
0x71, 0x91, 0xB2, 0xD2, 0xF3, 0x113, 0x133, 0x153, 0x974, 
0x995, 0x11D6, 0x1216, 0x1A97, 0x2B38, 0x3BB8, 0x85FF, 0x96FF, 0x7DFF, 
0x3BF9, 0x2B18, 0x1A97, 0x1A57, 0x11D5, 0x974, 0x954, 0xF3, 0xB2, 
0x91, 0x71, 0x71, 0x31, 0x10, 0x810, 0x810, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0x10, 0x10, 0xF, 0x30, 
0x30, 0x31, 0x52, 0x51, 0x71, 0x91, 0x91, 0xB2, 0xD2, 
0x113, 0x134, 0x154, 0x154, 0x975, 0x995, 0x11D6, 0x1A37, 0x22D8, 
0x2317, 0x1293, 0x7DDE, 0x96DF, 0x1AF2, 0x1AD7, 0x1AB8, 0x1257, 0x9D6, 
0x9B6, 0x955, 0x113, 0xD2, 0xD2, 0xB2, 0x91, 0x871, 0x31, 
0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x30, 0x31, 0x51, 0x51, 0x71, 
0x91, 0x92, 0xB2, 0xB2, 0xD2, 0xF3, 0x114, 0x134, 0x155, 
0x976, 0x9B6, 0x1217, 0x1A78, 0x1A97, 0x2B37, 0x5C99, 0xA6DF, 0xA6FE, 
0x5497, 0x2B78, 0x1296, 0x1256, 0x9F6, 0x976, 0x956, 0x114, 0xD3, 
0xD3, 0x92, 0x71, 0x71, 0x51, 0x30, 0x30, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 
0x30, 0x51, 0x51, 0x71, 0x91, 0xB1, 0xB2, 0xD2, 0xF2, 
0xF3, 0xF3, 0x114, 0x955, 0x976, 0x9B6, 0x1217, 0x9F5, 0x1276, 
0x1AD7, 0x5CDC, 0xAEFF, 0xB6FE, 0xAEFD, 0x965E, 0x2B57, 0x1AB7, 0x1276, 
0xA16, 0x996, 0x136, 0x114, 0xF3, 0xF3, 0xB3, 0x92, 0x71, 
0x51, 0x50, 0x50, 0x2F, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x2F, 0x30, 0x50, 0x71, 0x71, 0x71, 
0x91, 0xB2, 0xD2, 0xD2, 0xF3, 0xF3, 0x933, 0x954, 0x975, 
0x975, 0x1B4, 0x1235, 0x43F9, 0x33D8, 0x2377, 0x4459, 0x95FA, 0xBEDC, 
0xAEBD, 0x755B, 0x2B57, 0x1AD7, 0x1F4, 0x1D4, 0x9D6, 0x155, 0x114, 
0xF3, 0xF4, 0xB2, 0xB2, 0x92, 0x51, 0x70, 0x2F, 0x50, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0xF, 0x2F, 0x30, 
0x50, 0x71, 0x71, 0x91, 0xB2, 0xB2, 0xD2, 0x913, 0x933, 
0x114, 0x955, 0x153, 0x994, 0x995, 0x1A36, 0x2AD7, 0x1252, 0x85BD, 
0x7DDC, 0x33F5, 0x6D59, 0xB679, 0xCEFB, 0xAE5A, 0x6CB6, 0x3B76, 0x2B57, 
0x4C5B, 0x337A, 0x195, 0x175, 0x934, 0x114, 0xF3, 0xF3, 0xB2, 
0x92, 0x92, 0x50, 0x50, 0x2F, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x30, 0x50, 0x70, 0x51, 0x8B2, 0x51, 
0x92, 0xD3, 0x934, 0xF2, 0xF2, 0x1155, 0x975, 0x995, 0x9D6, 
0x9D6, 0x2AD8, 0x7D7F, 0x9E7F, 0xAEBD, 0xB6FC, 0x85B7, 0xBF3B, 0xCEB8, 
0xA552, 0xC6B8, 0xAE59, 0x53D3, 0x7D7C, 0x967F, 0x3BB8, 0x173, 0x11B6, 
0x154, 0x955, 0x114, 0xD3, 0xD2, 0xD2, 0x71, 0x30, 0x871, 
0x50, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x11, 0x11, 0x31, 
0x70, 0x71, 0x92, 0xB2, 0xB2, 0x8F3, 0xD3, 0xD2, 0x3298, 
0x4B7A, 0x19D5, 0x994, 0x9F6, 0xA37, 0x1236, 0x1256, 0x545B, 0x8DFD, 
0xA67B, 0xAE99, 0xBED8, 0xDF7A, 0x8C4E, 0x800, 0xCE96, 0xD75B, 0x9E19, 
0xB75F, 0x85FD, 0x2315, 0x1A76, 0x9D6, 0x975, 0x134, 0x134, 0x134, 
0x935, 0xB3, 0x71, 0x892, 0x71, 0x30, 0x30, 0x30, 0x10, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x30, 0x31, 0x31, 0x31, 0x51, 0x71, 0x91, 0x92, 0x92, 
0x914, 0xF3, 0x1175, 0xD1, 0x53DA, 0x95FF, 0x3B37, 0x1A75, 0xA76, 
0xA77, 0x12B8, 0x1AD8, 0x2338, 0x2B55, 0x6CF6, 0xBEDA, 0x9D52, 0x5AC8, 
0x2102, 0x0, 0x7BCC, 0xB635, 0xAE78, 0xA69B, 0x969F, 0x6D3E, 0x9F6, 
0xA17, 0x9B6, 0x11B6, 0x995, 0x995, 0x114, 0xF4, 0x8D3, 0x8B2, 
0x71, 0x72, 0x51, 0x30, 0x10, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x31, 0x51, 0x51, 
0x71, 0x92, 0x92, 0xB2, 0x934, 0xD1, 0x973, 0x973, 0x171, 
0x2AD4, 0x8DFF, 0x965F, 0x4C19, 0xA75, 0x1AD8, 0x1296, 0x1AD6, 0x2B99, 
0x4438, 0x965B, 0xC71B, 0x738B, 0x800, 0x840, 0x18A2, 0x800, 0x5B09, 
0xC6D9, 0x95D8, 0x4C17, 0x33B9, 0x1AB8, 0x1258, 0x1217, 0x9D5, 0x193, 
0x172, 0x1A16, 0x4B7C, 0x19B5, 0x51, 0x8B2, 0x71, 0x51, 0x30, 
0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0xF, 
0x2F, 0x4F, 0x50, 0x51, 0x71, 0x91, 0xB2, 0xB2, 0xD3, 
0x70, 0x2A56, 0x19F3, 0x2294, 0x43B8, 0x2AF2, 0x6CF9, 0xB75F, 0x651A, 
0x1AD6, 0x2B59, 0x4C19, 0x6D1B, 0x6D3B, 0x5496, 0xA65A, 0xBEB9, 0x4227, 
0x800, 0x20E3, 0x18A2, 0x800, 0x5AEA, 0xC6BB, 0x9E1B, 0x3BB6, 0x1B16, 
0x12D7, 0x12B8, 0x1257, 0x1256, 0x3BB8, 0x22D4, 0x3B56, 0x857F, 0x3297, 
0x51, 0x8D3, 0x92, 0x71, 0x31, 0x30, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x4F, 0x50, 0x50, 0x50, 
0x71, 0xB2, 0xD2, 0xD2, 0x913, 0x431A, 0x857F, 0x53F9, 0x64DB, 
0xA6FF, 0xA6DF, 0x9EBD, 0xA6DD, 0x6D38, 0x2B56, 0x3B97, 0x7D3B, 0xAE9E, 
0xB6DE, 0x9E19, 0xBEBA, 0xE79C, 0x9CD2, 0x800, 0x1081, 0x1081, 0x800, 
0x8C50, 0xCEDB, 0x9598, 0x6477, 0x6D3D, 0x33B9, 0x12D7, 0x22F8, 0x1254, 
0x64DB, 0x967F, 0x85FF, 0x6D3E, 0x19F4, 0xF2, 0xD3, 0x92, 0x71, 
0x51, 0x31, 0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x2F, 0x30, 
0x50, 0x50, 0x50, 0x51, 0x71, 0x92, 0xB2, 0xD2, 0xD2, 
0x19D6, 0x539B, 0x7D3F, 0x9E7F, 0x969F, 0x7DDC, 0x7DBA, 0xB75F, 0xAEDD, 
0x64B5, 0x6D19, 0x6CF8, 0x8558, 0xA5F8, 0x9D96, 0xCEB9, 0xA552, 0xAD52, 
0x9491, 0x41E7, 0x0, 0x0, 0x6B2A, 0xDED8, 0xDF3A, 0xB659, 0xA639, 
0xAEFF, 0x655D, 0x1B36, 0x2357, 0x4C5A, 0x9E5E, 0x9E5E, 0x5C9A, 0x22D6, 
0x9B4, 0x934, 0xD3, 0xB2, 0x72, 0x71, 0x51, 0x30, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x2F, 0x30, 0x50, 0x50, 0x50, 0x51, 0x71, 
0x71, 0x92, 0xB2, 0xD2, 0xF2, 0x954, 0xF1, 0x2295, 0x7D9F, 
0x4C7A, 0x2333, 0x4C34, 0x9E7B, 0xB69A, 0xBEDB, 0xB6BB, 0xB6BB, 0xBEBB, 
0xB617, 0x4A67, 0x738B, 0x20C1, 0x800, 0x800, 0x1082, 0x841, 0x820, 
0x41E5, 0x5AC8, 0x6BAC, 0xB5F6, 0xC698, 0xA638, 0x85BB, 0x3BF6, 0x3396, 
0x64FA, 0xBF1F, 0x8DBA, 0x3375, 0x1254, 0x152, 0x133, 0x113, 0xB2, 
0x72, 0x72, 0x51, 0x31, 0x30, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x30, 0x50, 
0x51, 0x51, 0x51, 0x51, 0x71, 0x91, 0x91, 0xB2, 0xD2, 
0xF3, 0x913, 0x11B5, 0x1A36, 0x1235, 0xA56, 0x2B57, 0x4C16, 0xA65A, 
0xA573, 0xCE55, 0xA532, 0xAD94, 0xD6D9, 0x840E, 0x31A4, 0x0, 0x1060, 
0x1082, 0x1082, 0x0, 0x821, 0x1061, 0x0, 0x820, 0x0, 0x5AEA, 
0x5AE9, 0xA593, 0xA659, 0x95FA, 0x7519, 0x7519, 0xB6DD, 0xB6FD, 0xAF1F, 
0x5CBA, 0x2AD5, 0x1A15, 0xB1, 0x8D3, 0x92, 0x72, 0x71, 0x51, 
0x31, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x31, 0x31, 0x51, 0x51, 0x51, 0x52, 
0x92, 0x91, 0x91, 0xB2, 0xD2, 0xF3, 0x933, 0x954, 0x995, 
0x9F7, 0x1AB9, 0xA35, 0x651B, 0xB71E, 0xB5F4, 0x6AE6, 0x1020, 0x5246, 
0x8C0E, 0x0, 0x0, 0x18C2, 0x20, 0x841, 0x1, 0x842, 0x0, 
0x0, 0x1082, 0x18A2, 0x20C3, 0x800, 0x18A0, 0xAD72, 0xD73A, 0xBEBA, 
0xB69C, 0xB69C, 0xB69B, 0x8DB8, 0x755A, 0x9E9F, 0x753F, 0x11D4, 0xF2, 
0x8D3, 0x92, 0x92, 0x71, 0x51, 0x51, 0x31, 0x30, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x31, 0x31, 
0x31, 0x51, 0x51, 0x51, 0x72, 0x92, 0x92, 0x91, 0xB2, 
0xD3, 0xF3, 0x113, 0x975, 0x976, 0x11D7, 0x1238, 0x1AB8, 0x4419, 
0x7D7A, 0xCEFA, 0x6B6A, 0x800, 0x1060, 0x800, 0x840, 0x861, 0x20, 
0x21, 0x1, 0x1, 0x801, 0x0, 0x20, 0x0, 0x0, 0x801, 
0x20A3, 0x800, 0x5A89, 0xB594, 0x738C, 0xA512, 0xADD5, 0xAE39, 0x6CB6, 
0x22B3, 0x5C7D, 0x3B3A, 0x154, 0xF3, 0x8D3, 0xB2, 0x92, 0x72, 
0x71, 0x51, 0x51, 0x30, 0x10, 0x10, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x30, 0x30, 0x31, 0x51, 0x51, 0x51, 0x51, 0x71, 0x72, 
0x92, 0x92, 0xB2, 0xB2, 0xD2, 0xF3, 0x114, 0x154, 0x134, 
0x996, 0x11D6, 0x1216, 0x1235, 0x1AD4, 0x5C76, 0xB679, 0xBE36, 0x840E, 
0x20E2, 0x0, 0x1062, 0x841, 0x0, 0x21, 0x1, 0x801, 0x801, 
0x800, 0x0, 0x21, 0x21, 0x821, 0x1041, 0x800, 0x1882, 0x20C2, 
0x800, 0x20A0, 0xAD93, 0xBEDD, 0x6D1A, 0x1233, 0x9F5, 0x154, 0x975, 
0x114, 0xD3, 0xB2, 0xB2, 0x92, 0x72, 0x71, 0x51, 0x31, 
0x30, 0x30, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x50, 0x50, 0x51, 
0x51, 0x71, 0x71, 0x72, 0x92, 0xB2, 0xB2, 0xB2, 0xD2, 
0xD3, 0xF3, 0x114, 0x153, 0x194, 0x175, 0x9D5, 0x2AD7, 0x6D1D, 
0x753A, 0x6CD6, 0x9D96, 0xCED9, 0x8CB1, 0x20, 0x1061, 0x821, 0x21, 
0x1, 0x1, 0x821, 0x801, 0x800, 0x800, 0x0, 0x20, 0x21, 
0x21, 0x0, 0x1061, 0x820, 0x18C2, 0x4A27, 0x8C0D, 0xCEBA, 0x753A, 
0x2B56, 0x1A96, 0x1236, 0x996, 0x155, 0x114, 0xF3, 0xD2, 0xB2, 
0x92, 0x92, 0x71, 0x51, 0x51, 0x51, 0x30, 0x30, 0x30, 
0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x50, 0x50, 0x50, 0x51, 0x71, 0x71, 0x72, 0x92, 
0x92, 0xB2, 0xB2, 0xD2, 0xD2, 0xF3, 0xF3, 0x133, 0x174, 
0x174, 0x9D6, 0x9F5, 0x1212, 0x85BC, 0xBF1F, 0xA619, 0xBE9A, 0x9D54, 
0x840, 0x0, 0x840, 0x20, 0x0, 0x1, 0x1, 0x0, 0x800, 
0x800, 0x800, 0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 0x840, 
0x20, 0x8CB0, 0xD6F9, 0xA5D7, 0x4C15, 0x2335, 0x1255, 0x1215, 0x9B6, 
0x155, 0x134, 0x113, 0xD2, 0xB2, 0xB2, 0x92, 0x92, 0x71, 
0x71, 0x51, 0x51, 0x31, 0x30, 0x30, 0x10, 0x10, 0x10, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x30, 0xF, 0x30, 0x10, 0x10, 0x10, 0x71, 
0x31, 0x50, 0x50, 0x50, 0x30, 0x51, 0x71, 0x71, 0x71, 
0x71, 0x71, 0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xD1, 
0xF2, 0x112, 0x113, 0x134, 0x174, 0x174, 0x9D6, 0x1235, 0x5418, 
0xA65C, 0xBE99, 0xCEB8, 0xCE77, 0xA532, 0x2923, 0x0, 0x18A1, 0x0, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 
0x0, 0x1, 0x0, 0x0, 0x10A2, 0x20, 0x4288, 0xB656, 0x9DD5, 
0x8577, 0x9E5E, 0x7D5E, 0x2296, 0x974, 0x1175, 0x133, 0x113, 0xF2, 
0xD2, 0xB2, 0xB2, 0x92, 0x92, 0x71, 0x51, 0x51, 0x51, 
0x50, 0x51, 0x30, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x2F, 0xF, 0xF, 0x50, 
0x10, 0x10, 0x871, 0x51, 0x51, 0x51, 0x71, 0x71, 0x71, 
0x51, 0x71, 0x71, 0x71, 0x71, 0x91, 0x91, 0x91, 0x92, 
0xB2, 0x92, 0xD2, 0xD2, 0xD2, 0xF2, 0x113, 0x134, 0x154, 
0x175, 0x9B5, 0x195, 0x32F8, 0x963F, 0xA65D, 0xADF7, 0xADB4, 0x6309, 
0x800, 0x2923, 0x820, 0x820, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x1, 0x821, 0x0, 
0x18C2, 0x20, 0x3A26, 0xB615, 0xCF1A, 0xBEDA, 0xAE9C, 0x7D5D, 0x1A75, 
0x973, 0x1195, 0x154, 0x113, 0x113, 0xF3, 0xD2, 0xB2, 0xB2, 
0x71, 0x51, 0x91, 0x71, 0x51, 0x51, 0x51, 0x30, 0x30, 
0x10, 0x10, 0x10, 0xF, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x2F, 0xF, 0xE, 0xE, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x30, 0x30, 0x851, 0x50, 0x51, 0x51, 0x71, 0x30, 0x51, 
0x71, 0x71, 0x51, 0x71, 0x72, 0x72, 0x92, 0x92, 0x92, 
0x92, 0xB2, 0x92, 0x92, 0xB2, 0xB2, 0xD2, 0xF3, 0xD3, 
0xF3, 0x113, 0x113, 0x134, 0x155, 0x174, 0x11D5, 0x9D5, 0x1A97, 
0x443B, 0x4C38, 0x6CD6, 0xA618, 0x844F, 0x5AA9, 0x1061, 0x0, 0x841, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x801, 0x0, 0x0, 0x820, 0x0, 0x2103, 0x4A27, 
0xA553, 0xB658, 0xB6BD, 0x4BF8, 0x9F4, 0x11F5, 0x974, 0x954, 0x134, 
0x113, 0xF3, 0xF2, 0xD2, 0xB2, 0x8D2, 0x8D2, 0x71, 0x92, 
0x71, 0x71, 0x51, 0x51, 0x30, 0x30, 0x30, 0x30, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0xF, 0x10, 0x30, 0xF, 
0xF, 0xF, 0x2F, 0x2F, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0xF, 0x10, 0x30, 0x50, 0x30, 0x70, 0x71, 
0x50, 0x51, 0x892, 0x72, 0x92, 0xB2, 0xB2, 0xB2, 0x92, 
0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xD3, 0xD2, 
0xD3, 0xD2, 0xF3, 0xF3, 0xF4, 0xF4, 0x914, 0x934, 0x155, 
0x975, 0x975, 0x995, 0x1217, 0x1237, 0xA35, 0x1AD5, 0x4C15, 0x95B8, 
0xDF3B, 0xA4F1, 0x0, 0x841, 0x841, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x1, 0x1, 0x0, 0x801, 
0x821, 0x1082, 0x0, 0x3185, 0x736C, 0x9CD2, 0x9556, 0x74D8, 0x4C1A, 
0x1D4, 0x9D5, 0x995, 0x954, 0x134, 0x133, 0x113, 0xF3, 0xF3, 
0xD3, 0xB2, 0x92, 0xB2, 0xB2, 0x92, 0x71, 0x71, 0x51, 
0x51, 0x31, 0x50, 0x30, 0x30, 0x30, 0x30, 0x10, 0x10, 
0x10, 0x10, 0xF, 0xF, 0x30, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 
0x50, 0x51, 0x891, 0x71, 0x71, 0x92, 0xB2, 0x91, 0x92, 
0xB2, 0x8F2, 0x8D2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB3, 
0xB3, 0xB3, 0xB3, 0xD3, 0xF3, 0xD3, 0xF3, 0xF3, 0xF4, 
0x114, 0x114, 0x934, 0x974, 0x975, 0x975, 0x11B5, 0x9B6, 0x11F7, 
0x1238, 0x22B9, 0x22B5, 0x6C97, 0xA5F8, 0xC656, 0x944E, 0x800, 0x1041, 
0x841, 0x0, 0x820, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x821, 0x1, 0x1082, 0x800, 0x62EA, 
0xD6D8, 0xBE9A, 0x6457, 0x1293, 0xA75, 0x1297, 0x9D6, 0x976, 0x975, 
0x955, 0x134, 0x113, 0x113, 0x113, 0xF3, 0xD3, 0xD3, 0xD2, 
0xB2, 0x92, 0x92, 0x92, 0x71, 0x71, 0x71, 0x51, 0x50, 
0x50, 0x50, 0x30, 0x30, 0x30, 0x30, 0x30, 0x51, 0x30, 
0x30, 0x30, 0x71, 0x71, 0x2F, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x30, 0x51, 0x71, 0x51, 0x8B2, 0x92, 
0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xF2, 0xB1, 0xF2, 0x933, 
0xF2, 0xD2, 0xF3, 0xD2, 0xD2, 0xD3, 0xD3, 0xF3, 0xD3, 
0xF3, 0xF4, 0x914, 0x934, 0x914, 0x134, 0x955, 0x975, 0x975, 
0x975, 0x9B5, 0x11D5, 0x11D6, 0x1217, 0x1238, 0x1A99, 0x1A76, 0x6CF9, 
0xAE7B, 0x9D32, 0x6B09, 0x3164, 0x820, 0x821, 0x821, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x820, 
0x21, 0x0, 0x1082, 0x800, 0x41E6, 0xAD94, 0xB67A, 0x7D7D, 0x1AF7, 
0x12B7, 0xA36, 0x11F7, 0x996, 0x976, 0x975, 0x154, 0x134, 0x134, 
0x113, 0x113, 0x113, 0x8F3, 0xF3, 0xD3, 0xB2, 0xB2, 0x92, 
0x92, 0x92, 0x71, 0x71, 0x71, 0x70, 0x70, 0x50, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x30, 0x71, 0x71, 0x50, 0x50, 
0x50, 0x70, 0x30, 0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x31, 0x51, 
0x72, 0x71, 0x8D3, 0x92, 0x51, 0xB2, 0xF3, 0xF3, 0xF3, 
0x913, 0xD1, 0x3AD8, 0x3277, 0x90, 0x112, 0x933, 0xF2, 0x113, 
0xF3, 0xF3, 0xF3, 0xF3, 0x114, 0x113, 0x934, 0x934, 0x1174, 
0x974, 0x975, 0x996, 0x997, 0x176, 0x195, 0x9F6, 0x9F6, 0x11F6, 
0x1A37, 0x1A78, 0x1A98, 0x22F8, 0x441A, 0x64D8, 0x9DB7, 0xC656, 0x634B, 
0x20, 0x18C3, 0x0, 0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1082, 0x0, 0x3984, 
0x840E, 0x8CF2, 0x9E1A, 0x4C38, 0x12B6, 0x12B8, 0x1278, 0x11F6, 0x11D6, 
0x995, 0x9B5, 0x174, 0x995, 0x154, 0x154, 0x955, 0xF3, 0xB2, 
0x914, 0xF3, 0xD3, 0xB2, 0xB2, 0xB2, 0x92, 0x92, 0x91, 
0x91, 0x91, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x51, 
0x8B2, 0x71, 0x71, 0x21B5, 0x29D6, 0x8D2, 0x8B1, 0x50, 0x30, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x30, 0x30, 0x51, 0x92, 0x91, 0x70, 0x6F, 0x19B4, 
0x21F6, 0x934, 0x113, 0xF2, 0x113, 0x974, 0x11D3, 0x647C, 0x7D1F, 
0x32B6, 0x1A15, 0x153, 0x933, 0x113, 0x134, 0x113, 0x113, 0x113, 
0x134, 0x154, 0x954, 0x953, 0x952, 0x11D4, 0x11D5, 0x995, 0x996, 
0x9F7, 0x1217, 0x9F6, 0x1237, 0x1257, 0x1A57, 0x1A98, 0x1AD9, 0x233A, 
0x2B9A, 0x3397, 0x8558, 0x9D96, 0x742E, 0x29A4, 0x0, 0x1042, 0x1, 
0x821, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x820, 0x0, 0x1081, 0x0, 0x5267, 0xB5D5, 0x9DF8, 0x5415, 0x3376, 
0x2338, 0x1AD8, 0x1257, 0x1237, 0x1216, 0x11F6, 0x9B5, 0x9B6, 0x155, 
0x995, 0x995, 0x154, 0x1A16, 0x2215, 0x90, 0x934, 0xF4, 0xD3, 
0xD3, 0xB2, 0xB2, 0xB2, 0xB2, 0x91, 0x91, 0x91, 0x91, 
0x71, 0x71, 0x92, 0x92, 0x92, 0x91, 0xD2, 0xB2, 0x21D5, 
0x63DD, 0x4B1A, 0x4F, 0x50, 0x30, 0x30, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x11, 0x50, 0x30, 0x892, 
0x70, 0x2256, 0x4BBA, 0x3316, 0x6CBD, 0x439B, 0x153, 0x11D5, 0x11F5, 
0x11F6, 0x9B4, 0x2295, 0x85BF, 0xA6DF, 0x85DF, 0x4399, 0x132, 0x1196, 
0x135, 0x154, 0x174, 0x133, 0x954, 0x175, 0x154, 0x11B4, 0x3AB8, 
0x32D6, 0x9B1, 0x1A12, 0x3B58, 0x2297, 0x1236, 0x1237, 0x1257, 0xA57, 
0x1298, 0x1A98, 0x22D9, 0x1AF9, 0x2B7A, 0x33DB, 0x3C1A, 0x64DA, 0x95FB, 
0xA5F6, 0x6329, 0x800, 0x2082, 0x1062, 0x0, 0x20, 0x20, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x18C2, 0x800, 0x2923, 
0x8CD2, 0xA618, 0x7539, 0x3BF7, 0x2BB9, 0x2359, 0x22F8, 0x1AB8, 0x1A98, 
0xA16, 0xA16, 0x1237, 0x9D7, 0x9B7, 0x11B6, 0x1216, 0x194, 0x2AF8, 
0x8DDF, 0x5C3A, 0x933, 0x936, 0x915, 0xD3, 0xD2, 0xF2, 0xD2, 
0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x72, 0x92, 0x8B2, 0x92, 
0xB2, 0xD3, 0xD2, 0x954, 0xD2, 0x4BBC, 0x645C, 0x950, 0x2A15, 
0x8B2, 0x50, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x11, 0x10, 0x50, 0x71, 0x92, 0x91, 0x11D4, 0x4BDA, 0x963F, 
0x8E1F, 0x2B16, 0x9D2, 0x9D2, 0x64DE, 0x5C9E, 0x1253, 0x2AF2, 0x7D7B, 
0xA6DF, 0x5478, 0x1234, 0x1216, 0x975, 0x976, 0x195, 0x174, 0x974, 
0x974, 0x195, 0x9D5, 0x993, 0x855F, 0x9DDE, 0x7477, 0x74D8, 0x9E1F, 
0x53F9, 0x1214, 0x1A97, 0x22B8, 0x2AF7, 0x2AF6, 0x2B17, 0x2B38, 0x3399, 
0x2337, 0x3378, 0x443A, 0x4C7A, 0x7539, 0xA617, 0x9532, 0x5289, 0x800, 
0x820, 0x10A2, 0x861, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x10A2, 0x18C2, 0x800, 0x800, 0x7BCE, 0xA5F7, 0x8598, 0x54B8, 0x3C39, 
0x33F9, 0x2357, 0x1AF6, 0x2B17, 0x22B6, 0x3B79, 0x3B78, 0x9D2, 0x1237, 
0x1218, 0x1217, 0x1236, 0x1B2, 0x1A72, 0x9E7D, 0x8DBB, 0x971, 0xD2, 
0x934, 0x955, 0xF3, 0xF3, 0xB2, 0xD2, 0xD2, 0xD2, 0xB2, 
0xB2, 0xB3, 0x92, 0xB3, 0xB2, 0xB2, 0xD2, 0x114, 0x134, 
0x194, 0x9F4, 0x649C, 0x6CFD, 0x42F9, 0x2F, 0x91, 0x50, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 0x51, 0x71, 
0x91, 0x1134, 0x30, 0x3AB8, 0x6CBD, 0x85BF, 0x963F, 0x64D9, 0x1A91, 
0x7D9D, 0x965F, 0x43B3, 0xA67B, 0xAE9C, 0x9E5E, 0x43B7, 0x1235, 0x1216, 
0xA17, 0x9F7, 0x195, 0x9B6, 0x9B6, 0x9B5, 0x9D5, 0x1236, 0x9F3, 
0x5C58, 0xAE38, 0xBE56, 0xADB6, 0xA5F9, 0x7519, 0x3335, 0x2317, 0x22D5, 
0x7519, 0x8D99, 0x7D3A, 0x5C37, 0x43B6, 0x64DA, 0x64D9, 0x5C98, 0x6D3A, 
0x7DBA, 0x9E39, 0xC71B, 0xBE59, 0x6B6D, 0x20, 0x20, 0x0, 0x0, 
0x821, 0x0, 0x0, 0x821, 0x0, 0x0, 0x800, 0x2964, 0x94D0, 
0xC6B9, 0xAE7B, 0x7D79, 0x64F9, 0x5CFA, 0x4C37, 0x64BA, 0x545A, 0x3335, 
0x3B95, 0x7D9B, 0x95FC, 0x6478, 0x2275, 0x1A98, 0x1A98, 0x22B7, 0x74FB, 
0x8538, 0x9596, 0x9E19, 0x6CB7, 0x649B, 0x2276, 0x113, 0x955, 0x114, 
0x114, 0xD3, 0xF4, 0xD3, 0xF2, 0xF2, 0xB2, 0xB2, 0x8D3, 
0xD2, 0xF2, 0x913, 0x113, 0x974, 0x1215, 0x1A95, 0x6D5E, 0x7DBF, 
0x4339, 0x91, 0x8B2, 0x30, 0x30, 0x10, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x2F, 
0x30, 0x30, 0x50, 0x71, 0x92, 0x91, 0xD2, 0x8F3, 0x2A16, 
0x993, 0x4377, 0x8E1E, 0xB73F, 0x8DDB, 0x8DDA, 0xA6BC, 0x95F8, 0xB6FB, 
0xA69B, 0x6CF9, 0x2AF5, 0x22B6, 0x1A97, 0x1F4, 0x1F5, 0x1216, 0x9B6, 
0x9D7, 0x11F7, 0x1236, 0x1235, 0x2B15, 0x6CB6, 0xB635, 0x7C0A, 0x8C8E, 
0xADD5, 0x9578, 0x6497, 0x2B56, 0x5458, 0x9576, 0x6C0F, 0x84D3, 0x9578, 
0x74F7, 0x74F6, 0x8537, 0x95B9, 0x7D57, 0x9E1A, 0xAE5A, 0xC6DB, 0xE79E, 
0xEF9D, 0xBE15, 0x7BED, 0x39C6, 0x1082, 0x821, 0x841, 0x841, 0x0, 
0x20C3, 0x5A8A, 0x9CD1, 0xD6B9, 0xF7DD, 0xD73B, 0xB67B, 0x9DFB, 0x95FB, 
0x7D18, 0x8D7A, 0x8559, 0x74B9, 0x6477, 0x74F7, 0x95D8, 0x7471, 0x9598, 
0x5C39, 0x22B6, 0x1AF7, 0x3356, 0xA61C, 0xAE19, 0xADD6, 0xA5D5, 0xAE9A, 
0x857A, 0x1232, 0x173, 0x975, 0x114, 0xF4, 0x934, 0xF4, 0xF3, 
0xF2, 0xF2, 0xF3, 0xF3, 0xF3, 0x913, 0x933, 0x113, 0x975, 
0x9B5, 0x1D2, 0x7DBF, 0x759E, 0xA31, 0x2235, 0x913, 0x71, 0x72, 
0x51, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x30, 0x30, 0x30, 0x30, 0x31, 0x51, 
0xB2, 0xD3, 0xD2, 0x933, 0x112, 0x9B5, 0x1A76, 0x3398, 0x6D1A, 
0xB6BB, 0xC6F9, 0xC6B8, 0xC6FA, 0xA69B, 0x5CD7, 0x3BD6, 0x3BB8, 0x2B36, 
0x1273, 0x3B97, 0x2AF6, 0x1A57, 0x1218, 0x1218, 0x1238, 0xA37, 0x1A95, 
0x7D7C, 0xA63B, 0xAD94, 0xA531, 0x842D, 0xC697, 0xBEBA, 0x74F6, 0x5456, 
0x7D5A, 0xA596, 0x7BCD, 0x7C0E, 0xBE57, 0xC6B9, 0x5B4C, 0x8CB1, 0xBE17, 
0x6B8D, 0x9D13, 0x73EF, 0x7C10, 0x6B8E, 0x840F, 0x948F, 0x842E, 0x5269, 
0x20E4, 0x862, 0x41, 0x841, 0x841, 0x3165, 0x736D, 0x9450, 0x8C2F, 
0x7BCE, 0x7BEF, 0x7C11, 0x8452, 0xA536, 0x6B6E, 0xCE7A, 0x94D3, 0x5B4E, 
0xADD8, 0xA5D7, 0xA575, 0x73AD, 0x9D35, 0x855A, 0x43F7, 0x2B75, 0x5437, 
0x84F6, 0xC67A, 0xD677, 0x8C4E, 0xADF5, 0x8D57, 0x2272, 0x1A35, 0x975, 
0x996, 0x154, 0x133, 0x134, 0x113, 0x974, 0x975, 0x134, 0x134, 
0x954, 0x133, 0x155, 0x996, 0x1B5, 0x9D4, 0x5C7B, 0x8DFE, 0x85DC, 
0x43B6, 0x111, 0x934, 0xB2, 0xB2, 0x31, 0x10, 0x30, 0xE, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x30, 0x50, 0x30, 0x872, 0x71, 0x92, 0xD2, 0x113, 0x113, 
0x11B5, 0x9D4, 0x1234, 0x2315, 0x5477, 0xA618, 0xC6B7, 0xB5F3, 0xD718, 
0xA679, 0x7579, 0x651A, 0x3BB6, 0x64B9, 0x859B, 0xA65E, 0x6C98, 0x191, 
0x22B8, 0x1237, 0x1A78, 0x1AD8, 0x22D6, 0x6D1A, 0x95D9, 0xCE99, 0xC5F5, 
0x20E1, 0x844F, 0x9D54, 0x8514, 0x8D99, 0xAE7B, 0xBDF7, 0x5267, 0x2943, 
0xB5D5, 0xBE16, 0x5AEA, 0x4206, 0x83ED, 0x3943, 0x41A5, 0x1061, 0x0, 
0x0, 0x0, 0x820, 0x0, 0x0, 0x1, 0x41, 0x0, 0x21, 
0x841, 0x0, 0x0, 0x800, 0x0, 0x0, 0x800, 0x0, 0x2945, 
0x41E8, 0x4A08, 0x9450, 0x5268, 0x630B, 0xCE78, 0xBE18, 0x5ACA, 0x4A06, 
0xA534, 0xA61B, 0x6496, 0x6CF7, 0x7D37, 0xA5B8, 0xC617, 0x7B8C, 0xAD32, 
0xBE36, 0xAE3A, 0x859E, 0x9B3, 0x9B5, 0x9B5, 0x995, 0x175, 0x974, 
0x974, 0x133, 0xF2, 0x995, 0x9B5, 0x153, 0x9B5, 0x195, 0x196, 
0x1B5, 0x1A76, 0x6D1D, 0x85BD, 0x8DFC, 0x5417, 0x132, 0x935, 0xF3, 
0x92, 0x71, 0x30, 0xF, 0x830, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x30, 0x30, 0x30, 0x30, 0x51, 0x71, 0x51, 
0x71, 0x92, 0xD3, 0xD3, 0x914, 0xF2, 0x3B57, 0x4C17, 0x6496, 
0xBF1D, 0xAE7A, 0xC6FA, 0xCE96, 0x9D0F, 0xCEB7, 0xCEFA, 0x9DF9, 0x8537, 
0x8D78, 0xAE19, 0xADB6, 0xA598, 0x7D1A, 0x3377, 0x1A96, 0x1AD8, 0x1AF8, 
0x2337, 0x33B6, 0x7539, 0xADB6, 0x9CB0, 0x3985, 0x0, 0x2944, 0xADB5, 
0xBE79, 0x9513, 0xB5D6, 0x5289, 0x0, 0x632C, 0x2965, 0x2124, 0x0, 
0x800, 0x800, 0x820, 0x0, 0x862, 0x18C4, 0x10A3, 0x20C3, 0x18A2, 
0x841, 0x1, 0x0, 0x20, 0x800, 0x800, 0x820, 0x10A1, 0x18C2, 
0x18C2, 0x20E3, 0x1061, 0x20, 0x0, 0x21, 0x0, 0x800, 0x800, 
0x3164, 0x4228, 0x8430, 0x2104, 0x800, 0xB595, 0xB639, 0x7CB4, 0xAE39, 
0x8CF4, 0x6B8D, 0x6B2A, 0x20, 0x9D53, 0xBE9A, 0x8579, 0x545B, 0xA55, 
0xA15, 0x9F6, 0x9B6, 0x995, 0x9B6, 0x994, 0x2255, 0x2A96, 0x9B3, 
0x9F4, 0x9F5, 0x1D4, 0x9F5, 0x1216, 0x1A17, 0x2257, 0x1A55, 0x4C3A, 
0x9EBF, 0x5478, 0x152, 0x11B6, 0x953, 0xF2, 0x8D2, 0x71, 0x31, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 
0x30, 0x50, 0x51, 0x51, 0x71, 0x92, 0x92, 0xB2, 0x8F4, 
0x914, 0x132, 0x64BB, 0xA6DF, 0xA69D, 0xAEBD, 0x961B, 0x9597, 0xCEB7, 
0xAD71, 0xA4EF, 0x9CF1, 0xB616, 0xCEDA, 0xBE38, 0xD6DA, 0xAD12, 0xBE17, 
0xA63B, 0x4C16, 0x2B16, 0x2B58, 0x2B57, 0x4418, 0x4417, 0x7D59, 0x8CB2, 
0x4A27, 0x800, 0x800, 0x0, 0xAD94, 0xAD74, 0x31A5, 0x62EB, 0x41E7, 
0x0, 0x0, 0x0, 0x0, 0x1061, 0x1882, 0x1041, 0x1061, 0x841, 
0x41, 0x0, 0x0, 0x800, 0x0, 0x1, 0x20, 0x0, 0x800, 
0x0, 0x800, 0x0, 0x0, 0x0, 0x20, 0x0, 0x820, 0x841, 
0x882, 0x10A3, 0x862, 0x1082, 0x1041, 0x800, 0x0, 0x0, 0x0, 
0x41E8, 0x9CD2, 0x7410, 0x8CB2, 0xDF1B, 0x842F, 0x800, 0x800, 0x2943, 
0x9D34, 0x95B8, 0x5C56, 0x1AB4, 0x1AD7, 0x1276, 0x1236, 0x9F6, 0x11D7, 
0x1217, 0x9B4, 0x5C3C, 0xA69F, 0x6479, 0x753C, 0x64DC, 0x22D6, 0x22B7, 
0x1236, 0x2277, 0x2AB8, 0x1AB7, 0x7DBF, 0x9EBF, 0x3B95, 0x9F3, 0x173, 
0x111, 0x42F9, 0x3236, 0x2F, 0x851, 0x10, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0xF, 0x10, 0x30, 0x30, 0x50, 0x51, 0x51, 0x71, 
0x71, 0xB2, 0xB2, 0xD3, 0x914, 0xD3, 0x2A77, 0x855E, 0x9E5F, 
0x8E1F, 0x759D, 0x4C58, 0x6CF7, 0xC6B8, 0xC614, 0x2102, 0x0, 0x94B0, 
0xC635, 0x9CF1, 0xB594, 0x7B8C, 0xB5F7, 0x9DB9, 0x53F5, 0x3BB8, 0x3BB8, 
0x6CD9, 0x8539, 0x8538, 0x9598, 0xCEDA, 0x94D1, 0x18A2, 0x820, 0x2985, 
0x632B, 0x2944, 0x20, 0x0, 0x800, 0x840, 0x1081, 0x1082, 0x841, 
0x1, 0x1, 0x0, 0x0, 0x1, 0x1, 0x20, 0x20, 0x820, 
0x20, 0x20, 0x21, 0x20, 0x20, 0x1, 0x1, 0x1, 0x20, 
0x821, 0x20, 0x0, 0x0, 0x0, 0x20, 0x20, 0x20, 0x20, 
0x840, 0x861, 0x861, 0x841, 0x21, 0x0, 0x0, 0x10A3, 0x528A, 
0xB595, 0x8C30, 0x800, 0x20A2, 0x800, 0x52AB, 0x8CF5, 0x6C97, 0x2B35, 
0x22F7, 0x1A96, 0x1257, 0xA17, 0x1238, 0x1258, 0x1257, 0x2B79, 0x8E5F, 
0xAEBC, 0xB69B, 0xAEBE, 0x85BD, 0x2316, 0xA75, 0x1A76, 0x22F7, 0x3398, 
0x863F, 0xA6DF, 0x3B93, 0x43D6, 0x6D3D, 0x5C3B, 0x74DE, 0x3AB7, 0x4F, 
0x71, 0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xD, 
0x2D, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 
0x30, 0x50, 0x51, 0x51, 0x71, 0x91, 0xB2, 0xB2, 0xB3, 
0x914, 0x113, 0x11D4, 0x2254, 0x3B77, 0x1AB5, 0x2B77, 0x33B8, 0x6D39, 
0xB678, 0x94CF, 0x18C2, 0x820, 0x41E5, 0x4A25, 0x3984, 0x3163, 0x39A5, 
0xBE17, 0x9536, 0x7D18, 0x4C58, 0x64DA, 0x8537, 0x530D, 0x9515, 0xBE5A, 
0xAD95, 0xBE37, 0x632C, 0x0, 0x10A1, 0x0, 0x20, 0x820, 0x1882, 
0x1041, 0x820, 0x820, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 
0x1, 0x1, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 0x20, 
0x0, 0x1, 0x1, 0x1, 0x1, 0x21, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x0, 0x0, 0x0, 0x20, 0x20, 0x840, 0x21, 
0x21, 0x821, 0x841, 0x20, 0x0, 0x820, 0x5249, 0x18A2, 0x1061, 
0x5248, 0xAD55, 0xBE5B, 0x6C95, 0x5C36, 0x7D5D, 0x5C3B, 0x1A55, 0x1AB8, 
0x1278, 0x1297, 0x1AB6, 0x2315, 0x5414, 0xA5F6, 0xBE96, 0xBEFB, 0x74F6, 
0x3B74, 0x6D3D, 0x64BA, 0x4BF6, 0x3353, 0x6D38, 0xA6BD, 0x8E1B, 0x967F, 
0x8E1F, 0x751E, 0x53DB, 0x19B4, 0x70, 0x70, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x30, 0x30, 0x10, 0x30, 0x50, 0x51, 0x51, 0x71, 
0x91, 0x92, 0xB2, 0xD3, 0xD3, 0xF4, 0x154, 0x153, 0x193, 
0x1D4, 0x1AB8, 0x22F8, 0x3377, 0x5457, 0xA617, 0xD6F9, 0x8C4F, 0x1881, 
0x0, 0x20, 0x0, 0x0, 0x2123, 0x634B, 0x94F4, 0xA5D9, 0x6CF8, 
0x85DB, 0xAE38, 0x6B8C, 0x52A9, 0xA534, 0x4A49, 0x18C3, 0x18C3, 0x841, 
0x0, 0x1082, 0x882, 0x0, 0x800, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x820, 0x820, 0x820, 
0x18A2, 0x0, 0x0, 0x0, 0x20C2, 0x94B1, 0xC658, 0x9534, 0x9D96, 
0xB618, 0x8CF5, 0x7CD8, 0x5418, 0x1A97, 0x2319, 0x2B17, 0x4C17, 0x7CF8, 
0xA5B7, 0xAD52, 0x9CF0, 0xC6D8, 0xA617, 0x7D16, 0xA65B, 0xCF3D, 0xAE38, 
0x95D7, 0xA679, 0xB71B, 0xB73D, 0x64D8, 0x1A93, 0x9B3, 0xB2, 0xB3, 
0x92, 0x70, 0x2F, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x30, 
0x50, 0x51, 0x51, 0x71, 0x71, 0x92, 0x92, 0xB2, 0xD3, 
0xF3, 0xD4, 0x954, 0x154, 0x9D5, 0x1257, 0xA17, 0x2AF8, 0x7D9D, 
0x8DB9, 0xAE38, 0xB5F6, 0x83CD, 0x800, 0x18A2, 0x10A2, 0x862, 0x1081, 
0x20, 0x20, 0x7C10, 0xB619, 0xAE7B, 0x74D4, 0xADF5, 0x9CF1, 0x0, 
0x2944, 0x18C3, 0x0, 0x821, 0x0, 0x821, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x861, 0x10A2, 0x0, 
0x861, 0x1082, 0x4228, 0x5B2C, 0xBE57, 0x94B0, 0x52A9, 0x84F5, 0x74F9, 
0x2B37, 0x2338, 0x5C99, 0x9E1C, 0xADF9, 0xD6B9, 0x940E, 0x28E1, 0xAD93, 
0xADF5, 0xBE99, 0xBE98, 0xAD93, 0xC696, 0xB656, 0xB698, 0xA69A, 0x9EBD, 
0x8E1D, 0x3376, 0x152, 0x934, 0xD4, 0x72, 0x50, 0x2F, 0xE, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x30, 0x30, 0x30, 0x30, 0x50, 0x51, 0x71, 0x71, 
0x71, 0x92, 0x92, 0xD2, 0xD2, 0xF3, 0xF3, 0x914, 0x1174, 
0x9D4, 0xA36, 0xA36, 0x2295, 0x95B9, 0xB677, 0xDF3A, 0xB5D5, 0x1060, 
0x800, 0x1882, 0x801, 0x0, 0x0, 0x10C2, 0x20, 0x5289, 0xD6B9, 
0xD6FB, 0x8471, 0x4AA9, 0x4A47, 0x18A2, 0x800, 0x0, 0x10A2, 0x840, 
0x0, 0x800, 0x0, 0x0, 0x0, 0x20, 0x20, 0x20, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x800, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 0x0, 0x0, 0x0, 
0x1, 0x821, 0x0, 0x20, 0x20, 0x0, 0x1, 0x1, 0x1903, 
0x6BAD, 0x840, 0x6B4C, 0xBE79, 0x8558, 0x4C38, 0x43D8, 0x64B7, 0xA5F9, 
0x94D2, 0x83CD, 0x5227, 0x800, 0x2124, 0x1903, 0x9D12, 0x8C8F, 0x0, 
0x4227, 0xADD5, 0xAE99, 0x5CB7, 0x54B9, 0x9EFF, 0x757D, 0x2AB6, 0x2A57, 
0xB2, 0x8B2, 0x30, 0x2F, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x30, 0x50, 0x50, 
0x50, 0x51, 0x71, 0x71, 0x71, 0x91, 0x92, 0xB2, 0x8D2, 
0xD2, 0x113, 0x113, 0x914, 0x954, 0x9B4, 0x1216, 0x1F5, 0x4BD9, 
0xAE39, 0xA572, 0x9D11, 0x630A, 0x20C2, 0x820, 0x1021, 0x0, 0x801, 
0x801, 0x1082, 0x0, 0x73AD, 0xDEFA, 0x7BEE, 0x4A47, 0x0, 0x0, 
0x0, 0x1082, 0x821, 0x0, 0x20, 0x0, 0x0, 0x0, 0x20, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x20, 0x20, 
0x821, 0x1, 0x1063, 0x10A4, 0x20, 0x0, 0x0, 0x8C71, 0xBE37, 
0x6C52, 0x7539, 0x6CD8, 0x8D77, 0xA596, 0x6B4B, 0x800, 0x800, 0x1062, 
0x0, 0x0, 0x820, 0x3984, 0x820, 0x860, 0xBE57, 0xAE7B, 0x5499, 
0x12D5, 0x4C59, 0x963F, 0x855F, 0x2235, 0x2F, 0x92, 0x50, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x30, 0x30, 0x50, 0x50, 0x50, 0x50, 0x71, 0x71, 0x91, 
0x91, 0xB2, 0xB2, 0xD2, 0xF3, 0xF3, 0x113, 0x134, 0x954, 
0x155, 0x995, 0x1216, 0x9F6, 0x64BC, 0xA61B, 0xBE57, 0x9D32, 0x738B, 
0x3984, 0x800, 0x1061, 0x0, 0x820, 0x1061, 0x821, 0x0, 0x9491, 
0x840F, 0x20, 0x0, 0x861, 0x10A2, 0x821, 0x0, 0x1, 0x20, 
0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 0x1, 
0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x0, 0x0, 0x0, 0x800, 0x800, 0x1, 0x1, 
0x842, 0x1082, 0x861, 0x20E3, 0x41E6, 0x7C0F, 0x9DF8, 0x95D8, 0xB617, 
0x7BEE, 0x20, 0x18A2, 0x1062, 0x821, 0x1062, 0x10A2, 0x800, 0x0, 
0x62E9, 0x94D1, 0xBE7A, 0xA65D, 0x43D9, 0x1AB6, 0x1235, 0x32D8, 0x3297, 
0xD1, 0xB2, 0x8B2, 0x31, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x30, 0x30, 0x30, 0x50, 0x50, 0x71, 
0x70, 0x51, 0x71, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xD2, 
0xF3, 0x114, 0x134, 0x154, 0x975, 0x995, 0x9B6, 0x11F6, 0x1A78, 
0x1254, 0x6477, 0x9DF9, 0xB638, 0xC677, 0x6B4B, 0x0, 0x1903, 0x10C2, 
0x20, 0x0, 0x0, 0x3145, 0x4A48, 0x820, 0x0, 0x18C3, 0x841, 
0x0, 0x0, 0x821, 0x21, 0x20, 0x20, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x800, 0x800, 0x1, 0x821, 0x1, 0x21, 0x841, 0x800, 
0x800, 0x52A9, 0x6BEF, 0xBE99, 0xCEB8, 0x5288, 0x0, 0x1083, 0x0, 
0x1, 0x21, 0x0, 0x18C3, 0x0, 0x738B, 0xD6D9, 0xA5F9, 0x4BB4, 
0x1A53, 0x1256, 0x11F6, 0x113, 0x70, 0x8F3, 0xB2, 0x51, 0x31, 
0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 
0x11, 0x31, 0x50, 0x50, 0x70, 0x50, 0x71, 0x71, 0x72, 
0xB2, 0x92, 0xB2, 0xD3, 0xD4, 0xF4, 0x114, 0x154, 0x174, 
0x975, 0x996, 0x11F7, 0x1217, 0x1258, 0x1A97, 0x2B57, 0x43F6, 0x7537, 
0x8514, 0x8491, 0x4A68, 0x0, 0x20, 0x20, 0x861, 0x861, 0x841, 
0x0, 0x841, 0x842, 0x21, 0x0, 0x0, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x21, 0x0, 0x1061, 0x18A2, 0x20, 0x20, 0x8450, 
0xDEF9, 0x5288, 0x800, 0x18C3, 0x0, 0x841, 0x0, 0x20, 0x1082, 
0x0, 0x39A4, 0xB5B6, 0x8557, 0x4C15, 0x3B96, 0x1A74, 0x11D5, 0x975, 
0x914, 0xB2, 0x92, 0x71, 0x51, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x31, 0x31, 0x31, 0x51, 0x50, 
0x50, 0x71, 0x72, 0x71, 0x92, 0xB2, 0xB2, 0xD3, 0xD4, 
0x114, 0x114, 0x154, 0x974, 0x11B5, 0x975, 0x11D6, 0x9F6, 0x1237, 
0x1A78, 0x22D9, 0x2B58, 0x33D7, 0x5477, 0x8DB9, 0xB618, 0x9D33, 0x8C71, 
0x7BEF, 0x6B6D, 0x18E3, 0x0, 0x821, 0x1062, 0x841, 0x821, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x20, 0x1062, 0x0, 0x20, 0x9CD2, 0x840E, 0x0, 0x18C3, 
0x0, 0x0, 0x841, 0x0, 0x18C3, 0x0, 0x5268, 0xC637, 0xA63A, 
0x9E9E, 0x8DFF, 0x5C5B, 0x973, 0x934, 0xF4, 0xB3, 0x92, 0x71, 
0x50, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x2F, 0x30, 0x30, 
0x31, 0x31, 0x51, 0x51, 0x51, 0x71, 0x892, 0x71, 0x92, 
0xD2, 0xD2, 0xF2, 0xF3, 0x113, 0xF3, 0x174, 0x174, 0x152, 
0x173, 0x994, 0x1216, 0x1237, 0x1298, 0x1278, 0x22F9, 0x2B36, 0x3BB7, 
0x4C59, 0x7519, 0xAE19, 0xD6FA, 0xDF1B, 0xA513, 0x5269, 0x820, 0x820, 
0x20, 0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x821, 0x861, 
0x0, 0x1082, 0x528A, 0x1062, 0x0, 0x1082, 0x861, 0x0, 0x1062, 
0x1042, 0x20A3, 0x800, 0x7C0E, 0xC6B9, 0xB6BB, 0x8D9C, 0x3B57, 0x153, 
0x114, 0xF4, 0xB3, 0x92, 0x71, 0x31, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0xF, 0x10, 0x10, 
0x10, 0x30, 0x30, 0x50, 0x30, 0x50, 0x51, 0x51, 0x51, 
0x71, 0x72, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0x113, 0x113, 
0x1175, 0x154, 0x194, 0x1235, 0x4B99, 0x3AF6, 0x32F7, 0x1A76, 0x1276, 
0x1AD8, 0x2318, 0x2B36, 0x6498, 0x7539, 0x753B, 0x7D19, 0xA5B7, 0xAD75, 
0x630B, 0x820, 0x0, 0x820, 0x841, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x20, 0x1062, 0x0, 0x1, 0x1083, 
0x0, 0x0, 0x1081, 0x18C3, 0x18A3, 0x800, 0x41A7, 0xB595, 0x9D34, 
0xAE18, 0xB6BD, 0x5C18, 0x151, 0x153, 0x114, 0xD3, 0xB2, 0x92, 
0x71, 0x31, 0x30, 0x10, 0xF, 0xF, 0xE, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x30, 0x30, 0x30, 0x50, 0x50, 
0x50, 0x50, 0x51, 0x71, 0x71, 0x71, 0x71, 0x92, 0x92, 
0x8D3, 0xD3, 0xF3, 0x934, 0x955, 0x114, 0x11B5, 0x172, 0x1212, 
0x95DD, 0xAE9F, 0x7DBE, 0x2B77, 0x2319, 0x22F8, 0x3BB7, 0x755A, 0x7CD4, 
0x9554, 0xBE7B, 0x8CD4, 0x5AEC, 0x6B4C, 0x820, 0x0, 0x10A2, 0x20, 
0x0, 0x0, 0x800, 0x800, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x0, 0x20, 0x0, 0x0, 0x821, 
0x0, 0x0, 0x1081, 0x841, 0x1, 0x1883, 0x2124, 0x0, 0x800, 
0x800, 0x41E7, 0x7BEF, 0xBE59, 0x9DD9, 0x5C77, 0x547A, 0x9F4, 0x11D6, 
0x133, 0x113, 0xD2, 0x92, 0x92, 0x71, 0x51, 0x31, 0x10, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 0x30, 
0x31, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x71, 0x71, 
0x91, 0x91, 0x92, 0x8D3, 0xB3, 0x92, 0xD3, 0x934, 0x133, 
0xD1, 0x2277, 0x11D3, 0x3315, 0x4BD4, 0x9D98, 0xB6BC, 0x755A, 0x2355, 
0x2337, 0x3377, 0x4C37, 0x8DDA, 0x530B, 0x73AC, 0xAD74, 0xC617, 0x4A48, 
0x0, 0x18E3, 0x861, 0x20, 0x840, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x20, 0x20, 0x0, 0x840, 
0x842, 0x21, 0x6B4D, 0xA534, 0x73AE, 0x7BCF, 0xA555, 0xADF8, 0x9598, 
0x5C77, 0x1293, 0x1F4, 0x9D6, 0x976, 0x134, 0xF3, 0xD2, 0xB2, 
0x92, 0x71, 0x51, 0x31, 0x10, 0x10, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x30, 0x30, 0x30, 0x31, 0x31, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x51, 0x71, 0x71, 0x91, 0x91, 0xB1, 0x92, 0x92, 
0xB3, 0x8F4, 0x934, 0x112, 0x2AB6, 0x857F, 0x8DDF, 0x4394, 0x8577, 
0xAE59, 0xA5B6, 0xA5B7, 0x74F7, 0x6CF9, 0x6CFA, 0x4BD6, 0x5C58, 0x8D59, 
0x9D33, 0x3142, 0x3985, 0x62EB, 0x18A2, 0x20, 0x841, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x20, 0x862, 0x1, 0x18C3, 0x9D13, 
0xDF3C, 0xBE9B, 0x8D99, 0x5C56, 0x4BD7, 0x22B4, 0x1AB7, 0x1257, 0x9B5, 
0x975, 0x134, 0x113, 0xD3, 0xB2, 0x92, 0x72, 0x51, 0x31, 
0x10, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x31, 0x11, 0x10, 
0x10, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0xF, 
0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 
0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x31, 0x31, 0x51, 0x51, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x72, 0x72, 0x92, 
0x92, 0xB1, 0xB1, 0xB2, 0xD3, 0xB3, 0xF4, 0x934, 0xF1, 
0x2275, 0x85BF, 0x963E, 0x961A, 0xB657, 0xB5F4, 0xBE15, 0xD6FA, 0xB63A, 
0x8D58, 0x8537, 0x8558, 0x7CF8, 0xA5FB, 0xD6BA, 0x7B8C, 0x800, 0x800, 
0x0, 0x840, 0x0, 0x800, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x882, 0x20, 0x0, 0x8451, 0xB65A, 0x74F6, 0x5457, 
0x2B56, 0x2318, 0x1277, 0x1237, 0x11D6, 0x954, 0x934, 0x113, 0xD3, 
0xD3, 0xB2, 0x72, 0x72, 0x51, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x30, 0x10, 0x30, 
0x70, 0x51, 0x51, 0x31, 0x31, 0x30, 0x50, 0xF, 0x10, 
0x10, 0x11, 0x10, 0x30, 0x10, 0x10, 0x10, 0x10, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x51, 
0x30, 0x51, 0x51, 0x51, 0x51, 0x31, 0x31, 0x51, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x71, 0x51, 0x51, 
0x72, 0x72, 0x72, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB3, 
0xB2, 0xD2, 0xF3, 0x133, 0x954, 0x995, 0x11F2, 0x6456, 0xB679, 
0xA552, 0x7389, 0xCE34, 0xC5F4, 0xC636, 0xB595, 0x73CE, 0xBE38, 0xBE7B, 
0x9516, 0x8C71, 0x7BCE, 0x0, 0x1062, 0x841, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x800, 0x0, 0x0, 0x20, 0x18C2, 
0x0, 0x3185, 0x73CE, 0xADD7, 0x95BA, 0x4C59, 0x1B17, 0x12B6, 0x9F5, 
0x9B5, 0x995, 0x134, 0x934, 0xD3, 0xD3, 0xB2, 0x72, 0x72, 
0x51, 0x31, 0x30, 0x10, 0xF, 0xF, 0xE, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0x30, 0x30, 0x92, 0x8D2, 0x91, 0x92, 0x72, 0x51, 
0x51, 0x51, 0x51, 0x30, 0x31, 0x31, 0x31, 0x10, 0x30, 
0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x51, 0x51, 0x30, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x71, 0x71, 0x71, 0x71, 0x71, 0x72, 0x72, 0x92, 0x92, 
0x92, 0xB2, 0xB3, 0xB3, 0xD3, 0xD3, 0xF3, 0x933, 0x134, 
0x11B5, 0x134, 0x4BBA, 0xAE9F, 0xAE39, 0xAD93, 0xBDD2, 0x8C2C, 0x41C3, 
0x7B4A, 0x6B0A, 0x41E5, 0x6B8C, 0xC679, 0xB5F7, 0x18C3, 0x0, 0x841, 
0x862, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1, 0x820, 0x820, 0x18C2, 0x0, 0x5269, 0xA553, 
0x6BD0, 0x5C98, 0x3376, 0x3356, 0x541A, 0x2AB7, 0x174, 0x1195, 0x113, 
0x914, 0xD2, 0xD3, 0xD3, 0x72, 0x51, 0x51, 0x30, 0x10, 
0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x30, 0x10, 0x1113, 
0x3A78, 0x21F6, 0xF3, 0xD2, 0xB2, 0xD2, 0x91, 0x71, 0x51, 
0x51, 0x32, 0x31, 0x31, 0x51, 0x31, 0x31, 0x30, 0x30, 
0x50, 0x50, 0x50, 0x50, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x91, 0x891, 0x50, 0x71, 0x51, 0x51, 0x51, 0x71, 0x71, 
0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 
0x71, 0x91, 0x91, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 
0xD3, 0xF3, 0xF4, 0x114, 0x954, 0x11B5, 0x993, 0x3B58, 0x74DA, 
0x9599, 0xAE17, 0xDF39, 0xA4D0, 0x4164, 0x800, 0x800, 0x20, 0x40, 
0xB5F5, 0x7C0D, 0x0, 0x1082, 0x841, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1062, 0x800, 0x28E3, 0x94D3, 0x9599, 0x74F7, 0x8D58, 
0xA5FC, 0x4356, 0x172, 0x1195, 0x954, 0x113, 0x113, 0xB2, 0xB2, 
0xB2, 0xB1, 0x50, 0x71, 0x30, 0x10, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x30, 0x71, 0x51, 0x3278, 0x431B, 0x112, 0xF2, 
0x112, 0x50, 0xF2, 0x91, 0x92, 0x72, 0x72, 0x51, 0x72, 
0x51, 0x51, 0x51, 0x51, 0x50, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x50, 0x71, 0x91, 0x71, 0x91, 0x71, 0x91, 0x71, 
0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x91, 
0x71, 0x91, 0x91, 0x91, 0x91, 0x91, 0xB1, 0xB1, 0xB2, 
0xB2, 0xB2, 0xD2, 0xD2, 0xF2, 0xF3, 0x114, 0xF4, 0x114, 
0x975, 0x974, 0x1215, 0x11F3, 0x1212, 0x751A, 0x9DFA, 0xADF7, 0xD698, 
0x8BEE, 0x800, 0x2104, 0x840, 0x860, 0x634A, 0x2963, 0x0, 0x10A2, 
0x0, 0x21, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x820, 0x842, 0x1, 
0x820, 0xA534, 0xB619, 0xA5B8, 0xADD7, 0x9536, 0x6C9A, 0x9D3, 0x11D5, 
0x974, 0x133, 0x134, 0x113, 0x113, 0xD2, 0x70, 0x8F2, 0x50, 
0x51, 0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x30, 0x50, 0x8B2, 
0x71, 0x2237, 0x539C, 0x4BBC, 0x32F8, 0x132, 0x32B8, 0x954, 0xD3, 
0xB2, 0x92, 0x92, 0x71, 0x72, 0x71, 0x71, 0x71, 0x71, 
0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x91, 0x71, 0x91, 
0xB2, 0xB2, 0x91, 0xB2, 0x92, 0x92, 0x92, 0x92, 0x92, 
0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 
0x92, 0x92, 0xB1, 0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 0xF2, 
0xF2, 0xF3, 0x114, 0x114, 0x135, 0x976, 0x976, 0x11D6, 0x1A36, 
0x22B7, 0x3B58, 0x4BD7, 0x8D38, 0x9CF3, 0x7B6B, 0x0, 0x0, 0x20, 
0x18A2, 0x840, 0x0, 0x1081, 0x0, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 0x0, 
0x0, 0x820, 0x0, 0x41, 0x8A2, 0x20, 0x5ACB, 0x6B4D, 0x31C6, 
0x73CD, 0x9D76, 0x74DB, 0x1214, 0x11D5, 0x9B5, 0x174, 0x133, 0x155, 
0x113, 0x974, 0x1173, 0x2E, 0x8F2, 0x51, 0x10, 0x10, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x30, 0x51, 0x91, 0xF3, 0x113, 0x1A16, 0x439A, 
0x5C7D, 0x5C7D, 0x4BBB, 0x974, 0x113, 0xD3, 0xB2, 0xB2, 0x91, 
0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x71, 0x92, 0x92, 
0x92, 0x92, 0xD2, 0x91, 0xB2, 0xD2, 0x91, 0xD2, 0xD2, 
0xB2, 0xB2, 0xB2, 0x92, 0x92, 0x92, 0x92, 0xB2, 0x92, 
0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xB2, 0xD2, 0xD3, 0xD2, 0xF2, 0xF3, 0xF3, 0x134, 0x955, 
0x155, 0x176, 0x9B6, 0x9D6, 0x1237, 0x1AB7, 0x2B18, 0x2B38, 0x6CBA, 
0x84B3, 0x94D0, 0x4228, 0x2104, 0x39E7, 0x1061, 0x0, 0x841, 0x0, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x21, 0x0, 0x20, 0x20, 0x0, 0x0, 0x0, 
0x20, 0x61, 0x0, 0x800, 0x820, 0x94F1, 0xA5D8, 0x4356, 0x1235, 
0x1A36, 0x11F5, 0x9B5, 0x9B5, 0x175, 0x174, 0x19F5, 0x643D, 0x42D8, 
0x6F, 0x92, 0x31, 0x10, 0x10, 0xE, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x71, 
0xB1, 0xD2, 0xF3, 0x153, 0x172, 0x4399, 0x64FE, 0x1234, 0x173, 
0x134, 0xF3, 0xD2, 0xD1, 0xD1, 0xB2, 0xB2, 0xB2, 0x92, 
0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 
0x8F3, 0xF3, 0x954, 0x954, 0x913, 0x8F3, 0xD3, 0xD2, 0xB2, 
0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xB2, 0xB2, 0xB2, 0xD2, 0xD2, 0xD3, 0xD3, 0xD3, 0xF3, 
0xF3, 0x113, 0x113, 0x133, 0x974, 0x174, 0x195, 0x9D6, 0x1217, 
0xA16, 0x1276, 0x1AF7, 0x2B99, 0x4C59, 0x8598, 0xB699, 0xBE58, 0xAD75, 
0x630C, 0x0, 0x1062, 0x841, 0x0, 0x0, 0x821, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 
0x0, 0x0, 0x0, 0x820, 0x820, 0x0, 0x1082, 0x20, 0x3165, 
0xA555, 0xAE38, 0x74D6, 0x2B16, 0x22D8, 0x1235, 0x9D4, 0x9D5, 0x1216, 
0x9D6, 0x1216, 0x172, 0x6C9E, 0x5C1C, 0xD0, 0x8B2, 0x72, 0x30, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x30, 0x50, 0x71, 0x91, 0xB2, 0x113, 0x994, 
0x9D3, 0x4C3B, 0x6D5E, 0x2AF6, 0x194, 0x975, 0x114, 0xF3, 0xF2, 
0xF2, 0xB2, 0xD2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xB2, 0xD2, 0xD3, 0xD3, 0x913, 0xF3, 0x1175, 0x5BFD, 0x2A98, 
0xB0, 0x933, 0x113, 0xF3, 0xD3, 0xD3, 0xD3, 0xB2, 0xB2, 
0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 0xD2, 0xD2, 0xD2, 
0xD2, 0xF3, 0xF3, 0xF4, 0xF4, 0x114, 0x114, 0x134, 0x133, 
0x174, 0x9B5, 0x1B5, 0x1236, 0x1236, 0x2AF8, 0x4BF8, 0x4C39, 0x3BF9, 
0x4C7A, 0x7557, 0xB6BA, 0xBE58, 0x738D, 0x0, 0x0, 0x842, 0x0, 
0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x801, 0x1, 0x0, 0x0, 0x0, 0x0, 
0x800, 0x0, 0x820, 0x861, 0x0, 0x7C31, 0x9576, 0x6495, 0x43D7, 
0x22D5, 0x5C3A, 0x645B, 0x1A54, 0xA14, 0x1A77, 0xA15, 0x3316, 0x7D5F, 
0x95BF, 0x2A36, 0x50, 0x892, 0x30, 0xF, 0x2F, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x50, 0x70, 
0x71, 0xB2, 0xB2, 0x934, 0x153, 0x2296, 0x6D1E, 0x85DF, 0x4C1A, 
0x193, 0x9B5, 0x154, 0x133, 0x913, 0xF2, 0xF3, 0xF3, 0xF3, 
0xD3, 0xB3, 0x8B3, 0xD2, 0xD2, 0x113, 0xF3, 0xF3, 0x113, 
0x914, 0x934, 0x174, 0x64BF, 0x5CBD, 0x1A74, 0x994, 0x154, 0x134, 
0xF3, 0x114, 0xF3, 0xD2, 0xD2, 0xD2, 0xD3, 0xD3, 0xD3, 
0xF2, 0xF2, 0xD2, 0xF3, 0xD3, 0xF3, 0xF3, 0x113, 0x113, 
0x114, 0x114, 0x114, 0x134, 0x174, 0x174, 0x9D5, 0x1D5, 0xA15, 
0x9D3, 0x649A, 0xA61C, 0x9E1B, 0x5C78, 0x7D7B, 0x6432, 0x73EE, 0x8C71, 
0x0, 0x0, 0x862, 0x0, 0x0, 0x20, 0x0, 0x0, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x820, 0x841, 
0x0, 0x21, 0x5BB0, 0x8557, 0x6496, 0x53F4, 0x9578, 0xB67D, 0x7D5A, 
0x3B75, 0x1294, 0x4C3A, 0x961D, 0x9E1E, 0x74BD, 0x19B5, 0x71, 0x892, 
0x10, 0x10, 0xF, 0x2F, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x30, 0x50, 0x71, 0x91, 0xB2, 0x913, 0xD2, 
0x193, 0x130, 0x5C9B, 0x64FC, 0x1274, 0x1216, 0x995, 0x995, 0x154, 
0x113, 0x113, 0x113, 0x113, 0x113, 0x114, 0xD3, 0xF3, 0x113, 
0x113, 0xF3, 0x113, 0x134, 0x975, 0x1196, 0x1194, 0x9F3, 0x3B98, 
0x967F, 0x5CDC, 0x172, 0x174, 0x174, 0x134, 0x114, 0x114, 0x113, 
0xF2, 0xF3, 0xF3, 0x114, 0xD3, 0x113, 0x112, 0xD2, 0xF3, 
0xF3, 0xF3, 0x113, 0x133, 0x134, 0x134, 0x934, 0x935, 0x955, 
0x975, 0x995, 0x11F5, 0x1275, 0x22D5, 0x53D6, 0xA5DA, 0x9D55, 0xB618, 
0x9599, 0xA61B, 0xADD6, 0x5AC9, 0x2103, 0x20C3, 0x21, 0x861, 0x0, 
0x0, 0x821, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1041, 0x1062, 0x1, 0x7432, 0xA5F9, 
0x9DD9, 0x9597, 0xADD7, 0x9D55, 0xB67B, 0x6496, 0x22F3, 0x5CB9, 0x9E7D, 
0x74F8, 0x990, 0xF2, 0xB1, 0x892, 0x10, 0x10, 0xF, 0x2F, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x50, 
0x71, 0x91, 0xB2, 0xF2, 0x1A36, 0x2AF8, 0x4C5A, 0x75BF, 0x5CBC, 
0x9F3, 0x1257, 0x9B6, 0x975, 0x975, 0x974, 0x994, 0x154, 0x134, 
0x975, 0x113, 0x954, 0x954, 0x113, 0x134, 0x135, 0x134, 0x995, 
0x133, 0x19F6, 0x643C, 0x85BE, 0x8E5F, 0x7DDF, 0x3378, 0x9D4, 0x9B5, 
0x175, 0x154, 0x114, 0x914, 0x113, 0x113, 0x113, 0x914, 0xF4, 
0x914, 0xF3, 0xF3, 0x914, 0x8F3, 0x8F4, 0x114, 0x114, 0x134, 
0x134, 0x134, 0x935, 0x955, 0x135, 0x996, 0x11F6, 0x172, 0x649B, 
0xA63D, 0x9D55, 0xA4F1, 0xCE35, 0xD6B8, 0x7C0F, 0xB5D6, 0xD6D8, 0x6B6B, 
0x0, 0x0, 0x21, 0x21, 0x0, 0x800, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x1, 
0x0, 0x1882, 0x0, 0x1083, 0xC639, 0xAD96, 0x52CC, 0x52AB, 0x632C, 
0xCE99, 0xAE39, 0x6475, 0x6D39, 0xA69C, 0x6475, 0x9B0, 0x2235, 0x1133, 
0x51, 0x851, 0x10, 0x30, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x30, 0x30, 0x50, 0x71, 0x91, 0xD2, 0xF2, 
0x32D9, 0x545D, 0x549B, 0x75BF, 0x757F, 0x43DA, 0x1257, 0x1237, 0x11D6, 
0x995, 0x9B5, 0x154, 0x195, 0x195, 0x173, 0x9D4, 0x194, 0x174, 
0x974, 0x954, 0x155, 0x175, 0x175, 0x11F5, 0x9D4, 0x4BD9, 0xA6DF, 
0x85FC, 0x1AF3, 0x1295, 0x1236, 0x1217, 0x9D6, 0x155, 0x1175, 0x934, 
0x954, 0x954, 0x134, 0x1175, 0x914, 0x114, 0x934, 0x114, 0x8F4, 
0x914, 0x914, 0x114, 0x114, 0x134, 0x134, 0x154, 0x954, 0x955, 
0x996, 0x997, 0x11D6, 0x11F4, 0x3B76, 0xAE7C, 0xA553, 0x62A6, 0x8C0C, 
0x6B29, 0x41C5, 0x6B2A, 0xA4F0, 0x1080, 0x0, 0x862, 0x21, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 
0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x1882, 0x800, 0x20C3, 
0xAD34, 0x5ACB, 0x0, 0x0, 0x0, 0x8C4F, 0xB5D5, 0xA619, 0xB6DC, 
0xAE7B, 0x8579, 0x7D5E, 0x5C3D, 0x91, 0x71, 0x851, 0x830, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 
0x51, 0x71, 0x92, 0xB3, 0x8F4, 0x974, 0x1A16, 0x1B3, 0x441A, 
0x969F, 0x5CFB, 0x1275, 0x1297, 0x1237, 0x1237, 0x9D6, 0x1238, 0xA17, 
0x1B4, 0x3BD9, 0x54BD, 0x1D4, 0x175, 0x995, 0x975, 0x996, 0x995, 
0x9D6, 0xA15, 0xA34, 0x651D, 0xAEFF, 0x5456, 0x12D3, 0x12D6, 0x1277, 
0x1D7, 0x196, 0x9B6, 0x996, 0x1195, 0x974, 0x995, 0x995, 0x154, 
0x975, 0x155, 0x155, 0x134, 0x934, 0x934, 0x934, 0x134, 0x134, 
0x154, 0x154, 0x974, 0x974, 0x975, 0x976, 0x996, 0x11F7, 0x1A56, 
0x1A95, 0x7D3B, 0xA5D8, 0xB5B5, 0x9CF0, 0x2902, 0x800, 0x800, 0x4A48, 
0x1061, 0x0, 0x821, 0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x820, 0x800, 0x820, 0x39A6, 0x20C3, 0x820, 0x18A3, 
0x800, 0x800, 0x820, 0x94F2, 0xAE17, 0xC6DB, 0xA63C, 0x5BF9, 0x32B8, 
0x90, 0xB1, 0x10, 0xF, 0x810, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x30, 0x51, 0x71, 0x92, 0x92, 
0xD3, 0x113, 0x153, 0x9D4, 0x22B6, 0x85FE, 0x7DDD, 0x1AF5, 0xA54, 
0x1AB6, 0x1255, 0x43BB, 0x1A76, 0xA16, 0x1AB7, 0x75DF, 0x54DB, 0x1B3, 
0x1237, 0x11F6, 0x11F6, 0x195, 0x9D6, 0x9D6, 0x1236, 0xA35, 0x4C7B, 
0x9EBF, 0x967F, 0x7DFE, 0x6D5D, 0x3358, 0x2AF8, 0x331A, 0x11F6, 0x11D6, 
0x9B5, 0x11D6, 0x193, 0x1A55, 0x2296, 0x174, 0x11B6, 0x174, 0x174, 
0x9B6, 0x154, 0x955, 0x155, 0x174, 0x174, 0x174, 0x974, 0x975, 
0x995, 0x11D7, 0x11D7, 0x1217, 0x1256, 0x22D7, 0x3356, 0x74B6, 0xA5F8, 
0xADB6, 0x4207, 0x800, 0x28E4, 0x800, 0x20, 0x821, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x20, 
0x820, 0x800, 0x820, 0x1882, 0x18C2, 0x820, 0x41E7, 0x9491, 0xB637, 
0xAE38, 0xAE1A, 0x959B, 0x5399, 0x6F, 0x912, 0x70, 0x30, 0x810, 
0xE, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 
0x31, 0x51, 0x72, 0x92, 0xB1, 0xF2, 0x133, 0x994, 0x9B4, 
0x43BA, 0x6D1C, 0x8E7F, 0x7DDE, 0x6D1B, 0x8E1F, 0x85DE, 0x8DFE, 0x5459, 
0x3338, 0x1AB5, 0x6D7B, 0x75BC, 0x1AB5, 0x1A76, 0x1D5, 0x1D5, 0x1237, 
0x11F6, 0x1A16, 0x1A57, 0x1298, 0x1B18, 0x653E, 0x8E3F, 0xAEDE, 0xBF3F, 
0x7D18, 0x7D1A, 0x6CFC, 0x1D2, 0x1A57, 0x1217, 0x1A77, 0x1234, 0x5459, 
0x7D5D, 0x1A14, 0x9B5, 0x11F6, 0x194, 0x175, 0x175, 0x995, 0x995, 
0x194, 0x194, 0x995, 0x996, 0x1196, 0x1196, 0x9B6, 0x9F7, 0x1257, 
0x1256, 0x1AD8, 0x2B37, 0x3B94, 0x6CF6, 0x9597, 0xADF7, 0x9CD1, 0x39A5, 
0x0, 0x861, 0x21, 0x1, 0x0, 0x800, 0x800, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x20, 0x20, 0x20, 0x0, 0x10A3, 0x2966, 0x0, 
0x20, 0x20, 0x83ED, 0xD6FB, 0x6C95, 0x6CD8, 0x95DE, 0x4315, 0x3297, 
0x8F2, 0x91, 0x51, 0x10, 0x30, 0x30, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x10, 0x30, 0x30, 0x51, 0x71, 0x92, 0x92, 
0xB2, 0xD2, 0x133, 0x153, 0x994, 0x2AB7, 0xA13, 0x4C39, 0x7DDF, 
0x6D5C, 0x759C, 0xA6DF, 0xB75F, 0x9E3C, 0x6CD9, 0x6CB9, 0x9E7C, 0xAEFF, 
0x43F8, 0x1A95, 0x4C1C, 0x43DB, 0xA15, 0x1A77, 0x2277, 0x1A77, 0x1AF9, 
0x2359, 0x2BB9, 0x43F6, 0x8D98, 0xAE58, 0xADF6, 0xBEDB, 0x8DBB, 0x43B7, 
0x1AB7, 0x1297, 0x1AB6, 0x85DF, 0x9EBF, 0xA69F, 0x4399, 0x1B4, 0x1216, 
0x9B5, 0x9D6, 0x9B6, 0x9B6, 0x9B5, 0x1B5, 0x1B5, 0x996, 0x996, 
0x11B6, 0x11B6, 0x9F7, 0xA17, 0x1257, 0x1A97, 0x22D7, 0x3B97, 0x755A, 
0x95FA, 0xA619, 0xAE18, 0x842F, 0x800, 0x20, 0x861, 0x0, 0x1, 
0x801, 0x800, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x882, 0x0, 0x73AF, 0x8451, 0x4289, 0x7C50, 0x9D34, 0xB65B, 
0x6CFA, 0x1A93, 0x4398, 0x11B3, 0x70, 0x8F3, 0x72, 0x31, 0x30, 
0xF, 0xF, 0x2F, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x31, 
0x51, 0x51, 0x71, 0x92, 0x92, 0xB2, 0xD3, 0x113, 0x133, 
0x154, 0x995, 0xA15, 0x1276, 0xA75, 0x1AF6, 0x2335, 0x4C57, 0x9E5C, 
0xAE9B, 0xB69A, 0xB679, 0xBEFB, 0x95B8, 0x4C36, 0x54BA, 0x967F, 0x547B, 
0x1295, 0x1AF8, 0x1A97, 0x1A97, 0x235A, 0x237A, 0x33D9, 0x4437, 0x8DFA, 
0xC73B, 0xC655, 0xA572, 0xB67A, 0x6CF9, 0x1B16, 0x12D6, 0x5479, 0xB71F, 
0x8E1C, 0x4C37, 0x2317, 0x1257, 0x1236, 0x1216, 0x9D6, 0x11D6, 0x9D6, 
0x11D6, 0x9D5, 0x9D5, 0x11D7, 0x11D7, 0x11D6, 0x11F6, 0xA17, 0x1238, 
0x1A79, 0x1A76, 0x3AF4, 0x7D18, 0xA619, 0xC6FB, 0xBE78, 0x6B8C, 0x20, 
0x0, 0x861, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x20, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x18C3, 0x0, 0x4228, 
0xCEBA, 0xA61A, 0x8579, 0x95BB, 0x7CFB, 0x3B38, 0x9B4, 0x112, 0x153, 
0x8F3, 0x72, 0x71, 0x30, 0x30, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x30, 0x31, 0x51, 0x51, 0x71, 0x92, 
0xB2, 0xB3, 0xD3, 0xF3, 0x113, 0x155, 0x975, 0x9D6, 0x1237, 
0x1277, 0x12B8, 0x1B17, 0x54DB, 0x9E9F, 0xB6FD, 0xC6D9, 0xBE55, 0xCEB8, 
0xC6DB, 0x7D58, 0x8DFB, 0xA67E, 0x43D5, 0x33B8, 0x2338, 0x3399, 0x3BDA, 
0x2B99, 0x2BB9, 0x5CDB, 0x755A, 0x95F9, 0xD77B, 0xB592, 0x83EC, 0xCEFA, 
0x95FA, 0x3C18, 0x33D8, 0x5CD8, 0xAEDE, 0xAEDD, 0x7518, 0x22F4, 0x22F7, 
0x1AB7, 0x1256, 0x1A56, 0x1216, 0x1217, 0x9D6, 0x9F6, 0x9F6, 0x11F7, 
0x11F7, 0x11F6, 0x1216, 0x1257, 0x1278, 0x1257, 0x4BFB, 0x8D7B, 0x84D4, 
0x9D54, 0x8C6F, 0xA532, 0x9470, 0x0, 0x18A3, 0x0, 0x0, 0x841, 
0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x840, 0x0, 0x820, 0x8CB3, 0x8D78, 0x4373, 0x2AB3, 
0x1213, 0x9B5, 0x995, 0x975, 0x934, 0xD3, 0x72, 0x71, 0x50, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x30, 
0x51, 0x51, 0x71, 0x92, 0x92, 0xB2, 0xD2, 0xF3, 0xF3, 
0x113, 0x154, 0x975, 0x9B6, 0x11D7, 0x1237, 0x1A98, 0x12B7, 0x4C9D, 
0x6D9D, 0x64D7, 0xB699, 0xCED8, 0x9CF0, 0xCE76, 0xD71A, 0xC6B9, 0xAE17, 
0x9DF9, 0x4417, 0x2B97, 0x759C, 0x85DD, 0x43F8, 0x4417, 0x85DC, 0xB6BD, 
0x9D54, 0xA4F2, 0x49E5, 0x62C9, 0xBE37, 0xA619, 0x64D8, 0x4417, 0x5CB9, 
0x85BB, 0xBEDB, 0xB679, 0x9E3C, 0x4C17, 0x1276, 0xA76, 0xA14, 0x1235, 
0x1A37, 0x1217, 0x1A58, 0x1217, 0x11F7, 0x9F7, 0x1217, 0x1237, 0x1276, 
0x1A97, 0x1276, 0x545B, 0x9E3C, 0x5B8E, 0x630C, 0x20C2, 0x800, 0x3986, 
0x0, 0x821, 0x1, 0x1, 0x0, 0x0, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 0x841, 
0x20, 0x7BF0, 0xA5B7, 0x7CD7, 0x4337, 0x1A15, 0x1A16, 0x994, 0x934, 
0xF3, 0xD2, 0x92, 0x71, 0x50, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x10, 0x30, 0x31, 0x51, 0x51, 0x71, 0x92, 
0xB2, 0xB2, 0xD2, 0xF3, 0xF3, 0x914, 0x154, 0x975, 0x996, 
0x11B6, 0x1A17, 0x1A57, 0x2319, 0x1AF7, 0x2B76, 0x64F8, 0xAE59, 0xB5F5, 
0x31A3, 0x5246, 0xC5F4, 0xB5D4, 0x9D31, 0xC6FB, 0x64F8, 0x4C77, 0x8DFB, 
0xAEBD, 0x8DDB, 0x8D9A, 0x95D9, 0xC6FB, 0xAD53, 0x1840, 0x800, 0x1882, 
0x5AEA, 0xB637, 0x9E3A, 0x8DFB, 0x7559, 0x95DA, 0xCED9, 0xA594, 0xA618, 
0x8579, 0x22F4, 0x441A, 0x7D9E, 0x64BC, 0x1236, 0x1A58, 0x1A58, 0x1217, 
0x1237, 0x1A58, 0x1A58, 0x1A57, 0x1276, 0x22D7, 0x1AD8, 0x3377, 0x74D6, 
0x9DB6, 0xA554, 0x62EB, 0x3145, 0x0, 0x1882, 0x0, 0x1, 0x1, 
0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x0, 0x820, 0x1082, 0x0, 0x6B6E, 0x9514, 0x957A, 
0x5C3B, 0x9D5, 0x11F6, 0x974, 0x1175, 0xF3, 0xD2, 0x91, 0x71, 
0x51, 0x30, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x30, 0x31, 
0x51, 0x51, 0x71, 0x92, 0x92, 0xB2, 0xB2, 0xF2, 0xF3, 
0xF3, 0x914, 0x954, 0x975, 0x996, 0x11D6, 0x11F6, 0x1A77, 0x1AB7, 
0x3398, 0x4C59, 0x85BA, 0xD73B, 0xC675, 0x4206, 0x800, 0x2923, 0x840, 
0x7C0E, 0xBE99, 0x9E5A, 0x7577, 0xA65A, 0xAE38, 0x73CF, 0xBDF7, 0xCEBA, 
0xDF3B, 0xBDF3, 0x20E0, 0x820, 0x801, 0x6B4A, 0xE75A, 0xC6F9, 0xA5D6, 
0xBEBA, 0xBE58, 0xB5B4, 0x94D0, 0x8470, 0xA5F8, 0x6455, 0x9E3D, 0xB71F, 
0x74FA, 0x22B6, 0x1A99, 0x1278, 0x1A99, 0x1A78, 0x1257, 0x1277, 0x1A97, 
0x22B7, 0x22D8, 0x2339, 0x3378, 0x53F4, 0xA5D8, 0xCEDA, 0xB5B5, 0x52A9, 
0x20, 0x862, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x801, 
0x821, 0x821, 0x3187, 0x6B8F, 0x7CD7, 0x43D9, 0x257, 0x1257, 0x995, 
0xF3, 0x8F3, 0xB2, 0xB2, 0x51, 0x51, 0x30, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x10, 0x30, 0x30, 0x30, 0x51, 0x51, 0x71, 0x71, 0x92, 
0x92, 0xB2, 0xD2, 0xF3, 0x113, 0xF4, 0x934, 0x955, 0x975, 
0x9B5, 0x11F6, 0x1236, 0x22D8, 0x2317, 0x22F4, 0x6D19, 0xA65B, 0xC697, 
0xA510, 0x18A2, 0x0, 0x0, 0x800, 0x2102, 0x8CB1, 0xC73B, 0xB6BA, 
0xBEDA, 0xCEB9, 0x4184, 0x9C6F, 0xAD33, 0x8C90, 0xAD72, 0x52A7, 0x821, 
0x1, 0x844F, 0xAD72, 0x94F1, 0x5AE9, 0xD6D8, 0xC636, 0x18A1, 0x20, 
0x8C8F, 0xBE57, 0x9576, 0xAE7A, 0xB6BB, 0x6474, 0x2B15, 0x2B39, 0x1AB8, 
0x1A98, 0x22B9, 0x1AB8, 0x1AB7, 0x22B8, 0x22D8, 0x22F8, 0x2339, 0x43D8, 
0x7D18, 0xB659, 0xCEDA, 0x7C0E, 0x20, 0x861, 0x862, 0x0, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x800, 0x0, 0x1082, 0x0, 0x5AAB, 0xAD97, 
0x7CB6, 0x22D4, 0x12B6, 0x1257, 0x1A57, 0x3AF8, 0x19B4, 0xB1, 0x8B2, 
0x51, 0x51, 0x30, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x30, 0x30, 0x30, 0x51, 0x51, 
0x51, 0x71, 0x71, 0x91, 0x92, 0xB2, 0xD2, 0xD2, 0xD2, 
0x113, 0x113, 0x134, 0x955, 0x996, 0x9D5, 0xA15, 0x215, 0x443B, 
0x8E7F, 0x757A, 0x9E1A, 0xB658, 0x94AF, 0x3983, 0x0, 0x1061, 0x1081, 
0x2103, 0x800, 0x840E, 0xEFBC, 0xB636, 0x6B6C, 0x9C91, 0x41E6, 0x20E3, 
0x39A6, 0x0, 0x0, 0x2944, 0x841, 0x18A3, 0x18E3, 0x0, 0x840, 
0x3184, 0x62E9, 0x7BAD, 0x3144, 0x800, 0x94B0, 0xCED8, 0xBEB9, 0xCF1B, 
0xBE57, 0x9DB6, 0x5C77, 0x2315, 0x2337, 0x2B38, 0x22B8, 0x1AB8, 0x2319, 
0x22D8, 0x231A, 0x2B3A, 0x3398, 0x753B, 0x7472, 0x636C, 0x6B4C, 0x5ACA, 
0x0, 0x21, 0x821, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x0, 0x10A2, 0x0, 0x2965, 0x9D55, 0x9D78, 0x8D59, 0x53F6, 0x1A55, 
0x9F4, 0x6CFC, 0x4B98, 0x70, 0x8B2, 0x71, 0x51, 0x10, 0x10, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x30, 0x31, 0x51, 0x51, 0x51, 0x51, 0x71, 0x71, 0x92, 
0xB2, 0xB2, 0xD2, 0xF2, 0xF3, 0x113, 0x133, 0x154, 0x975, 
0x996, 0x9F5, 0xA35, 0xA56, 0x2B58, 0x75BE, 0x9EBF, 0x9E1A, 0xC6DA, 
0xC636, 0x4A46, 0x820, 0x18C3, 0x1061, 0x20, 0x800, 0xA4F2, 0xAD73, 
0x5288, 0x2903, 0x800, 0x1061, 0x0, 0x0, 0x1082, 0x20, 0x0, 
0x820, 0x0, 0x1, 0x862, 0x0, 0x800, 0x800, 0x800, 0x1021, 
0x3145, 0x946F, 0x8CAF, 0xB637, 0xB5F6, 0x842E, 0x8CB1, 0x8558, 0x7DBB, 
0x759D, 0x3377, 0x2B38, 0x2B39, 0x22F8, 0x2339, 0x235B, 0x2B5A, 0x3BD8, 
0x755A, 0x8CF3, 0x7BED, 0x2944, 0x0, 0x1082, 0x0, 0x801, 0x1, 
0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x20, 0x1081, 0x20, 0x4A69, 
0xB5F8, 0x94F4, 0x9D97, 0x84F6, 0x4B96, 0x64BB, 0x9E7F, 0x6479, 0x4F, 
0x8B3, 0x91, 0x51, 0x10, 0x10, 0x810, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x30, 0xF, 0x31, 0x31, 0x51, 0x31, 0x71, 
0x71, 0x71, 0x71, 0x871, 0x92, 0xB2, 0xD2, 0xD2, 0xF2, 
0x112, 0x933, 0x954, 0x996, 0x195, 0x9D6, 0x9F5, 0x1236, 0x1298, 
0x1AB8, 0x2338, 0x4419, 0x5498, 0x963B, 0xB616, 0x6B4B, 0x800, 0x0, 
0x820, 0x0, 0x2924, 0x5289, 0x1061, 0x0, 0x820, 0x1041, 0x0, 
0x841, 0x841, 0x820, 0x1062, 0x841, 0x0, 0x821, 0x861, 0x861, 
0x841, 0x1061, 0x1061, 0x841, 0x800, 0x820, 0x0, 0x0, 0x73AD, 
0x5ACA, 0x0, 0xA553, 0xCEDA, 0xB6BB, 0x85BB, 0x3BB6, 0x3399, 0x2B59, 
0x2359, 0x2B79, 0x2B7A, 0x33BB, 0x3BF9, 0x5C98, 0xB639, 0xDF1A, 0x7BEE, 
0x0, 0x862, 0x821, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x861, 0x0, 0x39E7, 0x52AB, 0x1, 0x6B4D, 0xBE38, 
0x95B8, 0x9E3B, 0x7D3A, 0x2AB4, 0x70, 0x93, 0x71, 0x30, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 
0x31, 0x51, 0x30, 0x51, 0x92, 0x91, 0x891, 0x891, 0x892, 
0xB2, 0xD2, 0xF3, 0xF3, 0xF3, 0x133, 0x134, 0x954, 0x995, 
0x9F6, 0xA16, 0x1236, 0x1A56, 0x1AB8, 0x231A, 0x2B5A, 0x2B98, 0x4C99, 
0x8E1B, 0xCF1B, 0xC636, 0x83EE, 0x5289, 0x2924, 0x1081, 0x10A2, 0x0, 
0x0, 0x18A2, 0x841, 0x841, 0x0, 0x820, 0x820, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 
0x20, 0x0, 0x0, 0x820, 0x820, 0x0, 0x41E7, 0xAD74, 0xE73A, 
0xC678, 0x8D56, 0x64B7, 0x3BB7, 0x33B9, 0x33BA, 0x2B9A, 0x33DB, 0x33DA, 
0x4C7B, 0x753A, 0x7C51, 0xA532, 0x4A68, 0x20, 0x841, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x21, 0x20, 0x20, 0x1061, 
0x0, 0x0, 0x820, 0x0, 0x844F, 0xB679, 0xA63A, 0x6C98, 0x2233, 
0x91, 0x93, 0x71, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0xF, 0x10, 0x30, 0x10, 0x871, 0x50, 0x50, 0x8B2, 0x92, 
0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xD3, 0xF2, 0xF3, 0x113, 
0x113, 0x954, 0x954, 0x1A16, 0x194, 0x9D5, 0x1A77, 0x1A57, 0x22B8, 
0x1AB7, 0x2318, 0x33DA, 0x4C7A, 0x5CD9, 0x8DD9, 0xBE79, 0xF7BD, 0xDEFA, 
0x840F, 0x20E3, 0x820, 0x0, 0x10A2, 0x841, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x820, 0x861, 0x861, 
0x1041, 0x1041, 0x20E3, 0x4A48, 0x8C71, 0x5B0B, 0x8CD1, 0xA5F7, 0x7D5A, 
0x4C3A, 0x3BFB, 0x33DB, 0x341B, 0x3C19, 0x5CFA, 0x7D59, 0x73CF, 0x3143, 
0x1081, 0x861, 0x821, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x0, 0x21, 0x0, 0x1061, 0x0, 0x4207, 0x52A9, 0x20, 0x73CD, 
0x9D33, 0xAE38, 0xAE7C, 0x853C, 0x2A55, 0x91, 0x93, 0x51, 0x10, 
0x10, 0x2F, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x30, 0x31, 
0x51, 0x70, 0x71, 0xB1, 0x71, 0xD2, 0xB2, 0xB2, 0xB2, 
0xD3, 0xD3, 0xF3, 0x112, 0x133, 0x134, 0x955, 0x174, 0x3319, 
0x6D1F, 0x4C1B, 0x1274, 0x22D7, 0x22D6, 0x547A, 0x4C59, 0x3BD7, 0x85DD, 
0x9E5C, 0xA65A, 0xC69A, 0x94D2, 0x5ACA, 0x820, 0x0, 0x840, 0x841, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x21, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x840, 0x820, 0x0, 
0x0, 0x10A1, 0xCE35, 0xD6F9, 0x95B9, 0x64B8, 0x443A, 0x447C, 0x447C, 
0x4C9B, 0x5CD8, 0x95B9, 0xCE58, 0x942F, 0x800, 0x1082, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x1081, 
0x0, 0x4227, 0xB616, 0x8CD2, 0x9D97, 0xA5D9, 0x95BA, 0x7D1A, 0x3254, 
0x6F, 0x91, 0x92, 0x51, 0x10, 0xF, 0x2F, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x10, 0x30, 0x30, 0x51, 0x51, 0x71, 0x71, 0x92, 0xB2, 
0xB2, 0xD3, 0xD3, 0xD3, 0xD3, 0xF4, 0xF4, 0x113, 0x113, 
0x134, 0x154, 0x9B5, 0x9F5, 0x1D3, 0x6D7F, 0x9F1F, 0x4417, 0x2334, 
0x3B95, 0x8599, 0x963B, 0x6CF7, 0x961B, 0xA5F7, 0x5B6C, 0xA534, 0x31A6, 
0x0, 0x820, 0x820, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 0x0, 
0x20, 0x0, 0x820, 0x1061, 0x1061, 0x20, 0x20C2, 0x8BED, 0x9470, 
0x8CD2, 0x95D9, 0x64F9, 0x4CBA, 0x449B, 0x54BB, 0x755A, 0x8516, 0x736D, 
0x5207, 0x800, 0x1062, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x18A2, 0x0, 0x4249, 0xA619, 0x8558, 
0x4BD7, 0x22D5, 0x1A75, 0x972, 0x912, 0xB2, 0x91, 0x70, 0x50, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x10, 0x10, 0x30, 0x30, 0x30, 0x31, 0x51, 
0x51, 0x92, 0x92, 0xB2, 0xB2, 0xF3, 0xD2, 0xF3, 0xF4, 
0xF4, 0xF4, 0x114, 0x114, 0x133, 0x154, 0x175, 0x195, 0xA15, 
0xA34, 0x3BD9, 0x8E9F, 0x8EBF, 0x7DBC, 0x9E5D, 0xA637, 0xB678, 0xBEFC, 
0xC6FB, 0xD719, 0x73AC, 0x0, 0x20C3, 0x10A2, 0x841, 0x840, 0x820, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x821, 0x800, 
0x820, 0x1882, 0x800, 0x800, 0x1840, 0xB574, 0xB637, 0x7D78, 0x655A, 
0x5D3D, 0x5CFB, 0x859A, 0xA5D9, 0x9471, 0x1020, 0x0, 0x841, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x820, 
0x861, 0x0, 0x4249, 0x7CD5, 0x5C77, 0x1274, 0xA36, 0x194, 0x134, 
0x914, 0xB2, 0x91, 0x70, 0x30, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x30, 
0x30, 0x31, 0x51, 0x51, 0x71, 0x91, 0x51, 0xD3, 0xF4, 
0x133, 0x133, 0x133, 0x954, 0x135, 0x114, 0x134, 0x134, 0x934, 
0x934, 0x955, 0x995, 0x9B5, 0x9F5, 0x1256, 0x1296, 0x33B8, 0x5D1B, 
0x8E1D, 0xB6BC, 0x844E, 0x948E, 0x8CB0, 0x9D32, 0xBE14, 0x4A45, 0x800, 
0x800, 0x820, 0x20, 0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 
0x0, 0x0, 0x821, 0x0, 0x0, 0x800, 0x0, 0x1062, 0x0, 
0x2923, 0x7BAC, 0x8C70, 0x9E38, 0x7599, 0x655B, 0x6D7B, 0x95FA, 0x9576, 
0x7BCF, 0x20C3, 0x0, 0x861, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x18C3, 0x0, 0x6B8E, 0x9DF9, 
0x5C36, 0x2AF6, 0x1A76, 0x11D5, 0x933, 0xB2, 0xB2, 0x92, 0x51, 
0x30, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x30, 0x30, 0x30, 0x50, 0x51, 0x51, 0x71, 
0x71, 0x91, 0xD2, 0xB3, 0xF3, 0x435B, 0x2277, 0x112, 0x11B5, 
0x975, 0x155, 0x153, 0x953, 0x974, 0x975, 0x976, 0x996, 0x9D6, 
0x11F5, 0x1A57, 0x1AB8, 0x1AF8, 0x1AF5, 0x64D9, 0xAE5A, 0xBDF5, 0x7308, 
0x800, 0x4205, 0x6308, 0x800, 0x1861, 0x820, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x21, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x820, 0x0, 0x1, 0x1, 0x861, 0x0, 0x800, 0x7BCD, 0x9DB5, 
0xA67A, 0x7DFB, 0x7DBB, 0xA65B, 0xA5D7, 0x5ACB, 0x0, 0x10A2, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x841, 0x1041, 0x0, 0x7C10, 0xAE19, 0x8517, 0x4334, 0x74FE, 0x4B7A, 
0x70, 0x912, 0x91, 0x72, 0x31, 0x10, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 0x30, 0x50, 
0x51, 0x51, 0x71, 0x71, 0x71, 0x91, 0xB1, 0xD2, 0xF3, 
0x113, 0x2AB7, 0x649E, 0x543B, 0x2AD7, 0x995, 0x995, 0x994, 0x9D4, 
0x995, 0x996, 0x11B6, 0x9D6, 0x11F6, 0x1237, 0x1A57, 0x1AB9, 0x231A, 
0x2B9A, 0x5CFB, 0x963C, 0xC6BA, 0x738C, 0x800, 0x1861, 0x800, 0x10A1, 
0x0, 0x820, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x20, 0x840, 0x1081, 0x2943, 0x7C0E, 0xAE37, 0x9E7C, 0x8E3B, 0xB6BA, 
0x9553, 0x4228, 0x0, 0x1082, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 0x0, 0x0, 
0x841, 0xA576, 0x9DBA, 0x95DD, 0x4338, 0x90, 0xF2, 0x91, 0x71, 
0x31, 0x810, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 
0x30, 0x30, 0x30, 0x50, 0x50, 0x51, 0x71, 0x71, 0x71, 
0x91, 0xB1, 0xD1, 0xF2, 0xF3, 0x974, 0xF1, 0x543C, 0x757F, 
0x1A74, 0x9F5, 0x1217, 0x11F5, 0x194, 0x9D6, 0x9D6, 0x1216, 0x1216, 
0x1236, 0x1257, 0x1A78, 0x1AB8, 0x1AF8, 0x2B98, 0x43F7, 0x7D59, 0xBE9A, 
0xC617, 0x8BEF, 0x1000, 0x841, 0x41, 0x0, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x841, 0x1082, 0x0, 
0x4A26, 0x9D33, 0xB6FC, 0xAEDC, 0xC71B, 0x8CD2, 0x2124, 0x20, 0x1062, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1082, 0x0, 0x52AA, 0x5AEB, 0x528A, 0x9515, 0xAE3B, 0x7CD9, 
0x930, 0xF2, 0xF2, 0x91, 0x51, 0x30, 0x80F, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x50, 0x50, 
0x51, 0x71, 0x71, 0x91, 0x91, 0xB2, 0xB2, 0xD1, 0xF2, 
0x113, 0x134, 0x2256, 0x5C7D, 0x85FF, 0x54BB, 0x22B7, 0x1236, 0x1237, 
0x1217, 0xA38, 0xA58, 0xA15, 0xA35, 0x1277, 0x1AB9, 0x1AB8, 0x2338, 
0x54FB, 0x5D19, 0x7517, 0xB67B, 0xE75C, 0xCE16, 0x5248, 0x820, 0x21, 
0x41, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x821, 0x1, 0x21, 0x841, 0x800, 0x632B, 0xBEDB, 0xC75D, 
0xCF1B, 0x7C30, 0x0, 0x821, 0x1041, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x820, 0x0, 0x0, 0x2104, 0x0, 0x634D, 
0xB619, 0x8D56, 0x9599, 0x959D, 0x5378, 0x50, 0x8F4, 0x71, 0x91, 
0x70, 0x50, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x50, 0x50, 0x51, 0x51, 0x71, 0x71, 0x91, 0x91, 
0xB2, 0xB2, 0xD2, 0xF2, 0xF2, 0x134, 0x134, 0x2257, 0x22B6, 
0x6D7E, 0x865F, 0x2336, 0x1A96, 0x1A77, 0x1257, 0xA58, 0xA77, 0x3BDA, 
0x3BDA, 0x1AB8, 0x1AD9, 0x2B5A, 0x1B17, 0x5D3B, 0x96BE, 0xA63A, 0x7C51, 
0x94B1, 0x7BAD, 0x0, 0x0, 0x861, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x1, 0x801, 0x1, 
0x10A2, 0x0, 0x20E3, 0xA596, 0xE7BE, 0xDF7C, 0x73CF, 0x1, 0x1062, 
0x801, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x841, 0x0, 0x21, 0x7C31, 0x8D15, 0x330F, 0x3312, 0x3294, 
0xD1, 0x8D3, 0x8B3, 0x92, 0x51, 0x50, 0x2F, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x30, 0x30, 0x31, 0x50, 0x51, 0x51, 0x51, 0x71, 
0x71, 0x71, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xD2, 0x112, 
0x113, 0x114, 0x996, 0x995, 0x9D4, 0x3BF9, 0x865F, 0x651C, 0x1253, 
0x2AD7, 0x22B8, 0x2319, 0xA95, 0x759E, 0x85FF, 0x2337, 0x2338, 0x2B7A, 
0x33BA, 0x3C19, 0x6D5A, 0xAE3A, 0x8C91, 0x20E2, 0x1081, 0x10C3, 0x21, 
0x841, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x1, 0x821, 0x20, 0x10A2, 0x0, 0x6B6D, 
0xEFBE, 0xE77C, 0x5ACA, 0x0, 0x1882, 0x801, 0x801, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x820, 0x0, 0x18A3, 0x0, 0x10C3, 
0xA555, 0x8D56, 0x5435, 0x3334, 0x6E, 0x1154, 0x8D3, 0x92, 0x892, 
0x51, 0x31, 0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 0x10, 0x30, 
0x10, 0x30, 0x10, 0x30, 0x30, 0x30, 0x31, 0x31, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x71, 0x92, 0x92, 0x92, 0xB2, 
0xB2, 0xB2, 0xD2, 0xF3, 0x113, 0x133, 0x155, 0x176, 0x11D6, 
0x1A56, 0xA54, 0x33F8, 0x7DDE, 0x7D9D, 0x649B, 0x4399, 0x2357, 0x1B15, 
0x759B, 0x861D, 0x3BD7, 0x33F9, 0x33D9, 0x441B, 0x443A, 0x64D9, 0xB67A, 
0xE73A, 0x8C50, 0x0, 0x882, 0x41, 0x0, 0x800, 0x800, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x821, 0x0, 
0x0, 0x0, 0x1082, 0x21, 0x18C3, 0xDEB9, 0xF79B, 0x4A67, 0x20, 
0x1882, 0x801, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 
0x800, 0x820, 0x0, 0x10C3, 0x2987, 0x29E8, 0x9DB9, 0xA65F, 0x4BB8, 
0x91, 0x1115, 0xB2, 0x92, 0x51, 0x51, 0x31, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x31, 0x31, 0x31, 0x31, 
0x51, 0x51, 0x51, 0x51, 0x71, 0x71, 0x71, 0x72, 0x72, 
0x72, 0x92, 0x92, 0xB2, 0xB2, 0xD3, 0xD3, 0xF3, 0x113, 
0x113, 0x133, 0x976, 0x175, 0x9B5, 0x1236, 0x1AD7, 0xA73, 0x4C57, 
0xAF1F, 0xA67F, 0x4BD6, 0x4C99, 0x3C16, 0x7558, 0xA6DD, 0x6518, 0x5CFA, 
0x7DDF, 0x4C79, 0x5CFA, 0x9E7E, 0xA5D7, 0x7BCE, 0x5289, 0x0, 0x861, 
0x40, 0x801, 0x800, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x21, 0x0, 0x20, 0x20, 0x20, 0x841, 0x1081, 
0x800, 0xB573, 0xEF98, 0x4223, 0x20, 0x1082, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x18A2, 0x0, 0x2986, 
0x9514, 0x8CD4, 0xA5DA, 0x7CDB, 0xD0, 0x8F3, 0x8D4, 0x92, 0xB2, 
0x71, 0x51, 0x11, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x50, 
0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x51, 0x71, 0x71, 0x71, 0x72, 
0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 
0xD2, 0xD3, 0xF3, 0xF3, 0x134, 0x153, 0x994, 0x155, 0x9B6, 
0x11F6, 0x1236, 0x1277, 0x2B58, 0x651A, 0xA6BE, 0xB6DE, 0x95DA, 0xA69D, 
0x85B9, 0xA639, 0xB6BA, 0xAEBB, 0x9E5B, 0xA6BE, 0x7D7A, 0x7539, 0x9E5C, 
0xCEDB, 0x8430, 0x0, 0x840, 0x60, 0x20, 0x0, 0x1, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 
0x0, 0x20, 0x20, 0x0, 0x20E3, 0x800, 0x840D, 0xD6D4, 0x39E1, 
0x20, 0x10A2, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1082, 0x20, 0x52EC, 0xA597, 0x7CB5, 0x5373, 0x2212, 
0x1132, 0x1114, 0x93, 0x92, 0x91, 0x51, 0x51, 0x31, 0x10, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xE, 0xF, 0xE, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 
0xF, 0x30, 0x30, 0x71, 0x71, 0x92, 0x92, 0x91, 0x91, 
0x71, 0x51, 0x91, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 
0x92, 0x71, 0x92, 0x92, 0xB2, 0xB2, 0x92, 0xB2, 0xB2, 
0xB2, 0xD2, 0xF2, 0xB2, 0x112, 0x112, 0x913, 0x113, 0x114, 
0x154, 0x154, 0x995, 0x175, 0x9D7, 0x1217, 0x1258, 0x1298, 0x2B59, 
0x651B, 0xA69E, 0xBEFC, 0xBE99, 0xB658, 0xCED9, 0xEF9B, 0xAD93, 0xA533, 
0xCEDA, 0xB617, 0xC6FC, 0xA65B, 0xB69C, 0xC679, 0x6B2C, 0x0, 0x841, 
0x20, 0x20, 0x20, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 
0x18A2, 0x800, 0x5A87, 0xBDB0, 0x4202, 0x0, 0x10A2, 0x0, 0x21, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x1, 0x21, 0x0, 0x861, 0x840, 0x2944, 
0x4AAA, 0x9D78, 0x8D3C, 0x950, 0x952, 0x933, 0x8D3, 0x92, 0x92, 
0x71, 0x51, 0x31, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0x2F, 0xF, 0xF, 
0xF, 0x10, 0x10, 0x10, 0x10, 0x30, 0x50, 0x71, 0x71, 
0x8D2, 0x21B6, 0x1175, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x91, 
0x91, 0x91, 0x91, 0x8B2, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 
0xB2, 0xD3, 0xB2, 0xD2, 0xD2, 0xD2, 0xD2, 0xF2, 0x113, 
0x112, 0xF2, 0x934, 0x134, 0x154, 0x995, 0x9B6, 0x9B5, 0x9D6, 
0x1217, 0x1236, 0xA15, 0x22F9, 0x2B58, 0x3396, 0x64B6, 0xC6FB, 0xBE56, 
0x4225, 0x9C8F, 0xCDF4, 0x732A, 0x41C5, 0x83ED, 0x7BCD, 0xA574, 0xC6FB, 
0xDF7E, 0xC658, 0x41E6, 0x0, 0x1062, 0x20, 0x20, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1081, 0x800, 0x3163, 0x8C2C, 
0x39A2, 0x0, 0x1061, 0x21, 0x1, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 0x1, 0x1, 
0x0, 0x821, 0x18A3, 0x0, 0x8472, 0xA5B8, 0x7476, 0x4B58, 0x132, 
0x954, 0xF3, 0x92, 0xB2, 0x8B2, 0x71, 0x30, 0x51, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x10, 0x10, 0x31, 0x31, 
0x51, 0x71, 0x91, 0x91, 0xB3, 0x8F4, 0x2A78, 0x2216, 0x113, 
0x8F3, 0xB2, 0x92, 0xB2, 0xB2, 0xD2, 0xB2, 0xB2, 0x8D3, 
0xB2, 0xD2, 0xF3, 0xD2, 0xF3, 0xD3, 0xD2, 0xD2, 0xD3, 
0xF3, 0xD3, 0x113, 0xF3, 0x134, 0x113, 0x1175, 0x134, 0x11F6, 
0x9F6, 0x9D5, 0x9B6, 0x11F6, 0xA17, 0xA36, 0x4BFA, 0x5CBC, 0x1B17, 
0x2BD8, 0x6D7B, 0x85D9, 0xCF1A, 0xD6D8, 0x41E5, 0x820, 0x1881, 0x820, 
0x0, 0x0, 0x820, 0x20C2, 0x8470, 0xEFDC, 0xCE76, 0x18A0, 0x0, 
0x1082, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x0, 0x841, 0x0, 0x1881, 0x5247, 0x2902, 0x800, 0x841, 0x21, 
0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x21, 0x0, 0x0, 0x20, 0x0, 0x1061, 0x1082, 0x0, 0x426A, 
0x9537, 0x959C, 0x11F2, 0x973, 0x1195, 0x913, 0xD3, 0xB2, 0xB2, 
0x71, 0x51, 0x31, 0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0x10, 0xF, 0xF, 0x10, 0x30, 
0x50, 0x50, 0x51, 0x51, 0x71, 0x92, 0x91, 0xB1, 0xB2, 
0xD4, 0x114, 0x2AB9, 0x32F9, 0x154, 0x114, 0x914, 0xD3, 0xF3, 
0xD3, 0xD2, 0xD2, 0xD3, 0xD3, 0xD3, 0xD2, 0x934, 0x954, 
0x113, 0x113, 0x113, 0x113, 0x114, 0xF3, 0xF4, 0x114, 0x134, 
0x134, 0x955, 0x975, 0x154, 0x3B7B, 0x4C1D, 0xA35, 0x1217, 0x1A58, 
0x1AB8, 0xA35, 0x4C1A, 0x8E5F, 0x5D1C, 0x3C16, 0x759A, 0xAEDB, 0xC6B8, 
0xAD72, 0x4A26, 0x0, 0x820, 0x820, 0x861, 0x10A2, 0x801, 0x820, 
0x0, 0xAD72, 0xCE56, 0x800, 0x0, 0x1083, 0x1, 0x0, 0x800, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x800, 
0x2904, 0x1082, 0x0, 0x20, 0x0, 0x21, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x21, 0x1, 0x0, 0x20, 0x0, 
0x861, 0x18A2, 0x21, 0x2126, 0xA5B9, 0x7CF9, 0x32D5, 0x173, 0x995, 
0x113, 0xD2, 0xD3, 0x8D2, 0x92, 0x51, 0x51, 0x51, 0x10, 
0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x10, 0x30, 0x50, 0x50, 0x51, 0x51, 0x71, 0x71, 0x71, 
0x92, 0x92, 0xD2, 0xB1, 0x133, 0x134, 0x154, 0x22D9, 0x2B19, 
0x153, 0x11F6, 0x154, 0x134, 0x113, 0x113, 0xF3, 0xF4, 0xF4, 
0x114, 0x935, 0x134, 0x11F5, 0x32D9, 0x11D6, 0x174, 0x154, 0x154, 
0x955, 0x134, 0x975, 0x155, 0x975, 0x975, 0x995, 0x11F6, 0x194, 
0x43DC, 0x759F, 0x2B58, 0x1297, 0x12B8, 0xA77, 0x2318, 0x1AF6, 0x64FB, 
0xAEFF, 0x9E7B, 0x9E18, 0xCF5B, 0xADB3, 0x840, 0x0, 0x1061, 0x841, 
0x861, 0x20, 0x20, 0x821, 0x18C2, 0x0, 0x4206, 0x946F, 0x20E2, 
0x800, 0x1062, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1, 0x0, 0x0, 0x18A4, 0x1042, 0x0, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x821, 
0x821, 0x0, 0x0, 0x0, 0x18A2, 0x1082, 0x0, 0x3A09, 0x9558, 
0x74DA, 0x2253, 0x973, 0x1195, 0x934, 0x934, 0xF3, 0xB2, 0x92, 
0x92, 0x71, 0x51, 0x50, 0x10, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xE, 0xE, 0xF, 0xF, 
0x30, 0x50, 0x50, 0x71, 0x71, 0x71, 0x71, 0x91, 0x91, 
0xB2, 0x92, 0xB2, 0x92, 0xD2, 0x92, 0x113, 0xD2, 0x154, 
0x133, 0x11F5, 0x1214, 0x1233, 0x6CDD, 0x5C7C, 0x2AD7, 0x11F6, 0x174, 
0x994, 0x174, 0x154, 0x134, 0x134, 0x174, 0x175, 0x194, 0x2296, 
0x5C7E, 0x2297, 0x174, 0x9D5, 0x9B5, 0x194, 0x174, 0x11D6, 0x195, 
0x9B5, 0x9D5, 0x1B4, 0x1256, 0xA35, 0x22D7, 0x6D1C, 0x43D7, 0x1295, 
0x339A, 0x33B9, 0x33B8, 0x3BF8, 0x5437, 0xA65A, 0xCF3B, 0xCEF9, 0xEFBC, 
0xA511, 0x800, 0x1061, 0x841, 0x21, 0x0, 0x1, 0x0, 0x820, 
0x820, 0x860, 0x1060, 0x3164, 0x20A2, 0x800, 0x1022, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x1, 0x18A4, 0x1063, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1061, 0x18E4, 
0x1, 0x2, 0x4AEE, 0x9579, 0x5C16, 0x1A32, 0x9D4, 0x11D6, 0x134, 
0x934, 0xD2, 0xF3, 0xB2, 0x92, 0x92, 0x71, 0x51, 0x30, 
0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xE, 0xE, 0x2F, 0x2F, 0x70, 0x91, 0x91, 0xD2, 
0xB2, 0xD2, 0xD2, 0xD2, 0xD2, 0xF2, 0xF3, 0x933, 0x934, 
0x113, 0x113, 0x113, 0x154, 0x154, 0x193, 0x1A75, 0x43B6, 0x957B, 
0x957A, 0x7D3A, 0x64BA, 0x9F3, 0x9D5, 0x194, 0x194, 0x194, 0x194, 
0x1215, 0x9F4, 0x1D4, 0x1D3, 0x2B16, 0x64FD, 0x22F7, 0xA15, 0x9F5, 
0x1B4, 0x3318, 0x2AF8, 0x1B4, 0x9D5, 0x1D4, 0x1A76, 0x2B58, 0x1295, 
0x2317, 0x2315, 0x85DC, 0x8E1C, 0x3B96, 0x5CDB, 0x75BD, 0x3BF4, 0x7D9B, 
0xA65B, 0xD75B, 0xC676, 0x6309, 0x73AC, 0x630B, 0x0, 0x1061, 0x820, 
0x0, 0x0, 0x1, 0x821, 0x0, 0x0, 0x0, 0x840, 0x18A2, 
0x821, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x862, 0x41, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x841, 0x0, 0x1062, 0x0, 0x21, 0x84, 0x63F4, 0x7D3A, 0x4397, 
0x1233, 0x1A55, 0x11F5, 0x155, 0x155, 0x134, 0x113, 0xD2, 0xD2, 
0xB2, 0x92, 0x71, 0x51, 0x30, 0x30, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xD, 0xD, 0xE, 0xE, 0x2F, 0x10D2, 
0x10F2, 0x1153, 0x1154, 0x1154, 0x21F6, 0x2217, 0x1175, 0x19B5, 0x19F6, 
0x19B5, 0x11B5, 0x19D6, 0x2A78, 0x3ADA, 0x2216, 0x1A37, 0x2258, 0x1A38, 
0x2299, 0x1256, 0x43D9, 0x8DDD, 0x84B5, 0x42, 0x19CA, 0x7519, 0x3B58, 
0x2AF9, 0x3B7B, 0x333A, 0x22B8, 0x2B19, 0x545D, 0x3B99, 0x337A, 0x2B38, 
0x547A, 0x7DBF, 0x5CDE, 0x2B79, 0x4C1C, 0x3BBB, 0x5CBD, 0x5CBD, 0x43BB, 
0x4BFC, 0x3B79, 0x4C3B, 0x655F, 0x54FD, 0x655F, 0x7DBE, 0x961C, 0x9E7C, 
0x965E, 0x8E5F, 0x96BE, 0x967C, 0xA69C, 0xB6BB, 0xB615, 0x6308, 0x800, 
0x820, 0x800, 0x1882, 0x0, 0x0, 0x21, 0x21, 0x1, 0x821, 
0x0, 0x0, 0x800, 0x0, 0x841, 0x841, 0x21, 0x1, 0x20, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x0, 0x0, 0x21, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1082, 0x0, 0x3A49, 
0x9515, 0x9578, 0x74D8, 0x3355, 0x22B6, 0x1A97, 0x1236, 0x9B5, 0x996, 
0x155, 0x114, 0x113, 0xD2, 0xB2, 0x91, 0x71, 0x71, 0x51, 
0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xD, 
0xD, 0xE, 0xE, 0x2F, 0x10D2, 0x10F2, 0x1133, 0x1154, 0x934, 
0x2A17, 0x2217, 0x1175, 0x19B5, 0x21F6, 0x19B5, 0x19D6, 0x19D5, 0x2A78, 
0x3ADA, 0x2216, 0x2237, 0x2258, 0x2258, 0x2299, 0x1A77, 0x43D9, 0x8DFE, 
0x84D6, 0x63, 0x21EA, 0x7519, 0x3B78, 0x2B19, 0x3B9B, 0x333A, 0x2AD8, 
0x3339, 0x545C, 0x3B99, 0x3B9B, 0x3338, 0x5C9B, 0x7DBF, 0x64FE, 0x2B79, 
0x4C1C, 0x3BDB, 0x5CBD, 0x5CBD, 0x43BB, 0x4BFC, 0x3B7A, 0x547C, 0x655F, 
0x54FD, 0x655F, 0x7DDE, 0x963C, 0x9E7C, 0x965E, 0x8E5F, 0x96BF, 0x967D, 
0xA69C, 0xBEFB, 0xB616, 0x6B29, 0x800, 0x820, 0x800, 0x1061, 0x801, 
0x1, 0x0, 0x20, 0x1, 0x821, 0x0, 0x0, 0x820, 0x821, 
0x841, 0x821, 0x1, 0x1, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x1062, 0x0, 0x3A28, 0x9514, 0x9577, 0x6CD7, 0x3B75, 
0x1AB6, 0x1A97, 0x1216, 0x9B6, 0x975, 0x134, 0x133, 0xF2, 0xD2, 
0xB2, 0x92, 0x92, 0x892, 0x51, 0x10, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xD, 0xD, 0xE, 0xE, 0xE, 
0x2F, 0x30, 0x30, 0x71, 0x71, 0xD2, 0x91, 0xB2, 0xB2, 
0xD2, 0xB2, 0xD2, 0xD2, 0x113, 0x933, 0xF2, 0x133, 0xF3, 
0x154, 0x134, 0x194, 0x1A54, 0x43B7, 0x8D7B, 0x957A, 0x7D3A, 0x64BA, 
0x9F3, 0x9D5, 0x1B4, 0x194, 0x174, 0x194, 0x1215, 0x9F4, 0x1D4, 
0x1D4, 0x2B16, 0x64DD, 0x2B18, 0xA15, 0x9F5, 0x1B4, 0x2B18, 0x2AF8, 
0x1B4, 0x9F5, 0x1B3, 0x1255, 0x2B58, 0x12B5, 0x2337, 0x22F4, 0x85DC, 
0x85DC, 0x3B95, 0x54BA, 0x759C, 0x4415, 0x7D7A, 0xA67B, 0xD73B, 0xC676, 
0x634A, 0x840D, 0x630A, 0x820, 0x841, 0x821, 0x21, 0x20, 0x821, 
0x1, 0x0, 0x0, 0x0, 0x20, 0x1082, 0x841, 0x0, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x862, 0x861, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x821, 0x1, 0x861, 
0x0, 0x20, 0x42, 0x6413, 0x7D1A, 0x43B7, 0x1234, 0x1236, 0x11F6, 
0x975, 0x134, 0x133, 0x133, 0xD2, 0xB2, 0x92, 0x71, 0x71, 
0x51, 0x30, 0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xF, 0xF, 0x30, 
0x50, 0x50, 0x50, 0x71, 0x71, 0x91, 0x91, 0xB2, 0xB2, 
0xB2, 0xB2, 0xD2, 0xB2, 0x113, 0xD2, 0x154, 0x133, 0x11D5, 
0x1215, 0x1233, 0x64BC, 0x543B, 0x2AD7, 0x1216, 0x195, 0x995, 0x174, 
0x155, 0x154, 0x154, 0x174, 0x175, 0x994, 0x2296, 0x5C7E, 0x2298, 
0x174, 0x9B5, 0x9B5, 0x174, 0x194, 0x9D6, 0x995, 0x11D6, 0x9D5, 
0x1D5, 0x1236, 0xA15, 0x22D6, 0x755D, 0x43F8, 0x1AD6, 0x2B7A, 0x33B9, 
0x2B77, 0x43F9, 0x5437, 0xAE9B, 0xCF3A, 0xCF1A, 0xE7BB, 0xA511, 0x800, 
0x1881, 0x841, 0x0, 0x0, 0x0, 0x0, 0x820, 0x840, 0x860, 
0x1060, 0x3164, 0x20A2, 0x800, 0x821, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x1, 0x10A4, 
0x863, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1061, 0x18E3, 0x0, 0x2, 
0x4ACE, 0x8D38, 0x6457, 0x1212, 0x994, 0x1A17, 0x955, 0x113, 0x113, 
0xD2, 0xD2, 0xB2, 0x92, 0x71, 0x51, 0x50, 0x10, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0x2F, 0xF, 0x30, 0x10, 
0x30, 0x50, 0x70, 0x51, 0x71, 0x71, 0x91, 0x92, 0xB2, 
0x92, 0xD2, 0xB2, 0x133, 0x134, 0x134, 0x2AD9, 0x2B19, 0x153, 
0x11F6, 0x154, 0x134, 0x113, 0x113, 0xF3, 0xF4, 0xF4, 0xF4, 
0x134, 0x134, 0x11D5, 0x32D9, 0x11D6, 0x975, 0x134, 0x954, 0x955, 
0x155, 0x955, 0x155, 0x154, 0x175, 0x996, 0x11F7, 0x174, 0x4BFC, 
0x759F, 0x2337, 0x1277, 0x1298, 0x12B7, 0x2338, 0x1AD6, 0x5CDB, 0xAEFF, 
0x9E5A, 0x9E18, 0xCF5B, 0xB5D4, 0x1880, 0x0, 0x18A2, 0x1082, 0x841, 
0x20, 0x820, 0x820, 0x18C2, 0x20, 0x4226, 0x9490, 0x20C2, 0x800, 
0x1062, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x0, 0x821, 0x18C4, 0x842, 0x0, 0x821, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x18A2, 0x1082, 0x0, 0x31C8, 0x9557, 0x74D9, 
0x2253, 0x152, 0x11B5, 0x954, 0x113, 0xD3, 0xB2, 0xB2, 0xB2, 
0x71, 0x71, 0x51, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0x80E, 0xE, 0xE, 0xF, 
0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 0xF, 0x10, 0xF, 
0x30, 0x30, 0x50, 0x51, 0x71, 0x92, 0x91, 0xD2, 0xB2, 
0xD4, 0xF4, 0x2298, 0x2AF9, 0x154, 0x134, 0x914, 0xD3, 0xD3, 
0xD2, 0xD2, 0xD2, 0x8F3, 0xD3, 0xF3, 0xF3, 0x933, 0x954, 
0xF3, 0x113, 0x113, 0x913, 0x114, 0xF4, 0xF4, 0x114, 0x955, 
0x134, 0x975, 0x975, 0x154, 0x3B7B, 0x43FC, 0x1276, 0x1237, 0x1237, 
0x1278, 0xA35, 0x4C5A, 0x967F, 0x5CFB, 0x3BF6, 0x7DBA, 0xAEDB, 0xCED8, 
0xB592, 0x4A47, 0x820, 0x0, 0x841, 0x881, 0x10A2, 0x800, 0x820, 
0x0, 0xAD72, 0xCE56, 0x820, 0x0, 0x1082, 0x0, 0x0, 0x800, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x821, 0x0, 0x800, 
0x2904, 0x1082, 0x0, 0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 0x0, 
0x841, 0x18A3, 0x20, 0x1904, 0xA5D9, 0x8519, 0x2AB5, 0x173, 0x1195, 
0xF3, 0xF3, 0xB2, 0xB2, 0xB2, 0x71, 0x51, 0x51, 0x10, 
0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0xF, 0x10, 0x10, 
0x31, 0x31, 0x71, 0x91, 0x92, 0x93, 0xD4, 0x2A78, 0x1A16, 
0xF3, 0x8F3, 0xD2, 0xB2, 0xB2, 0x91, 0xB2, 0x92, 0x92, 
0xB2, 0x92, 0xB2, 0xD3, 0xD2, 0xD3, 0xF3, 0xD2, 0xD2, 
0xD3, 0x8F4, 0xD3, 0x113, 0xF3, 0x113, 0x113, 0x934, 0x954, 
0x11D6, 0x1B5, 0x9D5, 0x9D6, 0x11D6, 0x1238, 0x1F5, 0x4C1A, 0x547B, 
0x1B17, 0x341A, 0x655B, 0x85D9, 0xC6F9, 0xD6D7, 0x41E5, 0x0, 0x2102, 
0x0, 0x0, 0x20, 0x1040, 0x20C2, 0x844F, 0xEFBC, 0xCE76, 0x18C0, 
0x0, 0x1082, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x841, 0x800, 0x1060, 0x5247, 0x2923, 0x0, 0x841, 
0x21, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x21, 0x0, 0x861, 0x1061, 0x0, 
0x4289, 0x9536, 0x95BC, 0x19F2, 0x153, 0x1195, 0x913, 0xD3, 0xB2, 
0xB2, 0x71, 0x51, 0x31, 0x30, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0xF, 0x50, 0x50, 
0x71, 0x51, 0xB2, 0x21B6, 0x1175, 0xB2, 0xB2, 0xB2, 0x92, 
0x91, 0x91, 0x92, 0x91, 0x71, 0x92, 0x71, 0xB2, 0xB2, 
0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 0xB2, 0xD2, 
0xD2, 0x133, 0x133, 0xF2, 0x954, 0x954, 0x175, 0x195, 0x995, 
0x995, 0x9D6, 0x1217, 0x9F6, 0xA36, 0x22F9, 0x2B38, 0x3396, 0x64D7, 
0xBEDA, 0xC676, 0x4A46, 0x9CF0, 0xCE15, 0x7B8B, 0x41C4, 0x8C0D, 0x840D, 
0xA574, 0xC6DB, 0xDF9E, 0xCE78, 0x41E6, 0x0, 0x1062, 0x20, 0x0, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1082, 0x800, 
0x3163, 0x8C2C, 0x39C2, 0x0, 0x1061, 0x21, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x21, 
0x0, 0x821, 0x0, 0x821, 0x1082, 0x20, 0x8492, 0xA598, 0x7496, 
0x4B78, 0x132, 0x933, 0x913, 0xD2, 0xB2, 0x91, 0x71, 0x31, 
0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0x2E, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xE, 0xF, 0xF, 0xF, 
0x10, 0x10, 0xF, 0x10, 0x10, 0x50, 0x51, 0x71, 0x8D2, 
0x92, 0x71, 0x91, 0x91, 0x51, 0x91, 0x71, 0x71, 0x891, 
0x71, 0x71, 0x71, 0x72, 0x92, 0x92, 0x92, 0xB2, 0xB2, 
0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 0xD2, 0xF2, 0x112, 
0xF3, 0xF3, 0x955, 0x134, 0x975, 0x995, 0x996, 0x9D6, 0x9F7, 
0x1A78, 0x1AB9, 0x2B38, 0x653C, 0x9E9E, 0xBF1D, 0xBE99, 0xBE58, 0xD71A, 
0xEF7B, 0xAD93, 0xA553, 0xCEDA, 0xB616, 0xC6FB, 0xA65B, 0xB6BC, 0xC679, 
0x6B2B, 0x0, 0x841, 0x21, 0x0, 0x20, 0x0, 0x0, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x0, 0x20, 0x0, 0x18C2, 0x800, 0x5AA8, 0xBDD1, 0x4202, 0x0, 
0x18A2, 0x0, 0x21, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x0, 0x1, 0x1, 0x841, 0x821, 
0x841, 0x841, 0x2945, 0x4AAA, 0x9D98, 0x853B, 0x970, 0x111, 0x913, 
0x8D3, 0x92, 0x92, 0x71, 0x51, 0x31, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x30, 0x50, 0x51, 0x51, 0x50, 0x50, 0x50, 
0x50, 0x50, 0x50, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x71, 0x71, 0x71, 0x92, 0x92, 0x91, 0x92, 0x92, 
0x92, 0xB2, 0xD2, 0xD2, 0xD2, 0xD3, 0xF3, 0xF3, 0x114, 
0x134, 0x155, 0x174, 0x9B6, 0x11F6, 0x1217, 0x1278, 0x2B38, 0x5CD9, 
0xA6FE, 0xAEFD, 0x95D9, 0x9E5E, 0x8599, 0xA618, 0xB6DA, 0xAEBC, 0x9E3B, 
0xAEBD, 0x7D79, 0x6D59, 0x965B, 0xCEFA, 0x842F, 0x0, 0x862, 0x863, 
0x1, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x821, 0x0, 0x20, 0x20, 0x0, 0x18E2, 
0x0, 0x8C0D, 0xDEB6, 0x41C3, 0x800, 0x18A2, 0x0, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 0x1082, 0x0, 0x5B2D, 
0xADB8, 0x7C96, 0x5B95, 0x2213, 0xF2, 0x1114, 0x93, 0x92, 0x92, 
0x51, 0x10, 0x10, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x31, 0x51, 0x31, 0x51, 0x71, 0x71, 
0x71, 0x71, 0x71, 0x91, 0x91, 0x91, 0x92, 0xB2, 0xB2, 
0xD2, 0xD2, 0xD2, 0xF3, 0xF3, 0x114, 0x154, 0x175, 0x9B6, 
0x9B5, 0x1A57, 0x1AB8, 0xA74, 0x4C77, 0xA71F, 0x9E9F, 0x4BF6, 0x4C59, 
0x43F7, 0x7D58, 0xA6BD, 0x64F8, 0x5CFA, 0x75BD, 0x5CDA, 0x54F9, 0x967D, 
0xA5B6, 0x842E, 0x5ACA, 0x0, 0x862, 0x1, 0x820, 0x0, 0x0, 
0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 
0x821, 0x0, 0x0, 0x861, 0x1081, 0x0, 0xB593, 0xEF7A, 0x4205, 
0x0, 0x1882, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x18A3, 0x0, 0x2126, 0x8CD4, 0x8CD5, 0xA5BB, 0x7CDC, 
0x931, 0x8F3, 0x8D3, 0x8B2, 0x92, 0x31, 0x51, 0x10, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 
0x30, 0x30, 0x30, 0x31, 0x50, 0x51, 0x71, 0x71, 0x71, 
0x71, 0x71, 0x71, 0x91, 0x92, 0xB2, 0xB2, 0xB2, 0xD3, 
0xD3, 0xF3, 0x114, 0x135, 0x155, 0x11D7, 0x1236, 0x233, 0x33F9, 
0x7DFF, 0x757D, 0x5C9B, 0x43B9, 0x2318, 0x2316, 0x7D9C, 0x85FD, 0x3BB8, 
0x33BA, 0x33DA, 0x3BFA, 0x447B, 0x64F9, 0xBE9A, 0xE73A, 0x8C6F, 0x20, 
0x1082, 0x841, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x801, 0x801, 0x801, 0x1, 0x1082, 
0x40, 0x18E2, 0xD6D9, 0xEF9D, 0x4A69, 0x800, 0x18A2, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x820, 0x0, 
0x10C3, 0x2987, 0x29C8, 0x9DBA, 0x9E3F, 0x4BB9, 0x70, 0x1134, 0x92, 
0x91, 0x871, 0x51, 0x30, 0x10, 0x10, 0x10, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 
0x30, 0x50, 0x51, 0x51, 0x51, 0x51, 0x71, 0x71, 0x71, 
0x92, 0x92, 0x92, 0xB2, 0xB2, 0xD2, 0xF3, 0xF3, 0x135, 
0x976, 0x9B6, 0x1D4, 0x3C19, 0x867F, 0x5CFD, 0xA54, 0x22D7, 0x1AB7, 
0x231A, 0xA76, 0x757E, 0x85FF, 0x2317, 0x233A, 0x237A, 0x2B9A, 0x3C1A, 
0x6D5B, 0xAE3A, 0x8C90, 0x18E1, 0x10A0, 0x18C2, 0x20, 0x0, 0x820, 
0x800, 0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 
0x1, 0x801, 0x1, 0x1, 0x18A2, 0x0, 0x636D, 0xEFDE, 0xE77D, 
0x5AEB, 0x0, 0x1082, 0x1, 0x21, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x18C2, 0x0, 0x10E4, 0xA576, 0x8D37, 
0x5C16, 0x32F5, 0x6E, 0x1974, 0xB2, 0x8B2, 0x72, 0x51, 0x30, 
0x10, 0x10, 0x10, 0xF, 0x2F, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x10, 0x10, 0x10, 0x30, 0x30, 0x30, 0x50, 
0x50, 0x50, 0x50, 0x51, 0x71, 0x71, 0x91, 0x92, 0x92, 
0x92, 0xB2, 0xF2, 0x113, 0x135, 0x955, 0x1A18, 0x22B7, 0x6D9F, 
0x865F, 0x2337, 0x1A97, 0x1A77, 0x1257, 0xA58, 0xA57, 0x3BBA, 0x3BDA, 
0x1AD7, 0x1B19, 0x2339, 0x2338, 0x651C, 0x9EBF, 0xA61B, 0x7C72, 0x94D1, 
0x73AC, 0x820, 0x0, 0x1062, 0x0, 0x801, 0x801, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x20, 0x1, 0x821, 0x0, 0x1082, 
0x0, 0x2103, 0x9D95, 0xE7DE, 0xDF5D, 0x73CF, 0x0, 0x1082, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x20, 0x41, 0x7C30, 0x9556, 0x4351, 0x3313, 0x3295, 0x111, 
0x8F2, 0x8D2, 0x72, 0x52, 0x50, 0x30, 0x10, 0x10, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x50, 
0x51, 0x71, 0x71, 0x72, 0x92, 0x92, 0xB2, 0xB1, 0xF2, 
0x114, 0x955, 0x19F6, 0x5C7E, 0x861F, 0x549B, 0x22D7, 0xA36, 0x1237, 
0x1237, 0xA37, 0xA57, 0xA36, 0xA16, 0x1297, 0x1AD8, 0x1AB8, 0x2318, 
0x5CDC, 0x64D9, 0x7518, 0xB65B, 0xDF3B, 0xC615, 0x5289, 0x820, 0x842, 
0x821, 0x801, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x20, 0x21, 0x0, 0x841, 0x861, 0x0, 0x634C, 0xBEDB, 0xC75D, 
0xCEFB, 0x7C0F, 0x0, 0x841, 0x841, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x1903, 0x0, 0x638D, 
0xAE18, 0x8D57, 0x959B, 0x959D, 0x5BB8, 0x6F, 0x913, 0xB2, 0x92, 
0x71, 0x30, 0x10, 0x10, 0x10, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x30, 0x30, 0x30, 0x30, 0x50, 0x51, 0x71, 0x71, 
0x71, 0x92, 0x92, 0xB2, 0xF2, 0x113, 0x974, 0xF1, 0x5C3C, 
0x7D9F, 0x1A95, 0xA15, 0x11F6, 0x11F6, 0x195, 0x1F6, 0x1D6, 0x1A37, 
0x11F6, 0xA17, 0x1278, 0x1A98, 0x1AD8, 0x12D7, 0x2B78, 0x4417, 0x7D59, 
0xC69A, 0xC637, 0x840F, 0x20, 0x1, 0x842, 0x21, 0x0, 0x1, 
0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x801, 0x0, 0x820, 0x861, 
0x0, 0x5247, 0x9512, 0xB6FC, 0xAEDC, 0xC6DB, 0x94B2, 0x2104, 0x800, 
0x1061, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x1081, 0x20, 0x4AAA, 0x52CA, 0x4268, 0xA555, 0xB65B, 
0x74B9, 0x951, 0xD2, 0xD2, 0x70, 0x70, 0x30, 0x10, 0x810, 
0x810, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x30, 0x30, 0x50, 0x51, 0x51, 0x71, 0x72, 0x92, 0xB2, 
0xD2, 0x113, 0x112, 0x32B8, 0x647D, 0x541C, 0x2B18, 0x194, 0x995, 
0x994, 0x995, 0x9B5, 0x9B5, 0x11B6, 0x11B6, 0x11F7, 0x1217, 0x1237, 
0x1AB9, 0x233A, 0x2BBA, 0x5D1B, 0x963C, 0xCEBA, 0x736B, 0x800, 0x1061, 
0x0, 0x10A2, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x801, 0x801, 0x820, 0x840, 0x1881, 0x2944, 0x7C0E, 0xB658, 0x9E7C, 
0x963B, 0xB69A, 0x9D34, 0x4227, 0x0, 0x1061, 0x820, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 
0x0, 0x0, 0x18C2, 0x9D55, 0x9DB9, 0x9DDE, 0x4B38, 0x70, 0x112, 
0xB1, 0x70, 0x30, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x30, 0x50, 
0x51, 0x51, 0x51, 0x71, 0x91, 0xF3, 0x92, 0x913, 0x433A, 
0x2A56, 0x153, 0x9B5, 0x974, 0x954, 0x954, 0x954, 0x975, 0x975, 
0x975, 0x1195, 0x11D6, 0x11D6, 0x1A37, 0x1AB8, 0x1B17, 0x1B14, 0x64F7, 
0xAE59, 0xBDF5, 0x7309, 0x1000, 0x4A06, 0x632A, 0x0, 0x1061, 0x841, 
0x0, 0x821, 0x0, 0x0, 0x21, 0x0, 0x20, 0x0, 0x0, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x0, 0x21, 0x0, 0x801, 0x1, 0x1062, 0x0, 
0x800, 0x7BCD, 0xA5D6, 0x9E5A, 0x7DDB, 0x7DBB, 0xA67B, 0xA5F7, 0x5ACA, 
0x800, 0x18A2, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x841, 0x861, 0x0, 0x7C51, 0xB63A, 0x84F8, 
0x3B14, 0x74FE, 0x4B3A, 0x70, 0x8F3, 0x91, 0x70, 0x30, 0x30, 
0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x30, 0x30, 0x30, 0x50, 0x50, 0x51, 0x71, 
0xB2, 0x91, 0xD2, 0x913, 0x912, 0x112, 0x134, 0x134, 0x134, 
0x113, 0x133, 0x934, 0x134, 0x155, 0x954, 0x975, 0x11B5, 0x11D6, 
0x1A37, 0x1276, 0x33B8, 0x651B, 0x963C, 0xB6BB, 0x844F, 0x9C8F, 0x9490, 
0xA532, 0xC635, 0x4A67, 0x820, 0x0, 0x841, 0x0, 0x821, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x0, 0x18A3, 0x0, 0x2923, 0x7BCC, 0x8CB0, 0x9DF9, 0x7D9A, 
0x657B, 0x6D7B, 0x85D9, 0x9596, 0x7C0F, 0x20C2, 0x0, 0x862, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x18C3, 0x20, 0x636E, 0xA5FA, 0x5416, 0x2AD6, 0x1A77, 0x11B5, 0x933, 
0x8B2, 0x92, 0x91, 0x50, 0x30, 0x10, 0xE, 0x2F, 0xE, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x30, 0x30, 0x30, 0x50, 0x51, 0x71, 0x91, 0x92, 0xB2, 
0xB2, 0xF3, 0xF3, 0xF3, 0xF3, 0xF3, 0x113, 0x113, 0x114, 
0x134, 0x154, 0x974, 0x975, 0x11D6, 0x1215, 0x43DA, 0x969F, 0x969F, 
0x7DBC, 0x9E3C, 0xAE19, 0xBE79, 0xBEFB, 0xC6FA, 0xCEF9, 0x73CC, 0x0, 
0x20E3, 0x18A1, 0x1061, 0x821, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1082, 0x0, 0x800, 
0x1040, 0xADD3, 0xAE58, 0x7D7A, 0x5D1C, 0x551C, 0x5D1B, 0x7DDA, 0x9E19, 
0x8C91, 0x800, 0x0, 0x862, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x1, 0x0, 0x0, 0x21, 0x0, 0x1062, 0x0, 0x4249, 0x7494, 
0x6476, 0x1A74, 0xA16, 0x194, 0x154, 0xF4, 0xD3, 0xB2, 0x71, 
0x50, 0x10, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 0x30, 
0x50, 0x51, 0x91, 0x71, 0xB2, 0x92, 0xD2, 0xB2, 0xD3, 
0xD3, 0xF3, 0xF3, 0x113, 0x114, 0x114, 0x134, 0x174, 0x1195, 
0x11D5, 0x1D4, 0x757F, 0xA71F, 0x43F7, 0x2314, 0x3B95, 0x857A, 0x961B, 
0x7537, 0x963A, 0xA617, 0x5B6C, 0x9D54, 0x31C6, 0x0, 0x800, 0x820, 
0x821, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x861, 0x1081, 0x0, 0x2103, 0x8C0E, 0x9CD1, 0x84D1, 0x95D8, 0x5CBA, 
0x4C9C, 0x4CBC, 0x54BB, 0x757A, 0x7CF5, 0x6B8D, 0x5268, 0x0, 0x862, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x821, 0x10A3, 0x0, 0x39E8, 0xA5F8, 0x8D78, 0x4BD6, 0x22B4, 0x2294, 
0x992, 0xF2, 0xD3, 0xB2, 0x91, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x31, 0x51, 0x70, 
0x91, 0x71, 0x91, 0xB1, 0xB2, 0xB3, 0xB3, 0xD2, 0xF3, 
0xF3, 0xF3, 0x133, 0x153, 0x174, 0x174, 0x3319, 0x64FF, 0x441B, 
0x1275, 0x22F7, 0x22D6, 0x549B, 0x4C59, 0x3BB6, 0x7DDD, 0x963C, 0xAE9B, 
0xBEBB, 0x9513, 0x630A, 0x1881, 0x0, 0x801, 0x842, 0x0, 0x0, 
0x820, 0x20, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x21, 
0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x1, 0x21, 
0x0, 0x0, 0x0, 0x820, 0x820, 0x0, 0x0, 0x0, 0x840, 
0xC5F6, 0xD6FA, 0x95B7, 0x5C97, 0x4C5A, 0x443C, 0x4C5C, 0x4C5A, 0x64D9, 
0x95B9, 0xCE58, 0x944F, 0x0, 0x18A3, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x861, 0x0, 0x4A49, 
0xB617, 0x84B2, 0x9DB8, 0xA5FA, 0x95D8, 0x7D39, 0x3274, 0x70, 0x91, 
0x892, 0x50, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x851, 0x50, 0x2F, 0x92, 0x92, 0x71, 
0xB1, 0x92, 0xB2, 0xB2, 0xD3, 0xD3, 0xF3, 0x113, 0x133, 
0x153, 0x174, 0x1A36, 0x194, 0x1D5, 0x1298, 0x1277, 0x1AB8, 0x1AB7, 
0x1B17, 0x33DA, 0x4C7B, 0x6519, 0x8DD9, 0xB69A, 0xE7BD, 0xDEF9, 0x8C2E, 
0x20C3, 0x821, 0x0, 0x18A3, 0x1062, 0x0, 0x20, 0x20, 0x0, 
0x20, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x21, 0x0, 0x0, 0x1, 0x0, 0x841, 0x861, 0x861, 0x1061, 
0x1040, 0x2923, 0x5268, 0x9490, 0x6B4C, 0x8CB1, 0xA5F8, 0x755A, 0x4C59, 
0x3BBA, 0x3BFC, 0x3BFB, 0x3BFA, 0x5CBA, 0x8558, 0x73EF, 0x3143, 0x1882, 
0x841, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x0, 0x20, 0x1082, 0x0, 0x41E7, 0x52A9, 0x0, 0x73CE, 0x9D54, 
0xAE37, 0xB69B, 0x8D3C, 0x2A35, 0x71, 0x892, 0x50, 0x2F, 0x10, 
0xF, 0xF, 0x2F, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0xF, 0xF, 0x10, 0x10, 0x31, 
0x50, 0x50, 0x11, 0x32, 0x71, 0x91, 0x91, 0x92, 0xB2, 
0xB2, 0xB3, 0xD3, 0xF3, 0xF3, 0x133, 0x153, 0x155, 0x9B6, 
0x11F7, 0x11F6, 0x1217, 0x1257, 0x1A98, 0x2B19, 0x2379, 0x2BB9, 0x4C98, 
0x8DFA, 0xCEFB, 0xC636, 0x83ED, 0x4A47, 0x20C3, 0x1062, 0x18A3, 0x0, 
0x0, 0x18C3, 0x821, 0x841, 0x0, 0x20, 0x0, 0x0, 0x20, 
0x0, 0x20, 0x20, 0x0, 0x0, 0x0, 0x0, 0x821, 0x821, 
0x821, 0x0, 0x820, 0x0, 0x0, 0x800, 0x41E6, 0xB573, 0xEF7A, 
0xC678, 0x8556, 0x5C96, 0x3BD7, 0x33DA, 0x33BB, 0x2B9A, 0x33BA, 0x33FA, 
0x449A, 0x6D59, 0x7C71, 0xA553, 0x52A9, 0x0, 0x841, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x0, 0x20, 0x0, 0x20, 0x1081, 
0x0, 0x0, 0x20, 0x800, 0x83EF, 0xBE79, 0xA61A, 0x6457, 0x2213, 
0x91, 0x8B2, 0x71, 0x30, 0x30, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0xF, 0x51, 0x52, 0x52, 
0x51, 0x71, 0x71, 0x91, 0x92, 0x92, 0xB2, 0xB3, 0xD3, 
0xF2, 0x112, 0x133, 0x155, 0x976, 0x975, 0x9B6, 0x9F6, 0x1237, 
0x1A57, 0x22B8, 0x2338, 0x4439, 0x54B8, 0x9E3B, 0xB616, 0x6B29, 0x800, 
0x800, 0x1061, 0x0, 0x2924, 0x5ACB, 0x18A2, 0x0, 0x841, 0x841, 
0x0, 0x861, 0x1061, 0x840, 0x1082, 0x1062, 0x0, 0x841, 0x861, 
0x861, 0x861, 0x1082, 0x1061, 0x821, 0x0, 0x820, 0x0, 0x820, 
0x7BCE, 0x5AEA, 0x820, 0xA553, 0xCEB9, 0xB6BB, 0x8DFC, 0x3BB7, 0x3399, 
0x2359, 0x2B5A, 0x2359, 0x2B7A, 0x2BB9, 0x33F8, 0x5497, 0xB639, 0xDEFA, 
0x7BEE, 0x0, 0x841, 0x821, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x20, 0x0, 0x0, 0x1081, 0x0, 0x4207, 0x5AEB, 0x0, 0x6B6D, 
0xB618, 0x9578, 0x9E1C, 0x7D3B, 0x32B4, 0x90, 0x8B2, 0x71, 0x30, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x30, 0x30, 0x31, 0x31, 0x51, 0x51, 0x71, 0x71, 
0x71, 0x92, 0x92, 0xB2, 0xD2, 0xD2, 0xF2, 0x113, 0x914, 
0x935, 0x975, 0x9B6, 0x9F6, 0x1237, 0x1236, 0x2B38, 0x7DBF, 0x9EBF, 
0x961A, 0xC6FB, 0xC656, 0x4A46, 0x800, 0x20C3, 0x1081, 0x0, 0x0, 
0xA4F2, 0xB594, 0x5248, 0x2924, 0x0, 0x18A2, 0x0, 0x0, 0x18C2, 
0x0, 0x0, 0x821, 0x1, 0x0, 0x861, 0x0, 0x0, 0x0, 
0x0, 0x821, 0x3985, 0x946E, 0x94CF, 0xBE56, 0xB616, 0x8C6F, 0x84B2, 
0x7D58, 0x85BC, 0x755E, 0x3358, 0x2B18, 0x2B19, 0x22F8, 0x2339, 0x2339, 
0x2B79, 0x3BF8, 0x7539, 0x8CB3, 0x7BAD, 0x28E3, 0x800, 0x841, 0x1, 
0x821, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x800, 0x0, 0x0, 0x0, 0x0, 0x1081, 
0x20, 0x4A48, 0xBE17, 0x8D14, 0x9DB8, 0x7D38, 0x4395, 0x5C9A, 0xA69F, 
0x645A, 0x6F, 0x10D2, 0x871, 0x30, 0x50, 0xF, 0x2F, 0xE, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 
0x30, 0x30, 0x51, 0x51, 0x71, 0x71, 0x71, 0x92, 0xB2, 
0xB2, 0xD2, 0xF2, 0x113, 0x914, 0x934, 0x175, 0x195, 0x9D6, 
0x1216, 0xA15, 0x43DB, 0x8E5F, 0x755B, 0x9E1B, 0xBE9A, 0x94D0, 0x31A3, 
0x0, 0x1081, 0x1041, 0x2103, 0x0, 0x8450, 0xEFBD, 0xBE37, 0x7BCE, 
0x94B2, 0x39C6, 0x2103, 0x31A6, 0x0, 0x820, 0x2944, 0x801, 0x18A3, 
0x2104, 0x0, 0x1061, 0x39A5, 0x5AEA, 0x7BCD, 0x3144, 0x800, 0x9CCF, 
0xD6D6, 0xBE98, 0xCF3B, 0xB657, 0x9DD8, 0x5477, 0x22F5, 0x2AF8, 0x2AF8, 
0x22B7, 0x1AB7, 0x22F8, 0x1AD8, 0x2319, 0x2B59, 0x3357, 0x7D5B, 0x7C74, 
0x6B4D, 0x7BAE, 0x5AAA, 0x0, 0x0, 0x821, 0x0, 0x0, 0x20, 
0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x800, 0x0, 0x0, 0x0, 0x18A2, 0x0, 0x2985, 0x9D54, 0x9DB8, 
0x857A, 0x43D7, 0x1A95, 0xA33, 0x6CFD, 0x4B78, 0x4F, 0x10B2, 0x871, 
0x30, 0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x50, 0x51, 
0x51, 0x71, 0x71, 0x91, 0x92, 0xB2, 0xD2, 0xF2, 0xF3, 
0xF3, 0x114, 0x155, 0x195, 0x9B5, 0x9F6, 0x1236, 0x22D8, 0x22F7, 
0x2B15, 0x6D1A, 0xA63A, 0xCED8, 0xA551, 0x18C2, 0x800, 0x800, 0x800, 
0x2944, 0x8CD1, 0xBF1B, 0xB6BA, 0xC69A, 0xD6DA, 0x3184, 0x948F, 0xB574, 
0x94B0, 0xBDB2, 0x5AA7, 0x800, 0x0, 0x8C70, 0xAD74, 0x9D12, 0x5AE9, 
0xCEB8, 0xC677, 0x2101, 0x20, 0x94AE, 0xBE36, 0x9556, 0xB69B, 0xAE7A, 
0x6474, 0x2B34, 0x2B58, 0x22F8, 0x1A98, 0x1AB8, 0x1AB8, 0x1298, 0x1AB9, 
0x22B9, 0x22FA, 0x2B3A, 0x43D9, 0x7D18, 0xAE39, 0xCED9, 0x7C2E, 0x20, 
0x0, 0x841, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x18A2, 0x800, 0x5AEA, 0xA5B6, 0x74B5, 0x22B4, 0x1A97, 0x1A77, 0x1A36, 
0x32D8, 0x21F5, 0x91, 0x892, 0x851, 0x31, 0x30, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x30, 0x30, 0x30, 0x51, 0x51, 0x51, 0x71, 0x71, 
0x91, 0xB2, 0xB2, 0xD2, 0xF3, 0xF3, 0x114, 0x154, 0x175, 
0x9B5, 0x9F6, 0x1216, 0x1A57, 0x1A97, 0x3398, 0x4C58, 0x85BA, 0xD73B, 
0xC676, 0x4206, 0x820, 0x3143, 0x1880, 0x840E, 0xC6BA, 0x963A, 0x7557, 
0xAE5A, 0xB619, 0x740F, 0xB617, 0xC699, 0xDF3A, 0xBDF3, 0x1040, 0x1040, 
0x800, 0x5AEA, 0xDF5A, 0xCEFA, 0xA5D6, 0xBEBA, 0xB658, 0xADB4, 0x94F0, 
0x8C90, 0xADF7, 0x6C55, 0x961D, 0xB71F, 0x755A, 0x1AD5, 0x1AB7, 0x1A78, 
0x1A78, 0x1278, 0x1278, 0x1278, 0x1278, 0x1A98, 0x22D9, 0x22FA, 0x3358, 
0x5C15, 0xA5F8, 0xCEF9, 0xB5F5, 0x52A9, 0x0, 0x10A2, 0x20, 0x0, 
0x1, 0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x1, 0x0, 0x1, 0x841, 0x820, 0x31A6, 0x638E, 
0x7CF7, 0x4BFA, 0x9F6, 0x9F6, 0x9B6, 0x113, 0xF2, 0xD2, 0x92, 
0x51, 0x31, 0x30, 0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 
0x30, 0x31, 0x51, 0x51, 0x71, 0x92, 0xB2, 0xB2, 0xB3, 
0x8D3, 0xF3, 0x114, 0x934, 0x975, 0x9B5, 0x11D5, 0x11F6, 0x1A77, 
0x22F8, 0x2337, 0x2B96, 0x5CB7, 0xAE7A, 0xB615, 0x39C4, 0x5265, 0xCE34, 
0xBE13, 0x9D31, 0xC6FC, 0x64F9, 0x4C78, 0x8E1B, 0xA67C, 0x95DB, 0x8D9A, 
0x8DD9, 0xC71B, 0xAD72, 0x1840, 0x800, 0x18C2, 0x630A, 0xB657, 0x9E1A, 
0x8DBB, 0x753A, 0x95DB, 0xCEFB, 0xADD6, 0xADF8, 0x8D59, 0x2B15, 0x43F9, 
0x7D7E, 0x5C7B, 0xA36, 0x1278, 0x1A58, 0x1217, 0x1237, 0x1258, 0x1279, 
0x1279, 0x1AB8, 0x1AB7, 0x22D8, 0x3377, 0x74D6, 0xA5D6, 0x9D32, 0x5AA9, 
0x2103, 0x0, 0x1081, 0x0, 0x0, 0x1, 0x0, 0x0, 0x1, 
0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 
0x821, 0x1082, 0x0, 0x6B6D, 0x9555, 0x959A, 0x5C3B, 0x11D5, 0x19F7, 
0x975, 0x954, 0x113, 0xD2, 0x71, 0x51, 0x31, 0x30, 0x30, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x31, 0x51, 
0x71, 0x72, 0x92, 0x92, 0xB3, 0xD3, 0xF4, 0x114, 0x154, 
0x975, 0x9B5, 0x11F6, 0x1A57, 0x1A97, 0x1AD7, 0x54BC, 0x6DBE, 0x6518, 
0xAE9A, 0xCEF9, 0xA531, 0xC634, 0xD738, 0xC6D8, 0xAE37, 0x95B9, 0x4C18, 
0x2B77, 0x75BC, 0x85FD, 0x43D7, 0x4418, 0x861D, 0xAEDD, 0x9D34, 0xAD32, 
0x4A26, 0x62E9, 0xBE56, 0xAE38, 0x64D8, 0x4C38, 0x5499, 0x85BC, 0xB6BC, 
0xAE3A, 0x9DFC, 0x5418, 0x1295, 0xA76, 0xA15, 0x1236, 0x1258, 0x1218, 
0x1A17, 0x19F7, 0x1217, 0x9F7, 0x1238, 0xA38, 0x1256, 0x1AB7, 0x1276, 
0x5C7B, 0xA63B, 0x534C, 0x6B6C, 0x2103, 0x820, 0x41E6, 0x800, 0x1040, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x842, 0x821, 0x820, 0x7BEF, 
0x9DD8, 0x74D8, 0x4356, 0x1A35, 0x11F6, 0x995, 0x134, 0x113, 0xB2, 
0x71, 0x51, 0x51, 0x10, 0xF, 0xF, 0x80F, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x30, 0x51, 0x51, 0x71, 0x92, 0xB2, 
0xB3, 0xD3, 0x114, 0x134, 0x154, 0x995, 0x9D6, 0x1237, 0x1257, 
0x1AB8, 0x22F8, 0x5CBC, 0x9E9F, 0xB6FC, 0xBED9, 0xBE56, 0xCEB8, 0xCEDA, 
0x7D36, 0x8E1B, 0x9E9D, 0x43D4, 0x3377, 0x2318, 0x3398, 0x33D9, 0x2B79, 
0x33BA, 0x54BB, 0x6D5B, 0x9DFA, 0xD75C, 0xB5D3, 0x7C0C, 0xCF3A, 0x9619, 
0x43F7, 0x3BD7, 0x5CD8, 0xAEFF, 0xAEFE, 0x74F8, 0x2AD4, 0x22D7, 0x1AB6, 
0x1A97, 0x1A37, 0x11F7, 0x1217, 0x9F6, 0x11D6, 0x11D6, 0x11F6, 0x11F7, 
0x1217, 0x1238, 0x1237, 0x1A98, 0x1237, 0x4BDB, 0x8D7B, 0x7CB4, 0x9D34, 
0x8C90, 0xA553, 0x9471, 0x800, 0x1882, 0x801, 0x0, 0x840, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x21, 
0x0, 0x861, 0x0, 0x840, 0x8CD2, 0x8D58, 0x4374, 0x2AD3, 0x1A33, 
0x173, 0x995, 0x1195, 0x933, 0xD2, 0x92, 0x52, 0x31, 0x30, 
0xF, 0xF, 0x80F, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 
0x31, 0x51, 0x71, 0x92, 0x92, 0xD2, 0xF3, 0x114, 0x134, 
0x174, 0x994, 0x11F5, 0x1256, 0x1296, 0x1AF7, 0x2337, 0x4C18, 0x9E5C, 
0xAEDB, 0xAE9B, 0xB67A, 0xBEDA, 0x9DF9, 0x4C36, 0x4C9A, 0x969F, 0x547A, 
0x1A75, 0x22F8, 0x1AB7, 0x12B7, 0x233A, 0x2359, 0x33FA, 0x4438, 0x8DDA, 
0xC71C, 0xB635, 0xA593, 0xAE9A, 0x6D18, 0x22F5, 0x1AD5, 0x5C98, 0xAF1F, 
0x8E1C, 0x5457, 0x2B17, 0x1277, 0xA15, 0x1216, 0x9D6, 0x11D7, 0x9D6, 
0x11D6, 0x11B6, 0x995, 0x11B6, 0x11D6, 0x9B6, 0x11F7, 0x1217, 0x1217, 
0x1A78, 0x1A76, 0x3AF4, 0x7CF9, 0xA61A, 0xC6FB, 0xC69A, 0x636D, 0x820, 
0x800, 0x841, 0x1, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x10A3, 0x0, 0x4A68, 
0xC699, 0xA5FA, 0x8D9A, 0x8D9A, 0x7D3A, 0x4378, 0x9B3, 0xD1, 0x932, 
0x913, 0xF3, 0x72, 0x31, 0x30, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x51, 0x51, 0x71, 
0x92, 0xB2, 0xF2, 0x114, 0x134, 0x9B4, 0x2AB7, 0x1213, 0x541A, 
0x7DFF, 0x655C, 0x75BD, 0xA6FF, 0xAF1F, 0x967D, 0x651A, 0x5C98, 0x9E5C, 
0xAEFF, 0x43F8, 0x1295, 0x4C1C, 0x43BB, 0x1215, 0x1A77, 0x1A78, 0x22B8, 
0x1AF9, 0x1B38, 0x2BB8, 0x3BD6, 0x95D9, 0xAE59, 0xA5F7, 0xBEFD, 0x8DBC, 
0x3B56, 0x22B6, 0x1296, 0x22B5, 0x85DF, 0xA6BF, 0x9E9F, 0x43BA, 0x194, 
0x11F6, 0x9D5, 0x1B5, 0x9D6, 0x996, 0x995, 0x995, 0x995, 0x9B5, 
0x9B6, 0x11B6, 0x11B6, 0x11D7, 0x1217, 0x1277, 0x1AB7, 0x22B7, 0x4398, 
0x755B, 0x8DBA, 0xA5FA, 0xB618, 0x8C70, 0x0, 0x0, 0x842, 0x1, 
0x1, 0x800, 0x800, 0x0, 0x0, 0x0, 0x1, 0x0, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x21, 0x1, 0x1082, 0x0, 0x73AE, 0x842F, 0x4249, 0x740F, 0x9D74, 
0xAE5A, 0x751B, 0x1A94, 0x43B9, 0x992, 0x70, 0x8F4, 0x72, 0x52, 
0x31, 0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x30, 0x31, 0x51, 0x71, 0x71, 0x92, 0x8D2, 0xB2, 0x955, 
0x995, 0x194, 0x4BBA, 0x6D1D, 0x965F, 0x7DDE, 0x653B, 0x861F, 0x7DDD, 
0x8E1E, 0x4C37, 0x2B78, 0x12D5, 0x757B, 0x7D9C, 0x1A95, 0x1257, 0x1B5, 
0x9B6, 0x1A17, 0x11F6, 0x11F6, 0x1A57, 0x1AB8, 0x2338, 0x655D, 0x8E5F, 
0xA69D, 0xC75F, 0x7D39, 0x753B, 0x6CDC, 0x9B2, 0x1A97, 0x1256, 0x1A77, 
0x1213, 0x5438, 0x753C, 0x1214, 0x9D5, 0x11D6, 0x975, 0x1B5, 0x195, 
0x195, 0x975, 0x974, 0x994, 0x995, 0x995, 0x996, 0x11B6, 0x11D7, 
0x9D6, 0xA36, 0x1A97, 0x22D8, 0x3338, 0x3374, 0x6CF7, 0x8D56, 0xADD7, 
0x94D1, 0x41E6, 0x0, 0x1083, 0x21, 0x1, 0x800, 0x800, 0x0, 
0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x821, 0x0, 0x18A3, 
0x2924, 0x0, 0x0, 0x0, 0x7BED, 0xD71A, 0x6C95, 0x6CF9, 0x961E, 
0x3B35, 0x3AB8, 0x8D2, 0x71, 0x72, 0x31, 0x10, 0x30, 0xE, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x51, 0x71, 
0x71, 0x92, 0x92, 0x8F3, 0x113, 0x154, 0x9F5, 0x22B6, 0x85FF, 
0x75BE, 0x2316, 0xA75, 0xA75, 0x1275, 0x4BFA, 0x1A95, 0x214, 0x1AD6, 
0x75BE, 0x54BB, 0x1B3, 0x1217, 0x11D7, 0x19F7, 0x176, 0x11D7, 0x11F7, 
0x1216, 0xA35, 0x4C7B, 0x9EDF, 0x967E, 0x861E, 0x651B, 0x2B57, 0x22F7, 
0x2AF7, 0x1215, 0x11F5, 0x9D6, 0x11D6, 0x194, 0x1A35, 0x1A96, 0x194, 
0x9B5, 0x174, 0x995, 0x174, 0x175, 0x175, 0x155, 0x954, 0x954, 
0x975, 0x975, 0x995, 0x996, 0x9B6, 0x11F7, 0x1216, 0x1256, 0x1AB6, 
0x3355, 0x6C96, 0xA638, 0xADF5, 0x4206, 0x800, 0x20E3, 0x0, 0x20, 
0x840, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x21, 0x0, 0x821, 0x820, 0x800, 0x0, 0x18A3, 0x18A3, 0x800, 
0x41E8, 0x94B1, 0xB637, 0xAE58, 0x9E3A, 0x95DC, 0x53B9, 0x6F, 0x10D2, 
0x851, 0x30, 0x30, 0xE, 0x80F, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x30, 0x51, 0x51, 0x71, 0x92, 0xB3, 0xD3, 
0x1194, 0x1A36, 0x1B3, 0x441A, 0x8E9F, 0x5CDB, 0x1296, 0x1278, 0x1298, 
0x1257, 0x11F5, 0x1236, 0xA16, 0x1D4, 0x3398, 0x547C, 0x9D5, 0x175, 
0x996, 0x955, 0x996, 0x9B6, 0x11D6, 0x1A16, 0x9F4, 0x64FD, 0xA6FF, 
0x5476, 0x1AF3, 0x12D5, 0x1297, 0x1F6, 0x1B4, 0x11F6, 0x995, 0x11B5, 
0x975, 0x11B6, 0x175, 0x154, 0x195, 0x175, 0x134, 0x934, 0x954, 
0x134, 0x154, 0x154, 0x934, 0x954, 0x154, 0x174, 0x175, 0x995, 
0x995, 0x996, 0x11F7, 0x1236, 0x1AB4, 0x7D5A, 0xA5F8, 0xADB4, 0x94D0, 
0x20E1, 0x800, 0x800, 0x4A47, 0x1080, 0x0, 0x820, 0x0, 0x0, 
0x0, 0x20, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x0, 0x0, 0x21, 0x1, 0x821, 0x0, 0x820, 
0x39C6, 0x20E3, 0x0, 0x18C4, 0x801, 0x800, 0x841, 0x9D52, 0xAE36, 
0xBF1C, 0x9E3C, 0x53F8, 0x3AF8, 0x70, 0x871, 0x50, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 
0x50, 0x71, 0x91, 0xD2, 0xD1, 0x32F8, 0x5C7C, 0x549B, 0x75DF, 
0x75BE, 0x3BD9, 0x1A77, 0x1218, 0x9D6, 0x9B5, 0x994, 0x9B5, 0x195, 
0x195, 0x153, 0x9B5, 0x175, 0x155, 0x974, 0x154, 0x174, 0x174, 
0x974, 0x11B4, 0x9F4, 0x4BF9, 0x9EBF, 0x85FD, 0x22F5, 0x1A96, 0x1238, 
0x11F8, 0x11B6, 0x954, 0x974, 0x133, 0x154, 0x134, 0x134, 0x975, 
0x114, 0x934, 0x934, 0x8F3, 0x113, 0x133, 0x134, 0x134, 0x914, 
0x934, 0x154, 0x154, 0x154, 0x975, 0x995, 0x9B6, 0x11F7, 0x9F5, 
0x4396, 0xA65C, 0xA554, 0x5AA8, 0x942E, 0x732A, 0x4206, 0x6B4B, 0xA511, 
0x1040, 0x0, 0x1062, 0x40, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x1, 0x1, 
0x1, 0x1, 0x1082, 0x0, 0x18E1, 0xAD73, 0x5B2A, 0x20, 0x20, 
0x0, 0x9490, 0xB5D5, 0xAE18, 0xB69B, 0xA65B, 0x859A, 0x7D7E, 0x5C1C, 
0x91, 0x892, 0x50, 0x2F, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x71, 0x91, 0x91, 
0x112, 0x19F5, 0x2AD7, 0x4C5A, 0x759E, 0x5CDB, 0x1F2, 0x1217, 0x11D7, 
0x995, 0x994, 0x995, 0x154, 0x135, 0x155, 0x955, 0x114, 0x955, 
0x134, 0x112, 0x133, 0x133, 0x133, 0x975, 0x133, 0x1215, 0x545B, 
0x8DDF, 0x8E1F, 0x7DBF, 0x3379, 0x9B5, 0x996, 0x955, 0x935, 0x134, 
0x154, 0x954, 0x113, 0x114, 0x114, 0x114, 0xF4, 0xF3, 0x913, 
0xF3, 0x113, 0x113, 0x113, 0x113, 0x114, 0x134, 0x154, 0x154, 
0x954, 0x974, 0x995, 0x11D7, 0x173, 0x64BB, 0xA65D, 0x9D56, 0xA4F2, 
0xC5D6, 0xD699, 0x740F, 0xB616, 0xD6B8, 0x736C, 0x0, 0x0, 0x41, 
0x40, 0x0, 0x0, 0x20, 0x0, 0x0, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x1, 0x1, 0x1, 0x0, 0x18A2, 0x20, 
0x10C1, 0xBE57, 0xADF7, 0x532C, 0x4AC9, 0x634B, 0xC678, 0xB659, 0x6C75, 
0x7539, 0xA6BD, 0x6476, 0x18F, 0x2255, 0x933, 0x30, 0x71, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x30, 0x51, 0x91, 0xB2, 0xB3, 0xD3, 0x974, 0xD0, 
0x5C9C, 0x6D1C, 0x1253, 0x11F6, 0x11B6, 0x954, 0x953, 0x134, 0x114, 
0xF3, 0xF3, 0xF3, 0xF3, 0xD3, 0xF3, 0x113, 0xF3, 0xF3, 
0x113, 0x113, 0x974, 0x154, 0x9D5, 0x9F3, 0x3B78, 0x969F, 0x5CDC, 
0x152, 0x154, 0x955, 0x114, 0xF3, 0xF3, 0x113, 0xF3, 0xF3, 
0xF3, 0xD4, 0xF3, 0xF2, 0xF2, 0x114, 0xF3, 0x113, 0x113, 
0xF3, 0x113, 0x114, 0x114, 0x114, 0x934, 0x954, 0x995, 0x995, 
0x11F5, 0x1235, 0x22D5, 0x53F6, 0x9DDB, 0x9D76, 0xB638, 0x95B8, 0xA639, 
0xADB5, 0x5AC9, 0x2124, 0x20E4, 0x20, 0x61, 0x0, 0x0, 0x20, 
0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x821, 0x1061, 0x0, 0x8471, 0xA5F8, 0x9DFA, 0x8D78, 
0xADF7, 0x9D75, 0xB67B, 0x6497, 0x22D3, 0x5CBA, 0x961C, 0x74F8, 0x971, 
0x112, 0xB2, 0x71, 0x10, 0x30, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x51, 0x71, 
0x92, 0xB3, 0x956, 0x954, 0x2276, 0x74FF, 0x85DF, 0x4BFA, 0x194, 
0x975, 0x954, 0x113, 0xF3, 0xF3, 0x113, 0xF3, 0xF3, 0xD3, 
0xB2, 0xB2, 0xD2, 0xD2, 0xF3, 0xD3, 0xF3, 0x113, 0x954, 
0x134, 0x995, 0x64BF, 0x5C9C, 0x1A74, 0x993, 0x954, 0x113, 0xF3, 
0x114, 0xF3, 0xF2, 0xF3, 0xF3, 0xD3, 0xD3, 0xD3, 0xF2, 
0xF3, 0xB2, 0xF3, 0xF3, 0xF2, 0xF3, 0xF3, 0xF4, 0x114, 
0x114, 0x114, 0x954, 0x154, 0x974, 0x9B5, 0x9D6, 0xA15, 0x1213, 
0x6479, 0x9E1C, 0x9E1B, 0x5C97, 0x7D7A, 0x6C31, 0x73EF, 0x9492, 0x0, 
0x0, 0x882, 0x800, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1061, 0x800, 
0x1082, 0x638F, 0x8537, 0x6477, 0x53F5, 0x9578, 0xB69D, 0x7D1A, 0x3336, 
0x1296, 0x4C3B, 0x95FE, 0x9E1F, 0x74BE, 0x19B5, 0x71, 0x892, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x30, 0x51, 0x71, 0xB2, 0xD3, 0xF3, 0x9B5, 
0x9F4, 0x4BDA, 0x6D3F, 0x22F6, 0x194, 0x975, 0x113, 0xF3, 0xF3, 
0xD2, 0xD2, 0xD2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xD2, 0xD2, 0xD2, 0xF3, 0x113, 0xF3, 0x1195, 0x53DD, 0x2277, 
0xB0, 0x933, 0x113, 0xD3, 0xD3, 0xD3, 0xD3, 0xD2, 0xD2, 
0xD2, 0xD2, 0xD2, 0xD2, 0xD2, 0xD2, 0xD2, 0xD2, 0xD2, 
0xD2, 0xD3, 0xF3, 0xF3, 0xF4, 0xF3, 0x113, 0x934, 0x134, 
0x154, 0x995, 0x9B6, 0x1216, 0x1236, 0x2AF8, 0x43D9, 0x4C39, 0x3BF8, 
0x5458, 0x7D38, 0xBEBC, 0xBE39, 0x73EF, 0x21, 0x0, 0x842, 0x0, 
0x20, 0x40, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x801, 0x0, 0x0, 
0x0, 0x0, 0x21, 0x1082, 0x800, 0x8C30, 0x9D97, 0x6475, 0x4418, 
0x22D5, 0x5C7A, 0x5C3A, 0x1A34, 0x1216, 0x1257, 0x9F4, 0x32F6, 0x855E, 
0x95BF, 0x2A35, 0x50, 0x892, 0x31, 0x10, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x50, 
0x71, 0x92, 0xB2, 0x133, 0x132, 0x152, 0x43DA, 0x64DE, 0x1235, 
0x173, 0x133, 0xF3, 0xD3, 0xD2, 0xB2, 0xB2, 0x92, 0x92, 
0x92, 0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0x92, 
0xD2, 0x913, 0xF3, 0x933, 0x934, 0x934, 0xF3, 0xD3, 0xB2, 
0xD2, 0xD2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xB2, 0xB2, 0xB2, 0xB2, 0xD2, 0xD2, 0xD3, 0xD3, 0xD3, 
0xF3, 0xF3, 0x113, 0x113, 0x133, 0x134, 0x975, 0x996, 0x9B6, 
0x1217, 0x1217, 0x1276, 0x1AF7, 0x33B9, 0x4C38, 0x8D9A, 0xB65A, 0xBE39, 
0xADB6, 0x5B0B, 0x20, 0x1062, 0x821, 0x0, 0x20, 0x20, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x821, 0x0, 0x0, 0x20, 0x20, 0x0, 0x1082, 0x0, 
0x41A6, 0xAD34, 0xAE18, 0x74D6, 0x2AF5, 0x22F8, 0x1235, 0x1B4, 0x9F6, 
0x1217, 0x9D6, 0x1216, 0x172, 0x6C9D, 0x5BFB, 0xAF, 0x8D2, 0x71, 
0x31, 0x10, 0xE, 0x2E, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x2F, 0x30, 0x71, 0x92, 0xF3, 0x113, 
0x2256, 0x439A, 0x649E, 0x545D, 0x4BBB, 0x994, 0x113, 0xD3, 0xB2, 
0x92, 0xB2, 0x92, 0x92, 0x92, 0x91, 0x92, 0x92, 0x92, 
0x92, 0x92, 0x92, 0x92, 0xB2, 0x92, 0xB2, 0xF3, 0xD2, 
0x8F3, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 0x92, 0x92, 
0x92, 0x92, 0x92, 0xB2, 0x92, 0x92, 0x92, 0xB2, 0xB2, 
0xB2, 0xD2, 0xD2, 0xD3, 0xD3, 0xD3, 0xF3, 0xF2, 0xF2, 
0x133, 0x134, 0x954, 0x975, 0x9B6, 0x11D7, 0x1237, 0x1AB8, 0x1AB7, 
0x2B57, 0x6D1A, 0x7C92, 0x844F, 0x4A48, 0x861, 0x39E6, 0x1081, 0x1, 
0x821, 0x821, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x20, 0x20, 0x862, 0x0, 0x800, 0x0, 0x94D1, 0xADF9, 
0x4376, 0x1215, 0x1A36, 0x11F6, 0x9B5, 0x9B5, 0x174, 0x174, 0x1A35, 
0x5BFC, 0x3AD8, 0x6F, 0x91, 0x50, 0x30, 0x10, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x30, 0x51, 0x91, 0x91, 0x21F6, 0x539C, 0x4B9B, 0x32F8, 0x172, 
0x2AB8, 0x1174, 0xF2, 0xD2, 0x92, 0x71, 0x91, 0x71, 0x92, 
0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 0x71, 
0x92, 0xB2, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0x92, 0x92, 
0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 
0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xD3, 0xD3, 0xD2, 0xF2, 0xF3, 0x113, 0x114, 0x154, 0x175, 
0x995, 0x11F7, 0x1216, 0x1A97, 0x3B99, 0x43D6, 0x7D38, 0xA553, 0x738B, 
0x0, 0x0, 0x0, 0x1081, 0x0, 0x0, 0x841, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x20, 0x21, 0x0, 0x0, 0x1082, 0x0, 
0x62EB, 0x6B6E, 0x4228, 0x7BED, 0x9535, 0x74FC, 0x11F4, 0x11B5, 0x11B5, 
0x995, 0x153, 0x153, 0x133, 0x953, 0x953, 0x2F, 0x8D2, 0x70, 
0x30, 0x30, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x50, 0x8B2, 0x50, 
0x3258, 0x4B1B, 0x132, 0xF1, 0x112, 0x90, 0xF2, 0x91, 0x92, 
0x92, 0x71, 0x71, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x91, 0x51, 0x51, 0x71, 0x71, 
0x92, 0x51, 0x92, 0x91, 0x71, 0x71, 0x71, 0x71, 0x71, 
0x71, 0x72, 0x71, 0x71, 0x72, 0x92, 0x72, 0x72, 0x92, 
0x92, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xD2, 0xD2, 
0xF3, 0xD3, 0xF4, 0x134, 0x975, 0x174, 0x1215, 0x1214, 0x9D2, 
0x751C, 0x9DFB, 0xA5F8, 0xD6B9, 0x840E, 0x800, 0x2105, 0x1042, 0x1061, 
0x6B4C, 0x2964, 0x0, 0x1082, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 
0x1, 0x1, 0x1062, 0x800, 0x1861, 0xAD34, 0xAE19, 0xA5D8, 0xADB5, 
0x9535, 0x6C9B, 0x9D4, 0x11B5, 0x995, 0x113, 0x154, 0x113, 0x113, 
0xF2, 0x70, 0x8D2, 0x50, 0x30, 0x50, 0xF, 0xF, 0x10, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x30, 0x30, 0x10F3, 0x3A79, 0x21D6, 0xF2, 0xD2, 
0xB1, 0xD1, 0x91, 0x51, 0x71, 0x71, 0x51, 0x51, 0x51, 
0x31, 0x50, 0x50, 0x30, 0x50, 0x50, 0x50, 0x50, 0x50, 
0x30, 0x71, 0x71, 0x71, 0x71, 0x51, 0x51, 0x51, 0x71, 
0x71, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x51, 0x71, 0x71, 0x72, 0x72, 0x72, 0x92, 0x92, 0x92, 
0x92, 0xB2, 0xB2, 0xB2, 0xD2, 0xD3, 0xD3, 0xF4, 0x114, 
0x154, 0x9B5, 0x193, 0x3B58, 0x74FB, 0x8D9A, 0xB638, 0xD6F9, 0x94B0, 
0x3964, 0x800, 0x800, 0x0, 0x0, 0xB5D5, 0x844F, 0x0, 0x1062, 
0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x820, 0x0, 0x1, 0x1, 0x1062, 0x1041, 
0x2903, 0x94D3, 0x9599, 0x74F7, 0x8D57, 0xAE3C, 0x4337, 0x153, 0x11B6, 
0x114, 0x113, 0xF3, 0xD2, 0xD2, 0xB2, 0xB2, 0x71, 0x51, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x891, 0x8B2, 0x71, 0xB2, 0x71, 0x71, 0x71, 0x71, 0x51, 
0x30, 0x30, 0x30, 0x30, 0x31, 0x30, 0x10, 0x30, 0x10, 
0x10, 0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x51, 0x30, 0x51, 0x31, 0x51, 0x50, 0x50, 0x50, 0x51, 
0x51, 0x51, 0x51, 0x31, 0x51, 0x51, 0x51, 0x51, 0x51, 
0x71, 0x71, 0x72, 0x71, 0x72, 0x92, 0x92, 0xB2, 0xB2, 
0xB2, 0xD2, 0xF3, 0xF4, 0x114, 0x114, 0x11B5, 0x133, 0x4BB9, 
0xAE9F, 0xA618, 0xAD92, 0xBDD2, 0x8C4D, 0x49E4, 0x7B4B, 0x730A, 0x4A46, 
0x6B8B, 0xCED9, 0xB617, 0x18C2, 0x800, 0x861, 0x861, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 
0x820, 0x0, 0x18C3, 0x0, 0x528A, 0xA574, 0x6C10, 0x6477, 0x3355, 
0x3315, 0x541B, 0x2A97, 0x133, 0x954, 0x113, 0x934, 0xD2, 0xD3, 
0x92, 0x92, 0x72, 0x51, 0x30, 0xF, 0x30, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x2F, 0x30, 0x30, 0x51, 0x51, 
0x71, 0x51, 0x30, 0x30, 0x50, 0x10, 0x10, 0x10, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x10, 0xF, 0xF, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x30, 0x30, 0x51, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x50, 0x51, 0x51, 0x51, 0x31, 
0x31, 0x51, 0x51, 0x51, 0x51, 0x71, 0x71, 0x71, 0x71, 
0x71, 0x72, 0x91, 0xB1, 0xB1, 0xB2, 0xD2, 0xB2, 0xD3, 
0xF3, 0x134, 0x954, 0x994, 0x1A13, 0x6C76, 0xB699, 0xA551, 0x840A, 
0xCE54, 0xC615, 0xC616, 0xB594, 0x73ED, 0xB657, 0xB67A, 0x8D35, 0x94B1, 
0x83CD, 0x20, 0x1082, 0x841, 0x821, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x18C3, 0x0, 0x2966, 
0x6BCF, 0xA5D7, 0x95B9, 0x5438, 0x2317, 0x1297, 0x1F5, 0x994, 0x11B5, 
0x954, 0x934, 0xB2, 0xD2, 0xB2, 0x92, 0x71, 0x51, 0x30, 
0xF, 0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0x2F, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x10, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0xF, 
0xF, 0xF, 0x10, 0x10, 0xF, 0xF, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x31, 0x51, 0x51, 
0x51, 0x51, 0x51, 0x51, 0x51, 0x51, 0x71, 0x91, 0x91, 
0x91, 0xB2, 0xD3, 0xB3, 0xB3, 0xF4, 0x954, 0x112, 0x2276, 
0x8D9F, 0x9E5E, 0x9E1A, 0xB657, 0xB5D4, 0xBE15, 0xD6F9, 0xB63A, 0x8D77, 
0x8556, 0x8557, 0x7518, 0x9DFB, 0xCEB9, 0x738B, 0x0, 0x1, 0x0, 
0x841, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 
0x0, 0x1061, 0x40, 0x20, 0x8471, 0xB65A, 0x74F7, 0x5417, 0x2B57, 
0x1AD8, 0x1298, 0x1257, 0x9D4, 0x994, 0x953, 0x113, 0xD3, 0xB3, 
0x92, 0x72, 0x51, 0x50, 0x30, 0x10, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x30, 0x30, 0x31, 0x31, 0x30, 0x30, 0x51, 0x51, 
0x51, 0x51, 0x71, 0x71, 0x91, 0x91, 0x92, 0x92, 0xB2, 
0xB3, 0x8F4, 0x933, 0x112, 0x32B7, 0x7D5F, 0x8DBF, 0x4373, 0x8D58, 
0xB65A, 0x9D74, 0xA5B6, 0x74F7, 0x6CD9, 0x64D8, 0x4C15, 0x5457, 0x8D9A, 
0x9512, 0x3183, 0x3166, 0x6B2D, 0x18A3, 0x20, 0x1062, 0x0, 0x0, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x841, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1062, 0x0, 0x18E3, 0xA554, 
0xD73B, 0xBEBB, 0x8D79, 0x6478, 0x43D8, 0x22D6, 0x1297, 0x1256, 0x9D5, 
0x174, 0x133, 0x113, 0xD3, 0xB2, 0x92, 0x72, 0x51, 0x50, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xD, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0xF, 0xF, 
0x10, 0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x50, 
0x50, 0x30, 0x30, 0x50, 0x50, 0x50, 0x51, 0x71, 0x71, 
0x71, 0x91, 0x91, 0x91, 0x8D3, 0xB2, 0xB2, 0xD3, 0x113, 
0x113, 0xD1, 0x2256, 0x11D3, 0x3B16, 0x4B95, 0x9DD9, 0xB6DC, 0x755A, 
0x2355, 0x2357, 0x2356, 0x4C58, 0x8DBA, 0x5B0B, 0x738C, 0xB5B6, 0xBE18, 
0x4A49, 0x0, 0x18E3, 0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x841, 0x841, 0x0, 0x6B6C, 0x9CF2, 0x73AD, 0x73AE, 0x9D34, 0xADF9, 
0x8D79, 0x6498, 0xA52, 0x1D3, 0x11F6, 0x134, 0x134, 0xF3, 0xD2, 
0xB2, 0x92, 0x71, 0x51, 0x30, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x50, 0x50, 0x51, 0x51, 0x71, 0x71, 0x91, 0x91, 
0x71, 0x92, 0x8F3, 0xF3, 0xD3, 0x934, 0x1175, 0x134, 0x9B6, 
0x173, 0x9D2, 0x95DD, 0xAE9F, 0x7DDF, 0x2358, 0x2339, 0x1B18, 0x33B7, 
0x7519, 0x84D5, 0x9D35, 0xBE7B, 0x8CF4, 0x5B2D, 0x6B6D, 0x20, 0x0, 
0x1082, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x0, 0x0, 0x1061, 0x841, 0x0, 0x10C3, 0x2104, 
0x0, 0x800, 0x800, 0x41C5, 0x7BEE, 0xBE79, 0x9DF9, 0x5C77, 0x545A, 
0x11F5, 0x11B6, 0x954, 0x113, 0xD2, 0x92, 0x92, 0x71, 0x51, 
0x10, 0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x51, 
0x51, 0x71, 0x71, 0x71, 0x91, 0x91, 0xB2, 0x92, 0xB2, 
0xD2, 0xF2, 0x113, 0x975, 0x995, 0x193, 0x1A35, 0x4358, 0x32F7, 
0x22D8, 0x1A77, 0x1297, 0x1AD8, 0x22F7, 0x3B57, 0x5C59, 0x7D1A, 0x753A, 
0x7D17, 0xA597, 0xAD95, 0x630B, 0x840, 0x0, 0x840, 0x820, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x1082, 
0x0, 0x0, 0x10A4, 0x1, 0x0, 0x1081, 0x20C2, 0x20A2, 0x0, 
0x39C6, 0xAD74, 0x9D53, 0xAE38, 0xB6DE, 0x5C19, 0x132, 0x953, 0x113, 
0xD3, 0xB2, 0x92, 0x71, 0x31, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0xF, 0x30, 
0x30, 0x30, 0x30, 0x30, 0x31, 0x31, 0x51, 0x71, 0x71, 
0x891, 0x71, 0x92, 0x92, 0xB2, 0x8D3, 0xB1, 0xF2, 0xF3, 
0x134, 0x194, 0x173, 0x133, 0x974, 0x175, 0x1A38, 0x1257, 0x1297, 
0x1277, 0x22F7, 0x2B38, 0x3BB7, 0x4C58, 0x7518, 0xAE18, 0xDEFB, 0xE73B, 
0xA533, 0x52AA, 0x820, 0x20, 0x841, 0x841, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 
0x0, 0x0, 0x841, 0x1062, 0x0, 0x18C2, 0x5ACA, 0x842, 0x1, 
0x1061, 0x840, 0x0, 0x1041, 0x841, 0x18A2, 0x820, 0x840D, 0xBEB8, 
0xAE9B, 0x95DE, 0x3B18, 0x132, 0x113, 0xF3, 0xB2, 0x72, 0x51, 
0x31, 0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xF, 0xE, 0xF, 0xE, 0xF, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x2F, 0x2F, 0x2F, 0x30, 0x30, 
0x30, 0x31, 0x51, 0x51, 0x70, 0x70, 0x71, 0x71, 0x92, 
0x92, 0x92, 0x92, 0xD2, 0x8F3, 0xF3, 0x134, 0x174, 0x994, 
0x11D6, 0x11B7, 0x11B6, 0x1216, 0xA36, 0x1A77, 0x22D8, 0x2358, 0x33D8, 
0x5477, 0x8D99, 0xB618, 0x9D13, 0x8C50, 0x7BCE, 0x6B6D, 0x18E3, 0x0, 
0x20, 0x861, 0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1082, 0x0, 
0x20, 0x9CF1, 0x7BED, 0x800, 0x20C3, 0x0, 0x0, 0x821, 0x0, 
0x18C3, 0x0, 0x5AA7, 0xC656, 0xA639, 0x965D, 0x961F, 0x647C, 0x153, 
0x913, 0xF3, 0xB2, 0x72, 0x51, 0x50, 0x30, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x2F, 0xF, 0x10, 0x10, 0x10, 0x10, 0x30, 0x50, 
0x50, 0x50, 0x71, 0x51, 0x72, 0x92, 0x92, 0xB2, 0xB2, 
0xB2, 0xF3, 0x113, 0x133, 0x154, 0x154, 0x976, 0x1196, 0x11D6, 
0x1216, 0x1A97, 0x1AB6, 0x2B77, 0x3BD6, 0x7D38, 0x84F5, 0x8CB2, 0x4A68, 
0x0, 0x840, 0x0, 0x861, 0x1061, 0x1061, 0x0, 0x841, 0x1061, 
0x821, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1061, 0x18A2, 0x20, 0x1, 0x8C92, 0xDF19, 0x52A8, 0x0, 
0x20C3, 0x0, 0x821, 0x1, 0x1, 0x1082, 0x0, 0x3983, 0xB5D5, 
0x8557, 0x4C16, 0x2B15, 0x1A54, 0x11B4, 0x1175, 0x913, 0xD2, 0x92, 
0x71, 0x51, 0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x10, 0x10, 0x30, 0x50, 0x51, 0x51, 0x71, 
0x71, 0x92, 0x92, 0x92, 0xB2, 0xD3, 0xD3, 0xF3, 0x133, 
0x113, 0x154, 0x955, 0x975, 0x9B5, 0x1216, 0x1277, 0x1274, 0x6477, 
0xA61A, 0xB618, 0xC678, 0x634B, 0x20, 0x18E4, 0x10A3, 0x821, 0x0, 
0x0, 0x2945, 0x4A49, 0x800, 0x0, 0x18A2, 0x820, 0x0, 0x1, 
0x21, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x801, 
0x1, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x20, 0x20, 0x20, 0x0, 0x20, 0x0, 0x0, 0x0, 0x800, 
0x0, 0x0, 0x20, 0x0, 0x20, 0x841, 0x0, 0x0, 0x52CB, 
0x6BB0, 0xC69B, 0xCE99, 0x52A9, 0x0, 0x18A3, 0x1, 0x1, 0x21, 
0x21, 0x18A3, 0x800, 0x838C, 0xD6B9, 0x9DFA, 0x43B4, 0x1A94, 0x1256, 
0x11F6, 0x113, 0x90, 0xF2, 0xB2, 0x71, 0x50, 0x50, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x30, 0x51, 0x51, 0x51, 0x71, 0x71, 0x92, 0x92, 
0x92, 0xB2, 0xB2, 0xD2, 0xF3, 0x113, 0x154, 0x955, 0x975, 
0x9B6, 0x1216, 0xA35, 0x64DC, 0xA61A, 0xBE37, 0x9D11, 0x736B, 0x31A5, 
0x0, 0x1083, 0x1, 0x1, 0x1062, 0x820, 0x0, 0x9492, 0x8C30, 
0x0, 0x20, 0x1081, 0x1082, 0x821, 0x0, 0x0, 0x0, 0x20, 
0x0, 0x20, 0x0, 0x800, 0x0, 0x1, 0x0, 0x0, 0x0, 
0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x800, 0x0, 0x0, 0x0, 0x40, 
0x10A1, 0x820, 0x2924, 0x4208, 0x73EF, 0xAE3B, 0x9599, 0xADD7, 0x7C0F, 
0x20, 0x1061, 0x1082, 0x1, 0x862, 0x1082, 0x800, 0x800, 0x6AA9, 
0x94B1, 0xB65A, 0xA67E, 0x43FA, 0x1297, 0x1215, 0x32F8, 0x3AD8, 0xF1, 
0xB2, 0x892, 0x31, 0x30, 0xF, 0xF, 0xF, 0xE, 0xF, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 0x50, 
0x50, 0x51, 0x71, 0x71, 0x92, 0x92, 0x92, 0xB2, 0xB2, 
0xD2, 0x113, 0x114, 0x114, 0x975, 0x9B6, 0xA16, 0x214, 0x43F7, 
0xA639, 0xA552, 0xA531, 0x6B4A, 0x18C2, 0x801, 0x821, 0x821, 0x0, 
0x0, 0x10A2, 0x0, 0x6B4C, 0xDEFA, 0x842F, 0x4A48, 0x0, 0x800, 
0x800, 0x1082, 0x861, 0x0, 0x0, 0x1, 0x1, 0x1, 0x1, 
0x21, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 0x0, 0x0, 
0x0, 0x0, 0x1062, 0x18A3, 0x20, 0x20, 0x0, 0x8C52, 0xC618, 
0x7452, 0x7519, 0x64D8, 0x8557, 0xA5D6, 0x632B, 0x0, 0x0, 0x861, 
0x0, 0x800, 0x1000, 0x3964, 0x800, 0x1060, 0xBE37, 0xAE7C, 0x547A, 
0x12B5, 0x5479, 0x961F, 0x7D5F, 0x2236, 0x30, 0x892, 0x872, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x30, 0x30, 0x30, 0x50, 0x50, 0x51, 0x71, 
0x71, 0x92, 0x92, 0x92, 0xD2, 0xD3, 0xF3, 0xF3, 0x934, 
0x955, 0x195, 0x9F6, 0xA55, 0x22D3, 0x95D9, 0xB657, 0xE73A, 0xBDB4, 
0x1881, 0x800, 0x1062, 0x0, 0x0, 0x20, 0x18A2, 0x800, 0x5288, 
0xD6D9, 0xCF1B, 0x7C71, 0x52C9, 0x5268, 0x1040, 0x0, 0x0, 0x10A2, 
0x862, 0x0, 0x1, 0x1, 0x21, 0x0, 0x20, 0x20, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 0x800, 0x801, 
0x1, 0x800, 0x821, 0x0, 0x21, 0x841, 0x0, 0x800, 0x0, 
0x1904, 0x73EF, 0x1062, 0x630D, 0xBE59, 0x8D57, 0x4C37, 0x3C17, 0x6496, 
0xA63A, 0x94F3, 0x840E, 0x4A27, 0x0, 0x3185, 0x2103, 0xA512, 0x948F, 
0x0, 0x4A67, 0xADB4, 0xB69A, 0x5C97, 0x54BA, 0x9EFF, 0x755B, 0x2AD5, 
0x2A57, 0x92, 0x72, 0x51, 0x50, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x30, 
0x30, 0x50, 0x50, 0x51, 0x51, 0x51, 0x71, 0x91, 0xB2, 
0xB2, 0xD3, 0xF3, 0xF3, 0x1155, 0x954, 0x9D6, 0x1257, 0xA36, 
0x2B17, 0x7D7D, 0x8D99, 0xB659, 0xB616, 0x840D, 0x800, 0x1081, 0x882, 
0x8A2, 0x10C3, 0x0, 0x0, 0x840E, 0xB617, 0x9E5B, 0x74F5, 0xB616, 
0xA511, 0x800, 0x3165, 0x18C3, 0x0, 0x20, 0x20, 0x841, 0x21, 
0x0, 0x821, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 
0x1, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 0x0, 0x0, 0x882, 
0x882, 0x0, 0x1082, 0x18C2, 0x4227, 0x634C, 0xBE58, 0x9D12, 0x52CA, 
0x7CD4, 0x7519, 0x2B56, 0x2357, 0x5CB9, 0x95FC, 0xA5F9, 0xD6FB, 0x8C4F, 
0x18C0, 0xADB4, 0xADF6, 0xBEB9, 0xB6B8, 0xA5D3, 0xC6B7, 0xBE37, 0xBE79, 
0xAE9B, 0xA69D, 0x85FD, 0x3356, 0x152, 0x934, 0xF4, 0x72, 0x50, 
0x4F, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x30, 0x50, 0x51, 
0x50, 0x51, 0x71, 0x91, 0x91, 0xB2, 0xD3, 0xF3, 0xF3, 
0x934, 0x153, 0x9B4, 0x1D4, 0x1AB7, 0x2B38, 0x3397, 0x5C77, 0xA619, 
0xD6D9, 0x8C0E, 0x20C0, 0x0, 0x40, 0x20, 0x0, 0x2124, 0x6B4D, 
0x94F3, 0xAE39, 0x6D18, 0x85DB, 0xB638, 0x6B6B, 0x4A89, 0xAD55, 0x4A69, 
0x2124, 0x2103, 0x20, 0x0, 0x1082, 0x1082, 0x0, 0x800, 0x0, 
0x0, 0x0, 0x20, 0x20, 0x0, 0x0, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 
0x821, 0x841, 0x861, 0x18C3, 0x21, 0x0, 0x0, 0x18C2, 0x9CD1, 
0xCE78, 0x9535, 0xA5B7, 0xB618, 0x8D36, 0x7D18, 0x4C17, 0x1AD6, 0x2339, 
0x2336, 0x4C17, 0x74D8, 0x9D97, 0xA574, 0x9D11, 0xC6B9, 0xA5F7, 0x7D36, 
0x9E5B, 0xBF7D, 0x9E38, 0x95B8, 0xAE5A, 0xBEFB, 0xB71D, 0x64F9, 0x1AB4, 
0x993, 0xB1, 0xF3, 0xB2, 0x50, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x2F, 0x2F, 0x30, 0x30, 0x30, 0x50, 0x51, 0x51, 0x71, 
0x91, 0x92, 0x92, 0xD3, 0x8F3, 0x113, 0x11B4, 0x2274, 0x3B97, 
0x1AB4, 0x2357, 0x2BB7, 0x6D19, 0xB658, 0x948F, 0x1840, 0x800, 0x4A25, 
0x4A24, 0x3983, 0x3144, 0x3985, 0xC658, 0x9576, 0x74D7, 0x4C38, 0x64DA, 
0x8537, 0x4B2D, 0x8D15, 0xBE7A, 0xADB6, 0xC658, 0x632C, 0x0, 0x18A2, 
0x0, 0x0, 0x841, 0x1083, 0x841, 0x800, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 0x20, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x21, 0x21, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x21, 0x821, 0x820, 0x20, 0x21, 0x821, 0x0, 
0x1041, 0x5289, 0x20E3, 0x820, 0x4A27, 0xA555, 0xB67C, 0x6476, 0x5C56, 
0x7D5C, 0x545A, 0x1A95, 0x1A97, 0x1298, 0x1A97, 0x1A96, 0x22B4, 0x5415, 
0xA637, 0xBEB7, 0xBE9A, 0x7CF6, 0x4374, 0x6CFC, 0x5C9A, 0x43F7, 0x2B53, 
0x6D18, 0xAEDD, 0x95FA, 0x967F, 0x8E1F, 0x755F, 0x53DB, 0x19B5, 0x50, 
0x50, 0x30, 0x2F, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x30, 0x30, 0x31, 0x51, 0x71, 0x71, 0x8B2, 0x92, 0xB3, 
0x914, 0xF3, 0x2A76, 0x7D5E, 0x9E7F, 0x8E5F, 0x759C, 0x4C78, 0x6CF7, 
0xCEB9, 0xC5D4, 0x20C2, 0x800, 0x9C8F, 0xCE14, 0xAD11, 0xB593, 0x7BCC, 
0xB5F6, 0x9598, 0x5416, 0x3BD9, 0x3BB8, 0x6CD9, 0x7D59, 0x8559, 0x9598, 
0xCEBA, 0x94B1, 0x1062, 0x800, 0x3165, 0x6B4C, 0x2945, 0x1, 0x1, 
0x0, 0x821, 0x1082, 0x1882, 0x1061, 0x20, 0x0, 0x0, 0x0, 
0x0, 0x20, 0x20, 0x20, 0x20, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x800, 0x841, 0x861, 0x882, 0x821, 
0x0, 0x0, 0x0, 0x10A3, 0x528A, 0xB595, 0x8C30, 0x800, 0x18A2, 
0x0, 0x52EB, 0x7D17, 0x6478, 0x3356, 0x2316, 0x1255, 0x1A56, 0x1237, 
0x1237, 0x1A58, 0x1236, 0x3B99, 0x963F, 0xAEDD, 0xAEBB, 0xAE9D, 0x8D9C, 
0x2AD6, 0xA35, 0x1296, 0x1B18, 0x2B97, 0x8E5F, 0xA6FF, 0x3B92, 0x43B6, 
0x6CFD, 0x543B, 0x74DF, 0x3AB8, 0x30, 0x871, 0xF, 0x2F, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x31, 0x51, 
0x51, 0x91, 0x91, 0x92, 0xB3, 0x8D4, 0x1136, 0x112, 0x649B, 
0xA6FF, 0xA69D, 0xAEDD, 0x9E3B, 0x9597, 0xCE97, 0xB570, 0x9D0F, 0xA511, 
0xBDF6, 0xCE99, 0xBE77, 0xC6B7, 0xA510, 0xBE37, 0xA63C, 0x43D7, 0x2318, 
0x2B39, 0x2B17, 0x43F8, 0x4C38, 0x7D59, 0x8C92, 0x4A06, 0x800, 0x0, 
0x0, 0xAD74, 0xB596, 0x39C7, 0x6B0C, 0x4A08, 0x1, 0x1, 0x0, 
0x0, 0x1041, 0x1882, 0x1041, 0x1082, 0x842, 0x41, 0x0, 0x20, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x1, 
0x0, 0x0, 0x0, 0x0, 0x40, 0x841, 0x1062, 0x1082, 0x861, 
0x862, 0x882, 0x0, 0x0, 0x0, 0x800, 0x41C6, 0x9CF2, 0x7C30, 
0x8CD3, 0xDF3C, 0x844F, 0x800, 0x800, 0x2142, 0x9D54, 0x95B9, 0x5C57, 
0x1A94, 0x1A96, 0x1256, 0x1236, 0x9D6, 0x11D6, 0x11F7, 0x193, 0x5C5B, 
0xA69F, 0x5C79, 0x751C, 0x649C, 0x22B6, 0x2297, 0x1277, 0x1298, 0x2318, 
0x1AD6, 0x759F, 0x96BF, 0x43D5, 0xA13, 0x194, 0xB0, 0x42D8, 0x3236, 
0x50, 0x50, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x31, 0x31, 0x51, 0x70, 0x91, 0xB2, 
0xD3, 0xB3, 0x915, 0xD2, 0x3357, 0x4C17, 0x5C75, 0xBF1E, 0xAE7B, 
0xBEB9, 0xCE96, 0x94EE, 0xC6D7, 0xCF1A, 0x9DB9, 0x8517, 0x95B8, 0xA639, 
0xADD6, 0xA5B8, 0x751A, 0x3378, 0x1AB7, 0x1AD9, 0x2319, 0x2B38, 0x3376, 
0x7538, 0xADB6, 0xA511, 0x3144, 0x0, 0x2985, 0xADB6, 0xC69A, 0x94F4, 
0xBDB6, 0x5269, 0x0, 0x6B4E, 0x3165, 0x2944, 0x800, 0x800, 0x0, 
0x820, 0x0, 0x842, 0x18C3, 0x10A2, 0x18C2, 0x18A2, 0x1061, 0x1, 
0x0, 0x41, 0x21, 0x21, 0x801, 0x1882, 0x18A2, 0x18A2, 0x18E3, 
0x861, 0x0, 0x0, 0x820, 0x0, 0x0, 0x0, 0x31A6, 0x4A69, 
0x8C30, 0x2903, 0x800, 0xAD74, 0xB659, 0x7CF4, 0xA639, 0x8D14, 0x73AE, 
0x6B2A, 0x840, 0x9D52, 0xBEBA, 0x8579, 0x5C9B, 0x1256, 0x1216, 0x9D6, 
0x995, 0x9B6, 0x976, 0x11B5, 0x2A95, 0x2274, 0x9B2, 0x1214, 0x11F5, 
0x194, 0x9B5, 0x1217, 0x1257, 0x1297, 0xA54, 0x4C59, 0x9EDF, 0x5458, 
0x194, 0x996, 0x954, 0x8F2, 0xB1, 0x71, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x11, 
0x30, 0x30, 0x71, 0x92, 0x92, 0xB2, 0x934, 0xD2, 0x11B5, 
0x9D5, 0x1214, 0x2B15, 0x5456, 0x9E19, 0xBED8, 0xADD2, 0xCEF8, 0xA659, 
0x7579, 0x64FA, 0x3BD7, 0x5CDA, 0x7D7C, 0x9E1E, 0x6459, 0x9D3, 0x2297, 
0x1277, 0x1A97, 0x1AB7, 0x22D5, 0x7539, 0x95D8, 0xCEB8, 0xC614, 0x20E0, 
0x8C4E, 0x9D53, 0x8514, 0x95B9, 0xAE7C, 0xBDF7, 0x5A88, 0x3144, 0xBDB6, 
0xC657, 0x5AE9, 0x4A07, 0x83EE, 0x39A5, 0x41E6, 0x1081, 0x800, 0x800, 
0x800, 0x800, 0x800, 0x800, 0x841, 0x21, 0x20, 0x0, 0x21, 
0x801, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x2964, 0x4A07, 
0x5227, 0x9490, 0x4A68, 0x6B2C, 0xCE59, 0xC617, 0x5AEA, 0x4A46, 0xA554, 
0xA65B, 0x5C96, 0x64F8, 0x7518, 0x9D97, 0xB616, 0x842C, 0xAD50, 0xBE15, 
0xAE3A, 0x857D, 0x9F4, 0x195, 0x9B6, 0x996, 0x134, 0x975, 0x155, 
0x153, 0x132, 0x994, 0x974, 0x954, 0x11B6, 0x1175, 0x995, 0x9B5, 
0x2296, 0x651C, 0x85BE, 0x95FE, 0x53F8, 0xF2, 0x1196, 0xF3, 0xB1, 
0x71, 0x10, 0x830, 0x10, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x30, 0x72, 
0xB2, 0xD2, 0xD2, 0x113, 0x113, 0x11D5, 0x1A55, 0x3377, 0x6D1A, 
0xAEBD, 0xBEDA, 0xBEB8, 0xBEF9, 0xA69C, 0x5CD8, 0x2BB7, 0x2BB9, 0x2317, 
0xA33, 0x3358, 0x32F8, 0x1A57, 0x1217, 0x1236, 0x1256, 0x1236, 0x2295, 
0x857B, 0xA63A, 0xA594, 0xA510, 0x8C4C, 0xCE97, 0xBE9A, 0x74D6, 0x5477, 
0x7D59, 0xA576, 0x7BAD, 0x7BF0, 0xBE59, 0xBE79, 0x532C, 0x8CB2, 0xBDF7, 
0x6B8D, 0x9D54, 0x7C0F, 0x7BEF, 0x7BAE, 0x8C30, 0x9CB0, 0x8C4E, 0x5269, 
0x18A3, 0x1082, 0x20, 0x862, 0x1062, 0x2904, 0x6B4C, 0x9491, 0x8C70, 
0x7BEF, 0x7C10, 0x7C51, 0x8472, 0xA535, 0x6B8E, 0xC679, 0x8CD3, 0x634E, 
0xADD8, 0xADF8, 0xA575, 0x73CD, 0x9D55, 0x7D59, 0x4417, 0x33B6, 0x4C17, 
0x7D16, 0xC699, 0xC655, 0x8C6D, 0xB5F5, 0x8D16, 0x2272, 0x1A36, 0x975, 
0x955, 0x114, 0x155, 0x134, 0x134, 0x154, 0x154, 0x154, 0x154, 
0x934, 0x8F4, 0x1135, 0x1175, 0x994, 0x9D3, 0x547A, 0x85DE, 0x85BD, 
0x4376, 0xF1, 0xF3, 0x91, 0xB2, 0x51, 0x10, 0x10, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x30, 0x72, 0x92, 0x92, 0xB2, 0x8F3, 
0x2A17, 0x19F3, 0x4376, 0x861D, 0xB75F, 0x8DDB, 0x8DBA, 0xAE9C, 0x9619, 
0xB6FB, 0xA6BC, 0x64FA, 0x2336, 0x1AD7, 0x1AB8, 0x9D5, 0x9D5, 0x1216, 
0x9B5, 0x9D6, 0x11F6, 0x1216, 0x1235, 0x32F6, 0x6C97, 0xB616, 0x842C, 
0x948E, 0xB5B5, 0x95B9, 0x5C77, 0x2B76, 0x5458, 0x9577, 0x7410, 0x84D5, 
0x95BA, 0x6CF7, 0x6CF6, 0x8537, 0x95B9, 0x8578, 0x9E1B, 0xAE7A, 0xC6DB, 
0xE79F, 0xEF7D, 0xBDF5, 0x73CC, 0x2985, 0x841, 0x861, 0x0, 0x841, 
0x841, 0x18A2, 0x5269, 0x9CD1, 0xD6B9, 0xF7BD, 0xD73C, 0xB69B, 0x9DFA, 
0x9DDA, 0x84F8, 0x8D7A, 0x857A, 0x6C97, 0x6455, 0x74F7, 0x9599, 0x7C72, 
0x9D78, 0x5439, 0x1AD6, 0x2316, 0x3355, 0xA61C, 0xADF8, 0xA594, 0xADD5, 
0xB69B, 0x8D7C, 0x11B3, 0x155, 0x955, 0x914, 0x134, 0x113, 0xF2, 
0x133, 0x132, 0x112, 0xF2, 0x113, 0x934, 0xF3, 0x914, 0x913, 
0x995, 0x9B4, 0x1B2, 0x7DBF, 0x759D, 0x1251, 0x2A76, 0xD2, 0x92, 
0x72, 0x10, 0x31, 0xF, 0xF, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 
0x31, 0x72, 0xB2, 0x1113, 0x50, 0x3AB8, 0x74FD, 0x859D, 0x963E, 
0x5C98, 0x1A50, 0x7D7D, 0x8E1F, 0x43B3, 0xA67B, 0xAEBC, 0x9E7F, 0x3BB7, 
0xA35, 0x1257, 0x1216, 0x11F6, 0x9D6, 0x995, 0x11B5, 0x11B5, 0x995, 
0x1A16, 0x1214, 0x6439, 0xAE1A, 0xBE58, 0xADB6, 0xADF9, 0x74FA, 0x2B36, 
0x2316, 0x22F5, 0x74F9, 0x959A, 0x7D1A, 0x5417, 0x3BF6, 0x54DA, 0x64D8, 
0x5C97, 0x6D5B, 0x7D9A, 0x9E19, 0xC71B, 0xBE59, 0x6B4D, 0x0, 0x20, 
0x0, 0x20, 0x0, 0x820, 0x800, 0x0, 0x0, 0x0, 0x0, 
0x2123, 0x8C91, 0xBE79, 0xAE5B, 0x857A, 0x6CF9, 0x64DA, 0x4C18, 0x5CBA, 
0x4C59, 0x3375, 0x3B75, 0x7D7C, 0xA5FD, 0x6C57, 0x2295, 0x1A97, 0x1276, 
0x2AF6, 0x74BA, 0x8518, 0x9DB7, 0x9DF8, 0x6C97, 0x647B, 0x2A78, 0xF4, 
0x1155, 0xD2, 0x113, 0x113, 0x113, 0xF2, 0xD1, 0xD2, 0x113, 
0xD3, 0xD2, 0xD3, 0xD2, 0x934, 0x113, 0x174, 0x11F5, 0x1A95, 
0x6D3D, 0x85BF, 0x4359, 0xB1, 0x71, 0x72, 0x10, 0xF, 0x2F, 
0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0x10, 0x10, 0x10, 0x10, 0x51, 0x71, 0x892, 0x70, 
0x19F4, 0x4BDA, 0x8E1F, 0x965F, 0x3316, 0x9D3, 0x1D2, 0x64DE, 0x64DE, 
0x1253, 0x22B2, 0x753B, 0xA6DF, 0x5C58, 0x1214, 0x1A16, 0x974, 0x975, 
0x975, 0x155, 0x995, 0x974, 0x9B6, 0x11D6, 0x172, 0x857F, 0x95FF, 
0x6457, 0x74B8, 0x9DFF, 0x4BF9, 0x1275, 0x1A97, 0x1AB7, 0x2AF7, 0x22D6, 
0x2AD6, 0x3338, 0x2B99, 0x2378, 0x33B8, 0x4C59, 0x4C79, 0x7559, 0xA638, 
0x9512, 0x5269, 0x800, 0x1041, 0x18A2, 0x841, 0x20, 0x0, 0x800, 
0x0, 0x821, 0x20, 0x1081, 0x18C2, 0x20, 0x0, 0x73AE, 0xA5D8, 
0x8D79, 0x54B8, 0x3C39, 0x33D9, 0x2B58, 0x2317, 0x2337, 0x1A75, 0x3358, 
0x4379, 0x1213, 0x1A35, 0x1A36, 0x9F7, 0x1A58, 0x9B4, 0x2273, 0xA67E, 
0x8DBB, 0x150, 0x133, 0x934, 0x955, 0xF3, 0xF3, 0xD2, 0xD2, 
0xB2, 0xB2, 0xD2, 0xB2, 0xB2, 0xB2, 0xD2, 0xD2, 0xF2, 
0xF2, 0x114, 0x134, 0x974, 0x11F4, 0x5C7C, 0x6CFE, 0x3AB8, 0x51, 
0x92, 0x51, 0x2F, 0x2F, 0x2F, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x30, 0x50, 0x50, 0x71, 0x50, 0x2A56, 0x53FA, 0x32F5, 0x649C, 
0x437B, 0x174, 0x1216, 0x9D5, 0x9B4, 0x9B4, 0x2AD7, 0x859F, 0xAEBF, 
0x8DDF, 0x4B9A, 0x133, 0x1195, 0x954, 0x135, 0x135, 0x134, 0x954, 
0x175, 0x174, 0x11D5, 0x32D8, 0x2AB7, 0x992, 0x11F2, 0x3B38, 0x22B7, 
0xA35, 0x1237, 0x1237, 0xA57, 0x1AB8, 0x1A98, 0x22B9, 0x231A, 0x237A, 
0x33BA, 0x3BF9, 0x64DA, 0x95DA, 0xA5F6, 0x634A, 0x800, 0x2082, 0x1061, 
0x0, 0x0, 0x0, 0x800, 0x800, 0x0, 0x0, 0x20, 0x0, 
0x0, 0x18C2, 0x800, 0x2924, 0x94D3, 0xA5F9, 0x6D39, 0x3C17, 0x2BB9, 
0x2339, 0x22F8, 0x1297, 0x1AB7, 0x1256, 0x1D5, 0x1237, 0x11F5, 0x11B5, 
0x9B7, 0x11F8, 0x195, 0x2B19, 0x85BF, 0x5C19, 0x132, 0x1196, 0x114, 
0xB3, 0xF3, 0xD2, 0xB2, 0xB2, 0x93, 0x72, 0x92, 0xB2, 
0x72, 0xB2, 0xB2, 0xB2, 0xD1, 0xD2, 0xD3, 0x914, 0x71, 
0x5BDD, 0x645D, 0x110, 0x3237, 0x50, 0x30, 0x50, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xB, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x30, 0x51, 
0x71, 0x71, 0x70, 0x6F, 0x1194, 0x19D6, 0x934, 0xF3, 0x113, 
0x113, 0x973, 0x11B4, 0x645D, 0x7D1F, 0x2A96, 0x19F5, 0x933, 0x934, 
0x113, 0x114, 0x114, 0x113, 0x114, 0x134, 0x954, 0x954, 0x153, 
0x153, 0x11D5, 0x11D5, 0x974, 0x994, 0x11D6, 0x11F6, 0xA16, 0x1236, 
0x1A57, 0x1A77, 0x1A98, 0x1ABA, 0x22FA, 0x2B79, 0x3B96, 0x8559, 0x9D97, 
0x73EE, 0x3163, 0x800, 0x1040, 0x0, 0x21, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x20, 0x0, 0x1082, 0x0, 
0x4A47, 0xB5D6, 0x9DD8, 0x5435, 0x2B56, 0x2338, 0x1AB8, 0x1A57, 0x1256, 
0x1256, 0x9D6, 0x9B6, 0x11B5, 0x974, 0x995, 0x975, 0x175, 0x11F6, 
0x19F4, 0xF1, 0x953, 0x113, 0xF3, 0xD2, 0xB2, 0xB2, 0x92, 
0x92, 0x92, 0x92, 0x92, 0x92, 0x92, 0x91, 0x91, 0x91, 
0xB2, 0x91, 0x8D3, 0xB2, 0x21B6, 0x63DD, 0x431A, 0x4F, 0x50, 
0x30, 0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x10, 0x10, 0x30, 0x51, 0x71, 0x72, 0x8D3, 
0xB2, 0x71, 0xB2, 0x913, 0xF3, 0xF3, 0x934, 0xB1, 0x3AB8, 
0x2A77, 0x90, 0x113, 0x933, 0xF3, 0xF3, 0xF3, 0xF3, 0xF3, 
0x113, 0x113, 0x134, 0x934, 0x954, 0x954, 0x975, 0x975, 0x996, 
0x1196, 0x995, 0x995, 0x9F6, 0x11F6, 0x9F6, 0x1A37, 0x1A77, 0x1A99, 
0x22F9, 0x4C1A, 0x6CD9, 0xA5B8, 0xBE37, 0x6B2B, 0x800, 0x18A2, 0x0, 
0x841, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x862, 0x800, 0x3163, 0x7BED, 0x8CF3, 0xA61B, 
0x5459, 0x12B6, 0x22B8, 0x1237, 0xA16, 0x9F6, 0x9B5, 0x995, 0x995, 
0x154, 0x154, 0x975, 0x134, 0x133, 0x934, 0x913, 0x113, 0xF3, 
0xD2, 0xB2, 0xB2, 0x92, 0x92, 0x92, 0x71, 0x71, 0x71, 
0x71, 0x71, 0x71, 0x71, 0x71, 0x50, 0x8B2, 0x91, 0x91, 
0x21B5, 0x29D6, 0xD2, 0x91, 0x30, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x10, 0x30, 0x51, 0x71, 0x71, 0x92, 0x92, 0x92, 0xB2, 
0xB2, 0xB2, 0xB2, 0x912, 0xB1, 0xD2, 0x912, 0xF2, 0xD2, 
0xF3, 0xD2, 0xD3, 0xD3, 0xD3, 0xD3, 0xD3, 0xF3, 0x113, 
0x133, 0x133, 0x133, 0x134, 0x175, 0x975, 0x975, 0x994, 0x9B5, 
0x9D6, 0x1217, 0xA16, 0x1277, 0x1A98, 0x1AB6, 0x6CBA, 0xAE5C, 0x9D33, 
0x6309, 0x2923, 0x820, 0x820, 0x820, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x820, 0x800, 0x0, 
0x18A3, 0x0, 0x39E6, 0xB5D6, 0xB67C, 0x7D7E, 0x1AB7, 0x1A99, 0x1A58, 
0x1217, 0x1B5, 0x995, 0x975, 0x954, 0x154, 0x134, 0x113, 0x113, 
0xF3, 0xD2, 0x113, 0xD2, 0xB2, 0xB2, 0x92, 0x92, 0x71, 
0x71, 0x71, 0x71, 0x51, 0x51, 0x51, 0x51, 0x51, 0x50, 
0x50, 0x71, 0x51, 0x71, 0x50, 0x30, 0x30, 0x50, 0x71, 
0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x31, 
0x51, 0x51, 0x72, 0x71, 0x71, 0x91, 0x92, 0xB2, 0xB1, 
0x8D2, 0x8D2, 0xD2, 0xB2, 0xD2, 0xB2, 0xB2, 0xB2, 0xB2, 
0xB3, 0xD3, 0xD2, 0xD2, 0xD2, 0xF3, 0xF2, 0x113, 0x133, 
0x114, 0x114, 0x955, 0x975, 0x975, 0x9B6, 0x9D6, 0xA37, 0xA57, 
0x22F8, 0x1AB5, 0x64B8, 0xA619, 0xC657, 0x946E, 0x0, 0x1061, 0x841, 
0x0, 0x0, 0x20, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x800, 0x1882, 0x0, 0x630B, 0xD6D9, 
0xBE5A, 0x6457, 0x1A53, 0x1236, 0x1238, 0x9D6, 0x9B5, 0x995, 0x134, 
0x134, 0x954, 0x113, 0xD2, 0xF3, 0xF3, 0xB2, 0xB2, 0xB2, 
0x92, 0x92, 0x92, 0x71, 0x71, 0x51, 0x51, 0x51, 0x51, 
0x31, 0x31, 0x31, 0x50, 0x30, 0x30, 0x30, 0x50, 0x30, 
0x50, 0x891, 0x70, 0x30, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x10, 0x10, 0x51, 0x10, 0x30, 0x51, 
0x71, 0x71, 0x91, 0x91, 0x91, 0x91, 0x91, 0x71, 0x71, 
0x91, 0x92, 0xB2, 0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 
0xD2, 0xD2, 0x113, 0xF3, 0x113, 0x113, 0x114, 0x915, 0x955, 
0x975, 0x975, 0x9D6, 0xA16, 0x1256, 0x235, 0x1AD5, 0x4C36, 0x95F9, 
0xDF5B, 0x9CF0, 0x0, 0x841, 0x841, 0x0, 0x0, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x821, 
0x20, 0x840, 0x20, 0x3185, 0x62EA, 0x9CF2, 0x9536, 0x7D19, 0x4C1A, 
0xA36, 0x9D6, 0x11B6, 0x133, 0x954, 0x113, 0xF3, 0xF3, 0xD3, 
0xB2, 0xB2, 0x92, 0x92, 0x92, 0x92, 0x71, 0x71, 0x71, 
0x51, 0x31, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 
0x30, 0x10, 0x10, 0xF, 0xF, 0x30, 0xF, 0xF, 0x30, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 
0x10, 0x10, 0x30, 0x51, 0x51, 0x30, 0x51, 0x51, 0x31, 
0x51, 0x71, 0x71, 0x71, 0x892, 0x92, 0x92, 0x71, 0x72, 
0x92, 0x92, 0x92, 0xB2, 0xB2, 0xB2, 0xB2, 0xD3, 0xD2, 
0xF2, 0xF3, 0x114, 0x114, 0x134, 0x955, 0x975, 0x11B6, 0x9F5, 
0x1A96, 0x4C5B, 0x4C17, 0x6CF7, 0x9E18, 0x7C4E, 0x52A8, 0x1081, 0x0, 
0x841, 0x0, 0x801, 0x0, 0x0, 0x20, 0x20, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x822, 0x0, 0x0, 0x40, 0x20, 0x20E3, 
0x4A47, 0xA553, 0xB658, 0xB6DD, 0x4C18, 0x192, 0x11F6, 0x975, 0x954, 
0x113, 0x113, 0xD3, 0xD3, 0xD3, 0xB2, 0x92, 0x92, 0x92, 
0x72, 0x71, 0x71, 0x51, 0x51, 0x31, 0x30, 0x10, 0x10, 
0x30, 0x10, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0x30, 
0xF, 0xF, 0xF, 0x2F, 0x2F, 0xE, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0xF, 0x10, 
0x10, 0x30, 0x30, 0x30, 0x851, 0x51, 0x51, 0x31, 0x51, 
0x71, 0x51, 0x51, 0x71, 0x71, 0x71, 0x71, 0x92, 0x92, 
0x92, 0x92, 0xB2, 0x92, 0xB3, 0xD2, 0xD1, 0xF2, 0x113, 
0x134, 0x154, 0x155, 0x995, 0x194, 0x3318, 0x965F, 0xA67D, 0xA5F7, 
0xADB4, 0x6B2A, 0x800, 0x2944, 0x20, 0x821, 0x1, 0x0, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x0, 0x0, 0x0, 
0x841, 0x0, 0x10A1, 0x0, 0x41E6, 0xBE37, 0xCF1B, 0xB6BA, 0xA67C, 
0x7D5C, 0x1A75, 0x994, 0x975, 0x933, 0x113, 0xF3, 0xF3, 0xD2, 
0xB2, 0x92, 0x92, 0x92, 0x71, 0x71, 0x51, 0x51, 0x51, 
0x30, 0x10, 0x10, 0x10, 0x10, 0xF, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xE, 0xF, 0x2F, 0xF, 0xE, 
0xE, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x851, 0x30, 0x30, 0x30, 0x51, 0x31, 0x71, 
0x51, 0x71, 0x71, 0x71, 0x71, 0x92, 0xB2, 0xB2, 0x92, 
0xD2, 0xD1, 0xD1, 0xF2, 0xF3, 0x113, 0x134, 0x155, 0x975, 
0x11D5, 0x1A34, 0x53F7, 0x9E3C, 0xBE99, 0xD6F8, 0xCE57, 0xA4F2, 0x2103, 
0x0, 0x1082, 0x1, 0x1, 0x0, 0x0, 0x0, 0x0, 0x0, 
0x1, 0x1, 0x0, 0x0, 0x21, 0x0, 0x20, 0x1081, 0x800, 
0x4A68, 0xB616, 0x9DF7, 0x8577, 0x963D, 0x755D, 0x22B6, 0x974, 0x1195, 
0x113, 0xF3, 0xD2, 0xD3, 0xB2, 0xB2, 0x92, 0x71, 0x51, 
0x71, 0x51, 0x51, 0x51, 0x30, 0x10, 0x10, 0x10, 0x10, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 
0x30, 0x30, 0x30, 0x30, 0x50, 0x51, 0x51, 0x50, 0x51, 
0x71, 0x91, 0x92, 0x92, 0xB2, 0xB2, 0xD1, 0xD1, 0xD2, 
0xD3, 0x114, 0x135, 0x135, 0x976, 0x11D6, 0x9D4, 0x1233, 0x85DD, 
0xBF3E, 0xA637, 0xC699, 0xA533, 0x840, 0x0, 0x1062, 0x1, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x21, 0x0, 0x0, 
0x0, 0x0, 0x861, 0x840, 0x800, 0x9470, 0xCED9, 0x9DD7, 0x4C15, 
0x2B36, 0x1255, 0x11F5, 0x9B5, 0x154, 0x134, 0xF4, 0xD3, 0xB2, 
0xB2, 0x92, 0x71, 0x71, 0x51, 0x51, 0x51, 0x30, 0x30, 
0x30, 0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 0x30, 
0x30, 0x50, 0x50, 0x50, 0x51, 0x71, 0x71, 0x71, 0x91, 
0x92, 0x92, 0xB1, 0xD1, 0xD2, 0xD3, 0xF4, 0x114, 0x135, 
0x976, 0x995, 0x9B4, 0x2AF7, 0x6D1D, 0x755A, 0x6CB4, 0x9DB5, 0xD719, 
0x94B0, 0x0, 0x821, 0x842, 0x21, 0x0, 0x20, 0x0, 0x0, 
0x800, 0x0, 0x0, 0x21, 0x0, 0x20, 0x0, 0x861, 0x20, 
0x20A2, 0x49E6, 0x842E, 0xC6BA, 0x7D5A, 0x2B57, 0x1A76, 0x1A57, 0x9B5, 
0x154, 0x134, 0xF3, 0xD3, 0xB2, 0x92, 0x92, 0x71, 0x51, 
0x51, 0x50, 0x30, 0x30, 0x30, 0x30, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0xF, 0xF, 0x10, 0x30, 0x30, 0x30, 0x30, 0x50, 
0x50, 0x51, 0x51, 0x71, 0x71, 0x72, 0x72, 0x91, 0xB2, 
0xB2, 0xD3, 0xF3, 0x113, 0x134, 0x954, 0x1195, 0x11D6, 0x1216, 
0xA55, 0x1AB4, 0x5C76, 0xB698, 0xB634, 0x7C0D, 0x2103, 0x1, 0x1062, 
0x841, 0x0, 0x800, 0x0, 0x21, 0x0, 0x0, 0x0, 0x821, 
0x800, 0x800, 0x1041, 0x0, 0x18C2, 0x2903, 0x800, 0x28E0, 0xAD94, 
0xB6DD, 0x6D1B, 0x1254, 0x194, 0x133, 0x974, 0x113, 0xF3, 0xB2, 
0xB2, 0x92, 0x71, 0x51, 0x51, 0x51, 0x30, 0x30, 0x10, 
0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x30, 0x30, 0x30, 0x30, 0x30, 0x30, 0x51, 0x51, 
0x71, 0x72, 0x72, 0x72, 0x92, 0x8B2, 0xD2, 0xF3, 0x113, 
0x134, 0x154, 0x11B5, 0x11F6, 0x1257, 0x1AB7, 0x443B, 0x7D7A, 0xCF19, 
0x6B89, 0x20, 0x1080, 0x0, 0x821, 0x20, 0x0, 0x820, 0x0, 
0x0, 0x0, 0x0, 0x0, 0x0, 0x800, 0x800, 0x20A2, 0x820, 
0x5289, 0xB5B5, 0x7BAD, 0xAD52, 0xB5F6, 0xAE5A, 0x64B7, 0x1AB3, 0x5CBE, 
0x3B5A, 0x113, 0x933, 0xD2, 0xB2, 0x92, 0x92, 0x71, 0x51, 
0x50, 0x30, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x10, 
0x10, 0x10, 0x30, 0x30, 0x50, 0x51, 0x71, 0x71, 0x91, 
0xB1, 0xB1, 0xB2, 0xD2, 0x113, 0x114, 0x155, 0x175, 0x9F6, 
0x1AB8, 0xA54, 0x64FB, 0xBF1F, 0xB5D4, 0x6AE7, 0x1860, 0x5247, 0x8C50, 
0x0, 0x20, 0x18C4, 0x1, 0x1062, 0x821, 0x841, 0x820, 0x0, 
0x1882, 0x18A3, 0x20E4, 0x800, 0x1881, 0xAD53, 0xDF3A, 0xC6B9, 0xBEBB, 
0xB6BB, 0xB6BB, 0x8DB8, 0x757A, 0x969F, 0x7D5F, 0x19D5, 0xD2, 0x8F3, 
0xB2, 0x91, 0x71, 0x71, 0x51, 0x30, 0x30, 0x30, 0x10, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0xF, 0x10, 0x10, 0x10, 0x30, 
0x50, 0x50, 0x71, 0x71, 0x91, 0x91, 0x91, 0xB2, 0xD2, 
0xF3, 0x134, 0x995, 0x1256, 0xA35, 0xA75, 0x2336, 0x4C36, 0xA63B, 
0xA574, 0xCE76, 0xAD53, 0xBDF6, 0xD6DA, 0x842F, 0x2965, 0x0, 0x841, 
0x1061, 0x1082, 0x0, 0x0, 0x1041, 0x0, 0x800, 0x0, 0x630B, 
0x5B0A, 0xADB5, 0xAE38, 0x95F9, 0x6CF8, 0x7518, 0xB6BB, 0xB71D, 0xA71F, 
0x5499, 0x2295, 0x19F5, 0x8F3, 0xB2, 0x92, 0x91, 0x71, 0x51, 
0x30, 0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x10, 0x10, 0x10, 0x30, 0x50, 0x50, 0x50, 
0x71, 0x91, 0x92, 0x92, 0xB3, 0xD3, 0x953, 0x131, 0x22B4, 
0x7D9E, 0x549A, 0x2B33, 0x53F4, 0xA65C, 0xB67B, 0xBEBB, 0xB69B, 0xB69A, 
0xBEBA, 0xB616, 0x4A67, 0x7BAC, 0x2921, 0x0, 0x0, 0x18C2, 0x861, 
0x0, 0x4206, 0x630A, 0x73AD, 0xBE16, 0xBED8, 0xA659, 0x7D9A, 0x3BD6, 
0x2B76, 0x651B, 0xB71F, 0x8DB9, 0x3B54, 0x1A74, 0x152, 0x153, 0xF3, 
0xD2, 0x92, 0x71, 0x71, 0x50, 0x30, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0xF, 
0x10, 0x30, 0x50, 0x50, 0x50, 0x50, 0x71, 0x72, 0x92, 
0xB3, 0xD2, 0x19D5, 0x53DA, 0x7D5D, 0x967F, 0x969F, 0x85DD, 0x859B, 
0xBF1F, 0xAEBD, 0x6CB6, 0x7539, 0x6CD7, 0x8557, 0xA618, 0xA5B5, 0xCEB8, 
0xA552, 0xAD92, 0x9CD0, 0x39C6, 0x0, 0x0, 0x632A, 0xD6D8, 0xDF3B, 
0xAE37, 0xA659, 0xA6FE, 0x655D, 0x2378, 0x2337, 0x4C5A, 0x967E, 0x9E9E, 
0x5C7A, 0x2AF6, 0x993, 0x154, 0xF3, 0xB2, 0x92, 0x71, 0x51, 
0x50, 0x30, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xD, 0xE, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 
0x30, 0x50, 0x50, 0x71, 0x92, 0x92, 0xD3, 0x953, 0x3AF8, 
0x859F, 0x4C18, 0x64FA, 0xA6DF, 0x9EBF, 0xA6BF, 0xAEBE, 0x74F8, 0x2B75, 
0x33B6, 0x755A, 0xAEDF, 0xB6FE, 0x9E19, 0xBEBA, 0xEFBC, 0x9CB0, 0x800, 
0x1862, 0x1082, 0x0, 0x8470, 0xCEFB, 0x8D78, 0x5C77, 0x6D3D, 0x33B9, 
0x12B7, 0x1AD8, 0x1275, 0x64FC, 0x8E5F, 0x861F, 0x755F, 0x11D4, 0xD2, 
0x8F3, 0x92, 0x71, 0x51, 0x30, 0x30, 0x30, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x30, 0x30, 0x30, 0x50, 0x71, 
0x71, 0x92, 0xB2, 0xF3, 0x90, 0x2235, 0x1A33, 0x2272, 0x43D6, 
0x22D2, 0x6D19, 0xBF3F, 0x6CFA, 0x1AF6, 0x2B79, 0x4C19, 0x64FB, 0x651B, 
0x5C97, 0xA65B, 0xC699, 0x4A46, 0x800, 0x20C3, 0x18C3, 0x0, 0x5B0A, 
0xBEDA, 0x9E3B, 0x3B96, 0x1AF6, 0x1AD8, 0x1297, 0x1277, 0xA15, 0x3B99, 
0x1AB4, 0x3336, 0x7D7F, 0x2A97, 0x71, 0xD2, 0x71, 0x51, 0x51, 
0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x11, 0x31, 0x31, 0x51, 0x71, 0x92, 0xB2, 0xB2, 
0x914, 0xD2, 0x153, 0x9B3, 0x150, 0x32F5, 0x8E1F, 0x965F, 0x4419, 
0xA56, 0x1AB9, 0x1AB7, 0x1AD7, 0x2378, 0x4C39, 0x9E3B, 0xC6DB, 0x73AB, 
0x820, 0x840, 0x10A2, 0x820, 0x5B29, 0xC6D9, 0x95D8, 0x4C17, 0x3399, 
0x1297, 0xA57, 0xA16, 0x1216, 0x193, 0x172, 0x1A35, 0x4B9B, 0x19B5, 
0x71, 0x8D2, 0x51, 0x31, 0x30, 0x10, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x11, 0x31, 
0x31, 0x51, 0x71, 0x92, 0xB2, 0x92, 0xF4, 0x114, 0x974, 
0xF1, 0x4B9A, 0x8DBF, 0x3337, 0x1A95, 0x1257, 0xA58, 0x1A98, 0x1AD8, 
0x2338, 0x2B76, 0x7517, 0xBEDA, 0x9D32, 0x6329, 0x2143, 0x20, 0x7BEC, 
0xBE35, 0xB678, 0xAE9C, 0x9E7F, 0x6D5F, 0xA56, 0x1D6, 0x9D6, 0x174, 
0x995, 0x995, 0x133, 0xF3, 0xD3, 0xB2, 0x71, 0x851, 0x30, 
0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x10, 0x30, 0x50, 0x50, 0x71, 
0x92, 0x72, 0xB3, 0xF4, 0xF3, 0x113, 0x3298, 0x435A, 0x1A35, 
0x194, 0x9F6, 0x9F6, 0x1216, 0x1AB5, 0x54BB, 0x861D, 0x9E5A, 0xAE99, 
0xBEDA, 0xDF3B, 0x8C2E, 0x1040, 0xCE76, 0xCF1B, 0x95F9, 0xB75F, 0x85BD, 
0x22D4, 0x1A35, 0x19F6, 0x975, 0x955, 0x113, 0x934, 0x114, 0x92, 
0xB3, 0x8B2, 0x51, 0x30, 0x30, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x2F, 0x30, 0x50, 0x50, 0x71, 0xB2, 0x92, 0x92, 
0xD3, 0x934, 0xB2, 0xB2, 0x1174, 0x974, 0x9B6, 0x9D6, 0x1B4, 
0x22D6, 0x759E, 0x8E7F, 0xAEFD, 0xAEDC, 0x8598, 0xC6FD, 0xDEF9, 0xAD52, 
0xC699, 0xAE5B, 0x4BD4, 0x7D9D, 0x967F, 0x43B8, 0x993, 0x995, 0x955, 
0x914, 0x914, 0xD3, 0xB3, 0xD3, 0x8B3, 0x51, 0x71, 0x50, 
0x30, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x2F, 0x30, 
0x50, 0x51, 0x51, 0x91, 0xD2, 0xB2, 0xD2, 0xF3, 0x935, 
0x8F4, 0x934, 0x934, 0x995, 0x995, 0x1236, 0x22D7, 0xA32, 0x7D9C, 
0x85DD, 0x3BD7, 0x6CF9, 0xB679, 0xCEFA, 0xAE9B, 0x5C97, 0x3BB7, 0x2B37, 
0x4C1B, 0x3B7A, 0x195, 0x976, 0x135, 0x915, 0xD3, 0xF3, 0xB3, 
0x92, 0x72, 0x51, 0x50, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0x2F, 0x30, 0x50, 0x51, 0x71, 0x70, 
0x91, 0xB1, 0xB2, 0xD3, 0xB3, 0x8D4, 0x8F4, 0x934, 0x154, 
0x995, 0x9B5, 0x1B5, 0x1236, 0x43FA, 0x3398, 0x2358, 0x4C59, 0x95F8, 
0xB6FB, 0xA6BD, 0x757C, 0x2B37, 0x22D8, 0x1D4, 0x1D5, 0x9D6, 0x155, 
0x135, 0xF4, 0xF3, 0xD2, 0xB2, 0x71, 0x71, 0x71, 0x30, 
0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x30, 0x30, 0x31, 0x51, 0x51, 0x71, 0x71, 0x91, 0xB2, 
0xD2, 0x8D2, 0xF3, 0x114, 0x155, 0x175, 0x996, 0x11D7, 0x11F7, 
0x9D5, 0x1A97, 0x1AD7, 0x5CBB, 0xB6FE, 0xB6DB, 0xAEFE, 0x965F, 0x2B37, 
0x1AB8, 0x1277, 0x9F6, 0x9D6, 0x175, 0x133, 0x113, 0xD2, 0xD2, 
0xB2, 0x71, 0x51, 0x50, 0x30, 0x30, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x2F, 0x30, 0x30, 0x31, 
0x51, 0x51, 0x71, 0x91, 0xB1, 0xB1, 0xB2, 0xD2, 0xF4, 
0x114, 0x134, 0x155, 0x976, 0x1196, 0x1217, 0x1A78, 0x1AB8, 0x2316, 
0x5C97, 0xA6DE, 0x9E9D, 0x5477, 0x2B57, 0x12B8, 0xA37, 0x9F6, 0x174, 
0x133, 0x154, 0xF2, 0xD2, 0x92, 0x71, 0x50, 0x51, 0x50, 
0x30, 0x30, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x2F, 0x30, 0x30, 0x51, 0x51, 0x71, 0x71, 
0x91, 0xB1, 0xB2, 0xD3, 0xF4, 0x114, 0x133, 0x154, 0x974, 
0x995, 0x11D6, 0x1237, 0x1AB9, 0x22F8, 0x1AD4, 0x7DDD, 0x9EBF, 0x2B33, 
0x1AD5, 0x12B7, 0x1237, 0x11D6, 0x11B6, 0x974, 0x114, 0xD3, 0xD3, 
0xB2, 0x91, 0x71, 0x50, 0x30, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0x2E, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0x2F, 
0x30, 0x50, 0x50, 0x71, 0x71, 0x91, 0x91, 0xB2, 0xB2, 
0xD3, 0xF3, 0x113, 0x133, 0x974, 0x995, 0x11D6, 0x1237, 0x1278, 
0x2339, 0x3BF8, 0x75DE, 0x96DF, 0x85FF, 0x4459, 0x2317, 0x1A77, 0x1A37, 
0x9B5, 0x974, 0x954, 0x113, 0xB3, 0x92, 0x71, 0x50, 0x30, 
0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x50, 0x50, 
0x71, 0x71, 0x92, 0x92, 0xB2, 0xD3, 0xF3, 0x113, 0x133, 
0x954, 0x995, 0x11D6, 0x1256, 0x12B6, 0x12D4, 0x865F, 0x9EFF, 0x54B9, 
0x8E5F, 0x9EBF, 0x965F, 0x4BFA, 0x1214, 0x1235, 0xA14, 0x112, 0x113, 
0xD3, 0x92, 0x51, 0x30, 0x30, 0x30, 0x10, 0x10, 0xF, 
0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0x2F, 0x30, 0x50, 0x51, 0x71, 0x72, 0x91, 
0xB2, 0xD3, 0xF3, 0x113, 0x133, 0x974, 0x9B5, 0x9B5, 0x22D8, 
0x5CFD, 0x653C, 0x969F, 0x54B9, 0xA52, 0x3376, 0x7D9D, 0x963F, 0x6D1D, 
0x3BB8, 0x6D5E, 0x2B17, 0x1A76, 0x11B5, 0xB2, 0x92, 0x71, 0x51, 
0x31, 0x10, 0x10, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0x30, 
0x30, 0x50, 0x71, 0x71, 0x91, 0x92, 0xB3, 0xD3, 0xF3, 
0x133, 0x974, 0x11B5, 0x9F5, 0x1AB6, 0x7DBE, 0xA71F, 0x75BE, 0x1AB4, 
0x1A96, 0x22B7, 0x1234, 0x3337, 0x85DF, 0x8E3F, 0x861F, 0x759E, 0x43DA, 
0x132, 0xF3, 0x92, 0x51, 0x50, 0x30, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x30, 0x30, 0x50, 0x51, 0x71, 
0x91, 0x92, 0xB3, 0xD3, 0x113, 0x153, 0x995, 0x11F6, 0x1236, 
0x2317, 0x7DBD, 0x861F, 0x547B, 0xA35, 0x1216, 0x11F6, 0x194, 0x3B59, 
0x5C7B, 0x4BF8, 0x5CBA, 0x5CBB, 0x5C7D, 0x1A15, 0x21F6, 0x913, 0x50, 
0x30, 0x50, 0x2F, 0xE, 0x2E, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xB, 0xC, 
0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 
0xF, 0x10, 0x30, 0x30, 0x51, 0x71, 0x92, 0xB2, 0xF3, 
0x132, 0x173, 0x174, 0x9D5, 0x1F5, 0x2337, 0x75BF, 0x3BB7, 0x1234, 
0x1216, 0x174, 0x995, 0x974, 0x1A16, 0x1A35, 0x172, 0x9B3, 0x9F4, 
0x5C3D, 0x645F, 0x42FA, 0x1153, 0x30, 0x50, 0x30, 0xF, 0xF, 
0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 
0x51, 0x72, 0xB2, 0xD3, 0xD2, 0xF2, 0x32D9, 0x32F8, 0x2AF7, 
0x3378, 0x547B, 0x85DF, 0x4BFA, 0x9F5, 0x994, 0x154, 0x113, 0x113, 
0x133, 0x113, 0x133, 0x154, 0x133, 0x437B, 0x4B7B, 0xF2, 0xB1, 
0x70, 0x30, 0xF, 0xF, 0xF, 0x2F, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x10, 0x30, 0x51, 0x71, 0xB2, 0x92, 
0x913, 0x113, 0x4339, 0x6CFC, 0x85BC, 0x85DC, 0x85BD, 0x4C1A, 0x4BDB, 
0x1A36, 0x133, 0x113, 0xF3, 0xF3, 0xD2, 0xD2, 0xF3, 0x933, 
0xF2, 0x2A78, 0x433B, 0xF2, 0x70, 0x30, 0xF, 0xF, 0xF, 
0x2F, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 
0x30, 0x31, 0x71, 0x92, 0xB2, 0xF3, 0x934, 0x131, 0x5C59, 
0x85DC, 0x5455, 0x6D1A, 0x9B1, 0x153, 0x973, 0x113, 0xF3, 0xD2, 
0xB2, 0xB2, 0xB2, 0x92, 0xD2, 0xB2, 0x1174, 0x2A37, 0x8F2, 
0x50, 0xF, 0x2F, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 
0xF, 0xF, 0xF, 0xF, 0x10, 0x30, 0x31, 0x51, 0x92, 
0xB2, 0xD3, 0x974, 0x993, 0x4BF9, 0x861F, 0x85DE, 0x64FC, 0x2A96, 
0x132, 0x933, 0xB2, 0xB2, 0x92, 0x71, 0x71, 0x71, 0x71, 
0x71, 0x71, 0xB2, 0x71, 0x30, 0x30, 0xF, 0xF, 0x80F, 
0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0xF, 0xF, 
0x10, 0x10, 0x30, 0x51, 0x71, 0xB2, 0xF3, 0x133, 0x3B5A, 
0x64FE, 0x43D9, 0x1A95, 0x3338, 0x2A97, 0xD2, 0xD2, 0xB2, 0xB2, 
0x71, 0x71, 0x71, 0x51, 0x50, 0x51, 0x71, 0x50, 0xF, 
0x30, 0x2F, 0xF, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0xF, 0xF, 0x10, 0x10, 0x30, 0x71, 
0x92, 0xB2, 0xF2, 0x173, 0x1235, 0x543D, 0x3339, 0x132, 0x153, 
0xF2, 0x8F2, 0x8D2, 0x71, 0x51, 0x51, 0x30, 0x30, 0x30, 
0xF, 0x10, 0x30, 0xF, 0x50, 0xF, 0xF, 0xF, 0x80F, 
0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 
0xF, 0xF, 0x10, 0x30, 0x71, 0x91, 0xB2, 0x953, 0x132, 
0x1215, 0x5C7E, 0x32F9, 0x154, 0x933, 0x8F3, 0x91, 0x71, 0x71, 
0x30, 0x10, 0x10, 0xF, 0x10, 0x830, 0xF, 0xF, 0x10, 
0xF, 0xF, 0x80F, 0xF, 0xE, 0xE, 0xE, 0xD, 0x2D, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 0x10, 0x30, 
0x71, 0xB2, 0xF3, 0x112, 0xD0, 0x22B7, 0x5C3D, 0x2276, 0x133, 
0x913, 0xD2, 0x91, 0x71, 0x50, 0x10, 0x10, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xF, 0xF, 0x10, 0x30, 0x71, 0xD2, 0xD2, 0x994, 
0x2AB8, 0x4BBB, 0x4BFC, 0x437B, 0x1194, 0xD2, 0xB1, 0x91, 0x30, 
0x10, 0x10, 0x10, 0xF, 0xF, 0xF, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xF, 0xF, 0xF, 
0x30, 0x91, 0x91, 0xF3, 0x4B5B, 0x4B9C, 0x2297, 0x173, 0x3B1A, 
0x3AFB, 0xF3, 0x50, 0x71, 0x30, 0x10, 0xF, 0xF, 0xF, 
0xF, 0xF, 0xF, 0xF, 0xF, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0x2D, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xE, 0xE, 0xF, 0xF, 0x2F, 0x90, 0x19B5, 0x42DA, 
0x3ADA, 0x113, 0xD1, 0xF2, 0x113, 0x2A17, 0xD2, 0x50, 0x30, 
0x30, 0xF, 0xE, 0xF, 0xF, 0xE, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0x2D, 0xD, 
0xD, 0xD, 0xD, 0xC, 0xD, 0xC, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xE, 
0xF, 0xF, 0x6F, 0x21D5, 0x2A16, 0x21B5, 0x71, 0x8B2, 0x71, 
0x71, 0x50, 0x50, 0x30, 0xF, 0xF, 0xF, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xE, 0xE, 0xE, 0xF, 0xF, 0x4F, 0x2F, 
0x2F, 0x50, 0x871, 0x30, 0x50, 0x30, 0x2F, 0x2F, 0xF, 
0xF, 0xF, 0xE, 0x2F, 0xE, 0xE, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xE, 
0xE, 0xF, 0xF, 0xF, 0x50, 0x2F, 0xF, 0xF, 0x10, 
0xF, 0xF, 0xF, 0xE, 0x2F, 0x2F, 0xE, 0xE, 0xE, 
0xE, 0xE, 0xE, 0xE, 0xE, 0xE, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 0x9, 
0x9, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0xD, 0xD, 0xE, 0xE, 0xE, 0xF, 0x10, 
0xF, 0xF, 0xF, 0x10, 0xF, 0x10, 0xF, 0xF, 0xE, 
0x2E, 0xD, 0xE, 0x2F, 0xE, 0xF, 0xE, 0xE, 0xE, 
0xE, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 0xD, 
0xD, 0xD, 0x80D, 0x80C, 0xC, 0xC, 0xC, 0xC, 0xC, 
0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xC, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 0xB, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 0xA, 
0xA, 0xA, 0xA};